@@ -63,6 +63,8 @@ extern "C" {
         mfxU32 Type; //FrameType, e.g. MFX_FRAMETYPE_I
         mfxI32 DeltaQP;
         mfxU32 ClassAPQ;
+        mfxI8  QPDeltaExplicitModulation;
+        mfxU32 FeaturesAPQ[4];
         mfxU32 SpatialComplexity;
         mfxU32 KeepInDPB;
         mfxU32 RemoveFromDPBSize;
@@ -79,6 +81,8 @@ extern "C" {
     mfxStatus MFX_CDECL AEncProcessFrame(mfxHDL pthis, mfxU32 POC, mfxU8* InFrame, mfxI32 pitch, AEncFrame* OutFrame);
     mfxU16    MFX_CDECL AEncGetIntraDecision(mfxHDL pthis, mfxU32 displayOrder);
     mfxU16    MFX_CDECL AEncGetPersistenceMap(mfxHDL pthis, mfxU32 displayOrder, mfxU8 PMap[AENC_MAP_SIZE]);
+    mfxU16    MFX_CDECL AEncGetLastPQp(mfxHDL pthis);
+    mfxI8     MFX_CDECL AEncAPQSelect(mfxHDL pthis, mfxU32 SC, mfxU32 TSC, mfxU32 MVSize, mfxU32 Contrast, mfxU32 PyramidLayer, mfxU32 BaseQp);
     void      MFX_CDECL AEncUpdateFrame(mfxHDL pthis, mfxU32 displayOrder, mfxU32 bits, mfxU32 QpY);
 
 #ifdef __cplusplus
