@@ -71,6 +71,7 @@ struct BRC_FrameStruct
     mfxU32 LaIDist          = 0;
     mfxI16 qpDelta          = MFX_QP_UNDEFINED;
     mfxU16 qpModulation     = MFX_QP_MODULATION_NOT_DEFINED;
+    mfxI8  QPDeltaExplicitModulation      = 0;
     mfxU16 miniGopSize      = 0;
     mfxU16 QpMapNZ          = 0;
     mfxU16 PersistenceMapNZ = 0;
@@ -210,8 +211,8 @@ public:
         lowPower(0)
     {}
 
-    mfxStatus Init(mfxEncToolsCtrl const & ctrl, bool bMBBRC, bool bFieldMode);
-    mfxStatus GetBRCResetType(mfxEncToolsCtrl const & ctrl, bool bMBBRC, bool bNewSequence, bool &bReset, bool &bSlidingWindowReset);
+    mfxStatus Init(mfxEncToolsCtrl const & ctrl, bool bMBBRC, bool bFieldMode, bool bALTR);
+    mfxStatus GetBRCResetType(mfxEncToolsCtrl const & ctrl, bool bMBBRC, bool bNewSequence, bool &bReset, bool &bSlidingWindowReset, bool bALTR);
 };
 
 struct sHrdInput
@@ -585,11 +586,13 @@ public:
 
     ~BRC_EncToolBase() override { Close(); }
 
-    mfxStatus Init(mfxEncToolsCtrl const & ctrl, bool bMBBRC) override;
-    mfxStatus Reset(mfxEncToolsCtrl const & ctrl, bool bMBBRC) override;
+    mfxStatus Init(mfxEncToolsCtrl const & ctrl, bool bMBBRC, bool bALTR) override;
+    mfxStatus Reset(mfxEncToolsCtrl const & ctrl, bool bMBBRC, bool bALTR) override;
     void Close() override
     {
         m_bInit = false;
+        m_bDynamicInit = false;
+        m_FrameStruct.resize(0);
     }
 
     mfxStatus ReportEncResult(mfxU32 dispOrder, mfxEncToolsBRCEncodeResult const & pEncRes) override;
@@ -614,10 +617,10 @@ protected:
 
     virtual mfxU16 FillQpMap(const BRC_FrameStruct&, mfxU32 /*frameQp*/, mfxEncToolsHintQPMap*, mfxI16&) = 0;
 
-    mfxI32 GetCurQP(mfxU32 type, mfxI32 layer, mfxU16 isRef, mfxU16 qpMod, mfxI32 qpDeltaP) const;
-    mfxI32 GetSeqQP(mfxI32 qp, mfxU32 type, mfxI32 layer, mfxU16 isRef, mfxU16 qpMod, mfxI32 qpDeltaP) const;
-    mfxI32 GetPicQP(mfxI32 qp, mfxU32 type, mfxI32 layer, mfxU16 isRef, mfxU16 qpMod, mfxI32 qpDeltaP) const;
-    mfxF64 ResetQuantAb(mfxI32 qp, mfxU32 type, mfxI32 layer, mfxU16 isRef, mfxF64 fAbLong, mfxU32 eo, bool bIdr, mfxU16 qpMod, mfxI32 qpDeltaP, bool bNoNewQp) const;
+    mfxI32 GetCurQP(mfxU32 type, mfxI32 layer, mfxU16 isRef, mfxU16 qpMod, mfxI8 qpExp, mfxI32 qpDeltaP) const;
+    mfxI32 GetSeqQP(mfxI32 qp, mfxU32 type, mfxI32 layer, mfxU16 isRef, mfxU16 qpMod, mfxI8 qpExp, mfxI32 qpDeltaP) const;
+    mfxI32 GetPicQP(mfxI32 qp, mfxU32 type, mfxI32 layer, mfxU16 isRef, mfxU16 qpMod, mfxI8 qpExp, mfxI32 qpDeltaP) const;
+    mfxF64 ResetQuantAb(mfxI32 qp, mfxU32 type, mfxI32 layer, mfxU16 isRef, mfxF64 fAbLong, mfxU32 eo, bool bIdr, mfxU16 qpMod, mfxI8 qpExp, mfxI32 qpDeltaP, bool bNoNewQp) const;
     mfxI32 GetLaQpEst(mfxU32 LaAvgEncodedSize, mfxF64 inputBitsPerFrame, const BRC_FrameStruct& frameStruct, bool updateState);
 };
 
