@@ -156,7 +156,8 @@ inline void SetToolsStatus(mfxExtEncToolsConfig* conf, bool bOn)
         conf->AdaptiveQuantMatrices =
         conf->BRCBufferHints =
         conf->AdaptiveMBQP =
-        conf->BRC = mfxU16(bOn ? MFX_CODINGOPTION_ON : MFX_CODINGOPTION_OFF);
+        conf->BRC =
+        conf->SaliencyMapHint = mfxU16(bOn ? MFX_CODINGOPTION_ON : MFX_CODINGOPTION_OFF);
 }
 
 inline void CopyPreEncSCTools(mfxExtEncToolsConfig const & confIn, mfxExtEncToolsConfig* confOut)
@@ -716,7 +717,7 @@ mfxStatus EncTools::Init(mfxExtEncToolsConfig const * pConfig, mfxEncToolsCtrl c
     SetToolsStatus(&m_config, false);
     if (IsOn(pConfig->BRC))
     {
-        sts = m_brc->Init(*ctrl, IsOn(pConfig->AdaptiveMBQP));
+        sts = m_brc->Init(*ctrl, IsOn(pConfig->AdaptiveMBQP), IsOn(pConfig->AdaptiveLTR));
         MFX_CHECK_STS(sts);
         m_config.BRC = MFX_CODINGOPTION_ON;
     }
@@ -742,6 +743,11 @@ mfxStatus EncTools::Init(mfxExtEncToolsConfig const * pConfig, mfxEncToolsCtrl c
         MFX_CHECK_STS(sts);
     }
 
+    if(IsOn(pConfig->SaliencyMapHint))
+    {
+        MFX_RETURN(MFX_ERR_UNSUPPORTED);
+    }
+
     m_bInit = true;
     return sts;
 }
@@ -771,6 +777,7 @@ mfxStatus EncTools::Close()
         m_brc->Close();
         m_config.BRC = false;
     }
+    
 
     m_bInit = false;
 
@@ -802,7 +809,7 @@ mfxStatus EncTools::Reset(mfxExtEncToolsConfig const * config, mfxEncToolsCtrl c
     if (IsOn(config->BRC))
     {
         MFX_CHECK(m_config.BRC, MFX_ERR_UNSUPPORTED);
-        sts = m_brc->Reset(*ctrl, IsOn(config->AdaptiveMBQP));
+        sts = m_brc->Reset(*ctrl, IsOn(config->AdaptiveMBQP), IsOn(config->AdaptiveLTR));
         MFX_CHECK_STS(sts);
     }
     if (isPreEncSCD(*config, *ctrl))
@@ -1007,6 +1014,7 @@ mfxStatus EncTools::Submit(mfxEncToolsTaskParam const * par)
                 return MFX_ERR_UNDEFINED_BEHAVIOR;
             }
         }
+
     }
 
 
@@ -1014,7 +1022,7 @@ mfxStatus EncTools::Submit(mfxEncToolsTaskParam const * par)
 
     // Since AV1 BRC uses HEVC BRC, so need this conversion
     if(pEncRes && m_ctrl.CodecId == MFX_CODEC_AV1) {
-        pEncRes->QpY = EncToolsBRC::AV1_DC_Q_IDX_2_HEVC_QP[pEncRes->QpY];        
+        pEncRes->QpY = EncToolsBRC::AV1_DC_Q_IDX_2_HEVC_QP[pEncRes->QpY];
     }
 
     if (pEncRes && isPreEncSCD(m_config, m_ctrl)) {
@@ -1042,6 +1050,11 @@ mfxStatus EncTools::Submit(mfxEncToolsTaskParam const * par)
     mfxEncToolsHintPreEncodeGOP *pPreEncGOP = (mfxEncToolsHintPreEncodeGOP *)Et_GetExtBuffer(par->ExtParam, par->NumExtParam, MFX_EXTBUFF_ENCTOOLS_HINT_GOP);
     if (pPreEncGOP && IsOn(m_config.BRC))
     {
+        if (pPreEncGOP->QPModulation == MFX_QP_MODULATION_EXPLICIT) {
+            //MLAPQ Inference is only done when explicit modulation is used
+            sts = m_scd.GetMLApqDeltaQp(par->DisplayOrder, pPreEncGOP->QPDeltaExplicitModulation);
+            MFX_CHECK_STS(sts);
+        }
         return m_brc->ReportGopHints(par->DisplayOrder, *pPreEncGOP);
     }
 
@@ -1141,6 +1154,7 @@ mfxStatus EncTools::Query(mfxEncToolsTaskParam* par, mfxU32 /*timeOut*/)
         MFX_CHECK_STS(sts);
     }
 
+
     return sts;
 }
 
