@@ -193,6 +193,12 @@ mfxStatus VideoDECODEAV1::Init(mfxVideoParam* par)
     m_response_alien = {};
 
     mfxStatus sts = MFX_VPX_Utility::QueryIOSurfInternal(par, &m_request);
+    uint32_t dpb_size = std::max(8 + par->AsyncDepth, 8);
+    if (dpb_size >= m_request.NumFrameSuggested)
+    {
+        m_request.NumFrameSuggested = mfxU16(dpb_size + 1);
+    }
+
     MFX_CHECK_STS(sts);
 
     m_init_par = (mfxVideoParamWrapper)(*par);
@@ -613,7 +619,14 @@ mfxStatus VideoDECODEAV1::QueryIOSurf(VideoCORE* core, mfxVideoParam* par, mfxFr
 
     mfxStatus sts = MFX_ERR_NONE;
     if (!(par->IOPattern & MFX_IOPATTERN_OUT_SYSTEM_MEMORY))
+    {
         sts = MFX_VPX_Utility::QueryIOSurfInternal(par, request);
+        uint32_t dpb_size = std::max(8 + par->AsyncDepth, 8);
+        if (dpb_size >= request->NumFrameSuggested)
+        {
+            request->NumFrameSuggested = mfxU16(dpb_size + 1);
+        }
+    }
     else
     {
         request->Info = par->mfx.FrameInfo;
@@ -884,6 +897,8 @@ mfxStatus VideoDECODEAV1::QueryFrame(mfxThreadTask task)
     }
     mfxStatus sts = DecodeFrame(surface_out, frame);
 
+    m_decoder->Flush();
+
     MFX_CHECK_STS(sts);
     return MFX_TASK_DONE;
 }
@@ -957,10 +972,6 @@ mfxStatus VideoDECODEAV1::SubmitFrame(mfxBitstream* bs, mfxFrameSurface1* surfac
 
         for (;;)
         {
-            if (!m_decoder->IsFreeSlotInDPB()){
-                return MFX_WRN_DEVICE_BUSY;
-            }
-
             sts = m_surface_source->SetCurrentMFXSurface(surface_work);
             MFX_CHECK_STS(sts);
 
@@ -1304,12 +1315,6 @@ mfxStatus VideoDECODEAV1::FillOutputSurface(mfxFrameSurface1** surf_out, mfxFram
     mfxFrameSurface1* surface_out = *surf_out;
     MFX_CHECK(surface_out, MFX_ERR_INVALID_HANDLE);
 
-    // For repeated frame in VPL memory, ref_count of copied surface is added twice (in GetSurface),
-    // so need to decrease one more reference.
-     UMC::FrameMemID copiedFrmMid = m_decoder->GetRepeatedFrame();
-    if (copiedFrmMid != -1 && (fd->GetFrameMID() == copiedFrmMid) && surface_out->FrameInterface)
-        m_surface_source->DecreaseReference(copiedFrmMid);
-
     SetFrameType(*pFrame, *surface_out);
 
     surface_out->Info.FrameId.TemporalId = 0;
