@@ -43,6 +43,8 @@
 
 #include "mfx_utils.h"
 
+#include "mfx_unified_h264d_logging.h"
+
 inline bool IsNeedToUseHWBuffering(eMFXHWType /*type*/)
 {
     return false;
@@ -56,12 +58,12 @@ inline bool IsBigSurfacePoolApplicable(eMFXHWType type)
     return ret;
 }
 
-struct ThreadTaskInfo
+struct ThreadTaskInfo264
 {
     mfxFrameSurface1* surface_out      = nullptr;
     bool              is_decoding_done = false;
 
-    ThreadTaskInfo(mfxFrameSurface1* out)
+    ThreadTaskInfo264(mfxFrameSurface1* out)
         : surface_out(out)
     {}
 };
@@ -545,7 +547,7 @@ mfxStatus VideoDECODEH264::SetTargetViewList(mfxVideoParam *par)
 
 mfxStatus VideoDECODEH264::Reset(mfxVideoParam *par)
 {
-    MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_API, "VideoDECODEH264::Reset");
+    MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_INTERNAL, "VideoDECODEH264::Reset");
 
     UMC::AutomaticUMCMutex guard(m_mGuard);
 
@@ -649,7 +651,7 @@ mfxTaskThreadingPolicy VideoDECODEH264::GetThreadingPolicy(void)
 
 mfxStatus VideoDECODEH264::Query(VideoCORE *core, mfxVideoParam *in, mfxVideoParam *out)
 {
-    MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_API, "VideoDECODEH264::Query");
+    MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_INTERNAL, "VideoDECODEH264::Query");
     MFX_CHECK_NULL_PTR1(out);
 
     eMFXPlatform platform = MFX_Utility::GetPlatform(core, in);
@@ -801,7 +803,7 @@ mfxStatus VideoDECODEH264::GetVideoParam(mfxVideoParam *par)
 
 mfxStatus VideoDECODEH264::DecodeHeader(VideoCORE *core, mfxBitstream *bs, mfxVideoParam *par)
 {
-    MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_API, "VideoDECODEH264::DecodeHeader");
+    MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_INTERNAL, "VideoDECODEH264::DecodeHeader");
     MFX_CHECK_NULL_PTR2(bs, par);
 
     mfxStatus sts = CheckBitstream(bs);
@@ -866,7 +868,7 @@ mfxStatus VideoDECODEH264::DecodeHeader(VideoCORE *core, mfxBitstream *bs, mfxVi
 
 mfxStatus VideoDECODEH264::QueryIOSurf(VideoCORE *core, mfxVideoParam *par, mfxFrameAllocRequest *request)
 {
-    MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_API, "VideoDECODEH264::QueryIOSurf");
+    MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_INTERNAL, "VideoDECODEH264::QueryIOSurf");
     MFX_CHECK_NULL_PTR2(par, request);
 
     eMFXPlatform platform = MFX_Utility::GetPlatform(core, par);
@@ -881,10 +883,10 @@ mfxStatus VideoDECODEH264::QueryIOSurf(VideoCORE *core, mfxVideoParam *par, mfxF
 
     if (   !(par->IOPattern & MFX_IOPATTERN_OUT_VIDEO_MEMORY)
         && !(par->IOPattern & MFX_IOPATTERN_OUT_SYSTEM_MEMORY))
-        return MFX_ERR_INVALID_VIDEO_PARAM;
+        MFX_RETURN(MFX_ERR_INVALID_VIDEO_PARAM);
 
     if ((par->IOPattern & MFX_IOPATTERN_OUT_VIDEO_MEMORY) && (par->IOPattern & MFX_IOPATTERN_OUT_SYSTEM_MEMORY))
-        return MFX_ERR_INVALID_VIDEO_PARAM;
+        MFX_RETURN(MFX_ERR_INVALID_VIDEO_PARAM);
 
     int32_t isInternalManaging = params.IOPattern & MFX_IOPATTERN_OUT_SYSTEM_MEMORY;
 
@@ -907,10 +909,30 @@ mfxStatus VideoDECODEH264::QueryIOSurf(VideoCORE *core, mfxVideoParam *par, mfxF
 
     request->Type |= MFX_MEMTYPE_EXTERNAL_FRAME;
 
+#ifndef MFX_DEC_VIDEO_POSTPROCESS_DISABLE
+    mfxExtDecVideoProcessing * videoProcessing = (mfxExtDecVideoProcessing *)GetExtendedBuffer(par->ExtParam, par->NumExtParam, MFX_EXTBUFF_DEC_VIDEO_PROCESSING);
+    if (videoProcessing)
+    {
+        // need to substitute output format
+        // number of surfaces is same
+        request->Info.FourCC = videoProcessing->Out.FourCC;
+        request->Info.ChromaFormat = videoProcessing->Out.ChromaFormat;
+        sts = UpdateCscOutputFormat(par, request);
+        MFX_CHECK_STS(sts);
+
+        request->Info.Width = videoProcessing->Out.Width;
+        request->Info.Height = videoProcessing->Out.Height;
+        request->Info.CropX = videoProcessing->Out.CropX;
+        request->Info.CropY = videoProcessing->Out.CropY;
+        request->Info.CropW = videoProcessing->Out.CropW;
+        request->Info.CropH = videoProcessing->Out.CropH;
+    }
+#endif
+
     if (platform != core->GetPlatformType())
     {
         assert(platform == MFX_PLATFORM_SOFTWARE);
-        MFX_RETURN(MFX_WRN_PARTIAL_ACCELERATION);
+        MFX_RETURN(MFX_ERR_UNDEFINED_BEHAVIOR);
     }
 
     if (isNeedChangeVideoParamWarning)
@@ -989,26 +1011,37 @@ mfxStatus VideoDECODEH264::GetDecodeStat(mfxDecodeStat *stat)
 
 static mfxStatus AVCDECODERoutine(void *pState, void *pParam, mfxU32 threadNumber, mfxU32)
 {
-    auto decoder = reinterpret_cast<VideoDECODEH264*>(pState);
-    MFX_CHECK(decoder, MFX_ERR_UNDEFINED_BEHAVIOR);
+    MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_INTERNAL, "AVCDECODERoutine");
+    mfxStatus sts = MFX_ERR_NONE;
 
-    auto task =
-        reinterpret_cast<ThreadTaskInfo*>(pParam);
-    MFX_CHECK(task, MFX_ERR_UNDEFINED_BEHAVIOR);
+    try
+    {
+        auto decoder = reinterpret_cast<VideoDECODEH264*>(pState);
+        MFX_CHECK(decoder, MFX_ERR_UNDEFINED_BEHAVIOR);
 
-    return
-        decoder->RunThread(task, threadNumber);
+        auto task =
+            reinterpret_cast<ThreadTaskInfo264*>(pParam);
+        MFX_CHECK(task, MFX_ERR_UNDEFINED_BEHAVIOR);
+
+        sts = decoder->RunThread(task, threadNumber);
+    }
+    catch(...)
+    {
+        MFX_LTRACE_MSG_1(MFX_TRACE_LEVEL_INTERNAL, "exception handled");
+        return MFX_ERR_NONE;
+    }
+    return sts;
 }
 
 static mfxStatus AVCCompleteProc(void *, void *pParam, mfxStatus )
 {
-    delete reinterpret_cast<ThreadTaskInfo*>(pParam);
+    delete reinterpret_cast<ThreadTaskInfo264*>(pParam);
     return MFX_ERR_NONE;
 }
 
-mfxStatus VideoDECODEH264::RunThread(ThreadTaskInfo* info, mfxU32 threadNumber)
+mfxStatus VideoDECODEH264::RunThread(ThreadTaskInfo264* info, mfxU32 threadNumber)
 {
-    MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_API, "VideoDECODEH264::RunThread");
+    MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_INTERNAL, "VideoDECODEH264::RunThread");
 
     MFX_CHECK_NULL_PTR1(info);
 
@@ -1085,7 +1118,7 @@ mfxStatus VideoDECODEH264::DecodeFrameCheck(mfxBitstream *bs,
                                               mfxFrameSurface1 **surface_out,
                                               MFX_ENTRY_POINT *pEntryPoint)
 {
-    MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_API, "VideoDECODEH264::DecodeFrameCheck");
+    MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_INTERNAL, "VideoDECODEH264::DecodeFrameCheck");
 
     UMC::AutomaticUMCMutex guard(m_mGuard);
 
@@ -1101,7 +1134,7 @@ mfxStatus VideoDECODEH264::DecodeFrameCheck(mfxBitstream *bs,
                 return MFX_WRN_DEVICE_BUSY;
         }
 
-        ThreadTaskInfo * info = new ThreadTaskInfo{ *surface_out };
+        ThreadTaskInfo264* info = new ThreadTaskInfo264{ *surface_out };
 
         pEntryPoint->pRoutine           = &AVCDECODERoutine;
         pEntryPoint->pCompleteProc      = &AVCCompleteProc;
@@ -1560,6 +1593,9 @@ void VideoDECODEH264::FillOutputSurface(mfxFrameSurface1 **surf_out, mfxFrameSur
 
     surface_out->Data.DataFlag = (mfxU16)(pFrame->m_isOriginalPTS ? MFX_FRAMEDATA_ORIGINAL_TIMESTAMP : 0);
 
+    TRACE_BUFFER_EVENT(MFX_TRACE_API_AVC_OUTPUTINFO_TASK, EVENT_TYPE_INFO, TR_KEY_DECODE_BASIC_INFO,
+        surface_out, H264DecodeSurfaceOutparam, SURFACEOUT_H264D);
+
     UMC::SEI_Storer * storer = m_pH264VideoDecoder->GetSEIStorer();
     if (storer)
         storer->SetTimestamp(pFrame);
@@ -1567,7 +1603,7 @@ void VideoDECODEH264::FillOutputSurface(mfxFrameSurface1 **surf_out, mfxFrameSur
 
 mfxStatus VideoDECODEH264::DecodeFrame(mfxFrameSurface1 *surface_out, UMC::H264DecoderFrame * pFrame)
 {
-    MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_API, "VideoDECODEH264::DecodeFrame");
+    MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_INTERNAL, "VideoDECODEH264::DecodeFrame");
     MFX_CHECK_NULL_PTR1(surface_out);
 
     mfxI32 index;
@@ -1616,6 +1652,10 @@ mfxStatus VideoDECODEH264::DecodeFrame(mfxFrameSurface1 *surface_out, UMC::H264D
 
     UMC::AutomaticUMCMutex guard(m_mGuard);
     pFrame->setWasDisplayed();
+
+    TRACE_EVENT(MFX_TRACE_API_AVC_DISPLAYINFO_TASK, EVENT_TYPE_INFO, TR_KEY_DECODE_BASIC_INFO, make_event_data(
+        pFrame->m_PicOrderCnt[0], pFrame->m_PicOrderCnt[1], pFrame->FrameNum(), (uint32_t)pFrame->wasDisplayed(), (uint32_t)pFrame->wasOutputted()));
+
     return sts;
 }
 
