@@ -41,6 +41,8 @@
 
 using namespace UMC_HEVC_DECODER;
 
+#include "mfx_unified_h265d_logging.h"
+
 inline
 bool IsNeedToUseHWBuffering(eMFXHWType /*type*/)
 {
@@ -105,7 +107,7 @@ UMC::Status FillParam(MFXTaskSupplier_H265 * decoder, mfxVideoParam *par, bool f
     return umcRes;
 }
 
-struct ThreadTaskInfo
+struct ThreadTaskInfo265
 {
     bool              is_decoding_done = false;
     mfxFrameSurface1 *surface_out = nullptr;
@@ -142,7 +144,7 @@ VideoDECODEH265::~VideoDECODEH265(void)
 // Initialize decoder instance
 mfxStatus VideoDECODEH265::Init(mfxVideoParam *par)
 {
-    MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_API, "VideoDECODEH265::Init");
+    MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_INTERNAL, "VideoDECODEH265::Init");
     UMC::AutomaticUMCMutex guard(m_mGuard);
 
     MFX_CHECK(!m_isInit, MFX_ERR_UNDEFINED_BEHAVIOR);
@@ -398,25 +400,6 @@ mfxStatus VideoDECODEH265::Reset(mfxVideoParam *par)
 
     eMFXHWType type = m_core->GetHWType();
 
-#ifndef MFX_DEC_VIDEO_POSTPROCESS_DISABLE
-    mfxExtDecVideoProcessing * videoProcessing = (mfxExtDecVideoProcessing *)GetExtendedBuffer(m_vFirstPar.ExtParam, m_vFirstPar.NumExtParam, MFX_EXTBUFF_DEC_VIDEO_PROCESSING);
-
-    if (videoProcessing != nullptr)
-    {
-        // hardware resize is enabled
-        bool hardwareUpscale =
-            videoProcessing->Out.Width >= par->mfx.FrameInfo.Width ||
-            videoProcessing->Out.Height >= par->mfx.FrameInfo.Height;
-
-        if (hardwareUpscale)
-        {
-            // for now only downscale is supported
-            // at least Windows DirectX 11 provides only downscale interface
-            // ID3D11VideoContext1->DecoderEnableDownsampling()
-            return MFX_ERR_INVALID_VIDEO_PARAM;
-        }
-    }
-#endif
     eMFXPlatform platform = MFX_Utility::GetPlatform_H265(m_core, par);
     MFX_CHECK(platform == MFX_PLATFORM_HARDWARE, MFX_ERR_UNSUPPORTED);
 
@@ -456,7 +439,7 @@ mfxStatus VideoDECODEH265::Reset(mfxVideoParam *par)
 // Free decoder resources
 mfxStatus VideoDECODEH265::Close(void)
 {
-    MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_API, "VideoDECODEH265::Close");
+    MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_INTERNAL, "VideoDECODEH265::Close");
     UMC::AutomaticUMCMutex guard(m_mGuard);
 
     MFX_CHECK(m_isInit && m_pH265VideoDecoder.get(), MFX_ERR_NOT_INITIALIZED);
@@ -667,7 +650,7 @@ mfxStatus VideoDECODEH265::DecodeHeader(VideoCORE *core, mfxBitstream *bs, mfxVi
 // MediaSDK DECODE_QueryIOSurf API function
 mfxStatus VideoDECODEH265::QueryIOSurf(VideoCORE *core, mfxVideoParam *par, mfxFrameAllocRequest *request)
 {
-    MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_API, "VideoDECODEH265::QueryIOSurf");
+    MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_INTERNAL, "VideoDECODEH265::QueryIOSurf");
     MFX_CHECK_NULL_PTR2(par, request);
 
     eMFXPlatform platform = MFX_Utility::GetPlatform_H265(core, par);
@@ -713,7 +696,25 @@ mfxStatus VideoDECODEH265::QueryIOSurf(VideoCORE *core, mfxVideoParam *par, mfxF
     }
 
     request->Type |= MFX_MEMTYPE_EXTERNAL_FRAME;
+#ifndef MFX_DEC_VIDEO_POSTPROCESS_DISABLE
+    mfxExtDecVideoProcessing* videoProcessing = (mfxExtDecVideoProcessing*)GetExtendedBuffer(par->ExtParam, par->NumExtParam, MFX_EXTBUFF_DEC_VIDEO_PROCESSING);
+    if (videoProcessing)
+    {
+        // need to substitute output format
+        // number of surfaces is same
+        request->Info.FourCC = videoProcessing->Out.FourCC;
+        request->Info.ChromaFormat = videoProcessing->Out.ChromaFormat;
+        sts = UpdateCscOutputFormat(par, request);
+        MFX_CHECK_STS(sts);
 
+        request->Info.Width = videoProcessing->Out.Width;
+        request->Info.Height = videoProcessing->Out.Height;
+        request->Info.CropX = videoProcessing->Out.CropX;
+        request->Info.CropY = videoProcessing->Out.CropY;
+        request->Info.CropW = videoProcessing->Out.CropW;
+        request->Info.CropH = videoProcessing->Out.CropH;
+    }
+#endif
     MFX_CHECK(platform == core->GetPlatformType(), MFX_ERR_UNSUPPORTED);
 
     MFX_CHECK(!isNeedChangeVideoParamWarning, MFX_WRN_INCOMPATIBLE_VIDEO_PARAM);
@@ -787,29 +788,37 @@ mfxStatus VideoDECODEH265::GetDecodeStat(mfxDecodeStat *stat)
 // Decoder threads entry point
 static mfxStatus HEVCDECODERoutine(void *pState, void *pParam, mfxU32 threadNumber, mfxU32)
 {
-    MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_API, "HEVCDECODERoutine");
+    MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_INTERNAL, "HEVCDECODERoutine");
+    mfxStatus sts = MFX_ERR_NONE;
 
-    auto decoder = reinterpret_cast<VideoDECODEH265*>(pState);
-    MFX_CHECK(decoder, MFX_ERR_UNDEFINED_BEHAVIOR);
-
-    mfxStatus sts = decoder->RunThread(pParam, threadNumber);
-    MFX_CHECK_STS(sts);
+    try
+    {
+        auto decoder = reinterpret_cast<VideoDECODEH265*>(pState);
+        MFX_CHECK(decoder, MFX_ERR_UNDEFINED_BEHAVIOR);
 
+        sts = decoder->RunThread(pParam, threadNumber);
+        MFX_CHECK_STS(sts);
+    }
+    catch(...)
+    {
+        MFX_LTRACE_MSG_1(MFX_TRACE_LEVEL_INTERNAL, "exception handled");
+        return MFX_ERR_NONE;
+    }
     return sts;
 }
 
 // Threads complete proc callback
 static mfxStatus HEVCCompleteProc(void *, void *pParam, mfxStatus )
 {
-    delete reinterpret_cast<ThreadTaskInfo*>(pParam);
+    delete reinterpret_cast<ThreadTaskInfo265*>(pParam);
     return MFX_ERR_NONE;
 }
 
 // Decoder instance threads entry point. Do async tasks here
 mfxStatus VideoDECODEH265::RunThread(void * params, mfxU32 threadNumber)
 {
-    MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_API, "VideoDECODEH265::RunThread");
-    ThreadTaskInfo * info = reinterpret_cast<ThreadTaskInfo*>(params);
+    MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_INTERNAL, "VideoDECODEH265::RunThread");
+    ThreadTaskInfo265* info = reinterpret_cast<ThreadTaskInfo265*>(params);
 
     MFX_CHECK_NULL_PTR1(info);
 
@@ -920,7 +929,7 @@ mfxStatus VideoDECODEH265::DecodeFrameCheck(mfxBitstream *bs,
             }
         }
 
-        ThreadTaskInfo * info = new ThreadTaskInfo();
+        ThreadTaskInfo265* info = new ThreadTaskInfo265();
 
         if (*surface_out)
             info->surface_out = *surface_out;
@@ -941,7 +950,7 @@ mfxStatus VideoDECODEH265::DecodeFrameCheck(mfxBitstream *bs,
 // Check if there is enough data to start decoding in async mode
 mfxStatus VideoDECODEH265::DecodeFrameCheck(mfxBitstream *bs, mfxFrameSurface1 *surface_work, mfxFrameSurface1 **surface_out)
 {
-    MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_API, "VideoDECODEH265::DecodeFrameCheck");
+    MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_INTERNAL, "VideoDECODEH265::DecodeFrameCheck");
 
     MFX_CHECK(m_isInit, MFX_ERR_NOT_INITIALIZED);
 
@@ -1267,6 +1276,9 @@ void VideoDECODEH265::FillOutputSurface(mfxFrameSurface1 **surf_out, mfxFrameSur
 
     surface_out->Data.DataFlag = (mfxU16)(pFrame->m_isOriginalPTS ? MFX_FRAMEDATA_ORIGINAL_TIMESTAMP : 0);
 
+    TRACE_BUFFER_EVENT(MFX_TRACE_API_HEVC_OUTPUTINFO_TASK, EVENT_TYPE_INFO, TR_KEY_DECODE_BASIC_INFO,
+        surface_out, H265DecodeSurfaceOutparam, SURFACEOUT_H265D);
+
     SEI_Storer_H265 * storer = m_pH265VideoDecoder->GetSEIStorer();
     if (storer)
         storer->SetTimestamp(pFrame);
@@ -1300,24 +1312,34 @@ void VideoDECODEH265::FillOutputSurface(mfxFrameSurface1 **surf_out, mfxFrameSur
             info->FrameType |= MFX_FRAMETYPE_REF;
    }
 
-    mfxExtMasteringDisplayColourVolume* dispaly_colour = (mfxExtMasteringDisplayColourVolume*)GetExtendedBuffer(surface_out->Data.ExtParam, surface_out->Data.NumExtParam, MFX_EXTBUFF_MASTERING_DISPLAY_COLOUR_VOLUME);
-    if (dispaly_colour && pFrame->m_mastering_display.payLoadSize > 0)
+    mfxExtMasteringDisplayColourVolume* display_colour = (mfxExtMasteringDisplayColourVolume*)GetExtendedBuffer(surface_out->Data.ExtParam, surface_out->Data.NumExtParam, MFX_EXTBUFF_MASTERING_DISPLAY_COLOUR_VOLUME);
+    if (display_colour && pFrame->m_mastering_display.payLoadSize > 0)
     {
         for (size_t i = 0; i < 3; i++)
         {
-            dispaly_colour->DisplayPrimariesX[i] = (mfxU16)pFrame->m_mastering_display.SEI_messages.mastering_display.display_primaries[i][0];
-            dispaly_colour->DisplayPrimariesY[i] = (mfxU16)pFrame->m_mastering_display.SEI_messages.mastering_display.display_primaries[i][1];
+            display_colour->DisplayPrimariesX[i] = (mfxU16)pFrame->m_mastering_display.SEI_messages.mastering_display.display_primaries[i][0];
+            display_colour->DisplayPrimariesY[i] = (mfxU16)pFrame->m_mastering_display.SEI_messages.mastering_display.display_primaries[i][1];
         }
-        dispaly_colour->WhitePointX = (mfxU16)pFrame->m_mastering_display.SEI_messages.mastering_display.white_point[0];
-        dispaly_colour->WhitePointY = (mfxU16)pFrame->m_mastering_display.SEI_messages.mastering_display.white_point[1];
-        dispaly_colour->MaxDisplayMasteringLuminance = (mfxU32)pFrame->m_mastering_display.SEI_messages.mastering_display.max_luminance;
-        dispaly_colour->MinDisplayMasteringLuminance = (mfxU32)pFrame->m_mastering_display.SEI_messages.mastering_display.min_luminance;
+        display_colour->WhitePointX = (mfxU16)pFrame->m_mastering_display.SEI_messages.mastering_display.white_point[0];
+        display_colour->WhitePointY = (mfxU16)pFrame->m_mastering_display.SEI_messages.mastering_display.white_point[1];
+        display_colour->MaxDisplayMasteringLuminance = (mfxU32)pFrame->m_mastering_display.SEI_messages.mastering_display.max_luminance;
+        display_colour->MinDisplayMasteringLuminance = (mfxU32)pFrame->m_mastering_display.SEI_messages.mastering_display.min_luminance;
+        display_colour->InsertPayloadToggle = MFX_PAYLOAD_IDR;
+    }
+    else if(display_colour)
+    {
+        display_colour->InsertPayloadToggle = MFX_PAYLOAD_OFF;
     }
     mfxExtContentLightLevelInfo* content_light = (mfxExtContentLightLevelInfo*)GetExtendedBuffer(surface_out->Data.ExtParam, surface_out->Data.NumExtParam, MFX_EXTBUFF_CONTENT_LIGHT_LEVEL_INFO);
     if (content_light && pFrame->m_content_light_level_info.payLoadSize > 0)
     {
         content_light->MaxContentLightLevel = (mfxU16)pFrame->m_content_light_level_info.SEI_messages.content_light_level_info.max_content_light_level;
         content_light->MaxPicAverageLightLevel = (mfxU16)pFrame->m_content_light_level_info.SEI_messages.content_light_level_info.max_pic_average_light_level;
+        content_light->InsertPayloadToggle = MFX_PAYLOAD_IDR;
+    }
+    else if(content_light)
+    {
+        content_light->InsertPayloadToggle = MFX_PAYLOAD_OFF;
     }
 
 }
@@ -1377,6 +1399,9 @@ mfxStatus VideoDECODEH265::DecodeFrame(mfxFrameSurface1 *surface_out, H265Decode
 
     pFrame->setWasDisplayed();
 
+    TRACE_EVENT(MFX_TRACE_API_HEVC_DISPLAYINFO_TASK, EVENT_TYPE_INFO, TR_KEY_DECODE_BASIC_INFO, make_event_data(
+        pFrame->m_PicOrderCnt, (uint32_t)pFrame->wasDisplayed(), (uint32_t)pFrame->wasOutputted()));
+
     return sts;
 }
 
@@ -1404,7 +1429,7 @@ mfxStatus VideoDECODEH265::GetUserData(mfxU8 *ud, mfxU32 *sz, mfxU64 *ts)
     UMC::Status umcRes = m_pH265VideoDecoder->GetUserData(&data);
 
     if (umcRes == UMC::UMC_ERR_NOT_ENOUGH_DATA)
-        return MFX_ERR_MORE_DATA;
+        MFX_RETURN(MFX_ERR_MORE_DATA);
 
     MFX_CHECK(*sz >= data.GetDataSize(), MFX_ERR_NOT_ENOUGH_BUFFER);
 
