@@ -280,7 +280,7 @@ mfxStatus MFXVideoDECODEVC1::Init(mfxVideoParam *par)
 
     // Check. May be we in part mode
     if (MFX_ERR_NONE == MFXSts && isPartMode)
-        MFXSts = MFX_WRN_PARTIAL_ACCELERATION;
+        MFXSts = MFX_ERR_UNSUPPORTED;
 
     if (IOPattern & MFX_IOPATTERN_OUT_VIDEO_MEMORY)
     {
@@ -440,7 +440,7 @@ mfxStatus MFXVideoDECODEVC1::Reset(mfxVideoParam *par)
 
     if (false == IsHWSupported(m_pCore, par))
     {
-        MFXSts = MFX_WRN_PARTIAL_ACCELERATION;
+        MFXSts = MFX_ERR_UNSUPPORTED;
     }
 
     MFX_CHECK(!isNeedChangeVideoParamWarning, MFX_WRN_INCOMPATIBLE_VIDEO_PARAM);
@@ -526,25 +526,11 @@ mfxStatus MFXVideoDECODEVC1::Query(VideoCORE *core, mfxVideoParam *in, mfxVideoP
         in = &tpar;
 
         if (!IsHWSupported(core, in))
-            MFXSts = MFX_WRN_PARTIAL_ACCELERATION;
+            MFXSts = MFX_ERR_UNSUPPORTED;
     }
 
     if (MFX_ERR_NONE == MFXSts)
         MFXSts = MFXVC1DecCommon::Query(core, in, out);
-    else // MFX_WRN_PARTIAL_ACCELERATION;
-    {
-        MFXSts = MFXVC1DecCommon::Query(core, in, out);
-
-        if (0 < out->Protected)
-        {
-            // unsupported since there is no protected decoding
-            out->Protected = 0;
-            MFXSts = MFX_ERR_UNSUPPORTED;
-        }
-
-        if (MFX_ERR_NONE == MFXSts)
-            MFXSts = MFX_WRN_PARTIAL_ACCELERATION;
-    }
     MFX_CHECK(MFXSts < MFX_ERR_NONE, MFXSts);
     return MFXSts;
 }
@@ -571,7 +557,7 @@ mfxStatus MFXVideoDECODEVC1::GetVideoParam(mfxVideoParam *par)
     if (pSPS)
     {
         if (pSPS->SPSBufSize < m_RawSeq.size())
-            return MFX_ERR_NOT_ENOUGH_BUFFER;
+            MFX_RETURN(MFX_ERR_NOT_ENOUGH_BUFFER);
 
         std::copy(std::begin(m_RawSeq), std::end(m_RawSeq), pSPS->SPSBuffer);
         pSPS->SPSBufSize = (mfxU16)m_RawSeq.size();
@@ -582,7 +568,7 @@ mfxStatus MFXVideoDECODEVC1::GetVideoParam(mfxVideoParam *par)
 
 mfxStatus MFXVideoDECODEVC1::DecodeFrameCheck(mfxBitstream *bs, mfxFrameSurface1 *surface_work, mfxFrameSurface1 **surface_disp)
 {
-    MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_API, "MFXVideoDECODEVC1::DecodeFrameCheck");
+    MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_INTERNAL, "MFXVideoDECODEVC1::DecodeFrameCheck");
     mfxStatus MFXSts;
 
     MFX_CHECK(m_bIsDecInit, MFX_ERR_NOT_INITIALIZED);
@@ -614,7 +600,7 @@ mfxStatus MFXVideoDECODEVC1::DecodeFrameCheck(mfxBitstream *bs, mfxFrameSurface1
                 if(*((uint32_t*)ptr)!= 0x0F010000)
                 {
                     bs->DataOffset = bs->DataLength;
-                    return MFX_ERR_MORE_DATA;
+                    MFX_RETURN(MFX_ERR_MORE_DATA);
                 }
                 else
                 {
@@ -626,7 +612,7 @@ mfxStatus MFXVideoDECODEVC1::DecodeFrameCheck(mfxBitstream *bs, mfxFrameSurface1
         }
         else
         {
-            return MFX_ERR_MORE_DATA;
+            MFX_RETURN(MFX_ERR_MORE_DATA);
         }
     }
 
@@ -794,7 +780,7 @@ mfxStatus MFXVideoDECODEVC1::SelfConstructFrame(mfxBitstream *bs)
         {
             bs->DataLength -= dataSize;
             bs->DataOffset += dataSize;
-            return MFX_ERR_MORE_DATA;
+            MFX_RETURN(MFX_ERR_MORE_DATA);
         }
         else
         {
@@ -884,9 +870,9 @@ mfxStatus MFXVideoDECODEVC1::SelfConstructFrame(mfxBitstream *bs)
                     std::copy(bs->Data + bs->DataOffset, bs->Data + bs->DataOffset + m_SaveBytesSize, m_pSaveBytes);
                     m_sbs.TimeStamp = bs->TimeStamp;
                 }
-                return MFX_ERR_MORE_DATA;
+                MFX_RETURN(MFX_ERR_MORE_DATA);
             }
-            return MFX_ERR_NOT_ENOUGH_BUFFER;
+            MFX_RETURN(MFX_ERR_NOT_ENOUGH_BUFFER);
         }
     }
 }
@@ -948,9 +934,13 @@ mfxStatus MFXVideoDECODEVC1::SelfDecodeFrame(mfxFrameSurface1 *surface_work, mfx
         {
             *surface_disp = 0;
             if (bs && bs->DataLength > 4)
-                return MFX_ERR_MORE_SURFACE;
+            {
+                MFX_RETURN(MFX_ERR_MORE_SURFACE);
+            }
             else
-                return MFX_ERR_MORE_DATA;
+            {
+                MFX_RETURN(MFX_ERR_MORE_DATA);
+            }
         }
 
 
@@ -968,7 +958,7 @@ mfxStatus MFXVideoDECODEVC1::SelfDecodeFrame(mfxFrameSurface1 *surface_work, mfx
         bs->DataLength -= m_SHSize;
         bs->DataOffset += m_SHSize;
 
-        return MFX_ERR_MORE_DATA;
+        MFX_RETURN(MFX_ERR_MORE_DATA);
     }
 
     else if ((IntUMCStatus == UMC::UMC_OK)||
@@ -1047,7 +1037,7 @@ mfxStatus MFXVideoDECODEVC1::SelfDecodeFrame(mfxFrameSurface1 *surface_work, mfx
             (!m_pVC1VideoDecoder->IsLastFrameSkipped())) // skipped picture
         {
             m_bIsNeedToProcFrame = false;
-            return MFX_ERR_MORE_SURFACE;
+            MFX_RETURN(MFX_ERR_MORE_SURFACE);
         }
 
 
@@ -1093,9 +1083,13 @@ mfxStatus MFXVideoDECODEVC1::SelfDecodeFrame(mfxFrameSurface1 *surface_work, mfx
         else
         {
             if (bs && bs->DataLength > 4)
-                return MFX_ERR_MORE_SURFACE;
+            {
+                MFX_RETURN(MFX_ERR_MORE_SURFACE);
+            }
             else
-                return MFX_ERR_MORE_DATA;
+            {
+                MFX_RETURN(MFX_ERR_MORE_DATA);
+            }
         }
 
     }
@@ -1165,7 +1159,7 @@ mfxStatus MFXVideoDECODEVC1::ReturnLastFrame(mfxFrameSurface1 *surface_work, mfx
     if (m_bIsDecodeOrder)
     {
         SetFrameOrder(m_surface_source.get(), &m_par, true, m_qTS.front(), m_bIsSamePolar);
-        return MFX_ERR_MORE_DATA;
+        MFX_RETURN(MFX_ERR_MORE_DATA);
     }
 
     m_pVC1VideoDecoder->m_pStore->SeLastFramesMode();
@@ -1201,7 +1195,7 @@ mfxStatus MFXVideoDECODEVC1::ReturnLastFrame(mfxFrameSurface1 *surface_work, mfx
         switch (memID) {
         case -1:
         case -2:
-            return MFX_ERR_MORE_DATA;
+            MFX_RETURN(MFX_ERR_MORE_DATA);
         default:
             // only one frame in stream | reset + decodeframeasync + drain with zero bitstream
             // memID may be arbitrary in case of external allocator
@@ -1260,7 +1254,7 @@ mfxStatus MFXVideoDECODEVC1::PostProcessFrameHW(mfxFrameSurface1 *surface_work,
     }
 
     if (-1 == memIDdisp)
-        return MFX_ERR_MORE_DATA;
+        MFX_RETURN(MFX_ERR_MORE_DATA);
 
     if (m_bIsSWD3D && memIDdisp > -1)
     {
@@ -1302,7 +1296,7 @@ mfxStatus MFXVideoDECODEVC1::DecodeHeader(VideoCORE *, mfxBitstream *bs, mfxVide
 
     mfxVideoParam temp;
     MFXSts = MFXVC1DecCommon::ParseSeqHeader(bs, &temp, pVideoSignal, pSPS);
-    if(MFXSts == MFX_ERR_NOT_INITIALIZED) return MFX_ERR_MORE_DATA;
+    if(MFXSts == MFX_ERR_NOT_INITIALIZED) MFX_RETURN(MFX_ERR_MORE_DATA);
     if((MFXSts == MFX_ERR_MORE_DATA) && (bs->DataFlag & MFX_BITSTREAM_COMPLETE_FRAME || bs->DataFlag & MFX_BITSTREAM_EOS))
         MFXSts = MFX_ERR_NONE;
 
@@ -1448,7 +1442,7 @@ mfxStatus MFXVideoDECODEVC1::QueryIOSurf(VideoCORE *core, mfxVideoParam *par, mf
 
     if (!IsHWSupported(core, par))
     {
-        sts = MFX_WRN_PARTIAL_ACCELERATION;
+        sts = MFX_ERR_UNSUPPORTED;
     }
 
     return sts;
@@ -1730,7 +1724,7 @@ mfxStatus MFXVideoDECODEVC1::IsDisplayFrameReady(mfxFrameSurface1 **surface_disp
         MFXSts = m_pCore->IncreaseReference(&(*surface_disp)->Data);
         MFX_CHECK_STS(MFXSts);
 
-        return MFX_ERR_MORE_SURFACE;
+        MFX_RETURN(MFX_ERR_MORE_SURFACE);
     }
     else
     {
@@ -1783,7 +1777,7 @@ mfxStatus MFXVideoDECODEVC1::RunThread(mfxFrameSurface1 *surface_work,
                                        mfxU32 threadNumber,
                                        mfxU32 taskID)
 {
-    MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_API, "MFXVideoDECODEVC1::RunThread");
+    MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_INTERNAL, "MFXVideoDECODEVC1::RunThread");
 
     (void)threadNumber;
     mfxStatus sts;
@@ -1820,11 +1814,9 @@ mfxStatus MFXVideoDECODEVC1::RunThread(mfxFrameSurface1 *surface_work,
         else
         {
 
-            return sts;
+            MFX_RETURN(sts);
         }
     }
-
-    return MFX_ERR_ABORTED;
 }
 
 static mfxStatus VC1CompleteProc(void *, void *pParam, mfxStatus )
@@ -1863,7 +1855,7 @@ mfxStatus MFXVideoDECODEVC1::DecodeFrameCheck(mfxBitstream *bs,
         pEntryPoint->pParam = pAsyncSurface;
         pEntryPoint->pRoutineName = (char *)"DecodeVC1";
 
-        if (MFX_ERR_NONE == mfxSts)
+        if (MFX_ERR_NONE == mfxSts && (m_InternMediaDataOut.GetFrameType() != NONE_PICTURE))
         {
             FillMFXDataOutputSurface(*surface_out);
         }
