@@ -486,9 +486,10 @@ namespace Base
         mfxU32 SegmentationBitOffset;
         mfxU32 SegmentationBitSize;
         mfxU32 LoopFilterParamsBitOffset;
-        mfxU32 FrameHdrOBUSizeInBits;
-        mfxU32 FrameHdrOBUSizeByteOffset;
+        mfxU32 FrameHeaderOBUSizeInBits;
+        mfxU32 FrameHeaderOBUSizeByteOffset;
         mfxU32 UncompressedHeaderByteOffset;
+        mfxU32 HDRHeaderByteOffset;
         mfxU32 CDEFParamsBitOffset;
         mfxU32 CDEFParamsSizeInBits;
     };
@@ -717,11 +718,14 @@ namespace Base
     typedef struct _DpbFrame
         : FrameBaseInfo
     {
-        mfxU32   DisplayOrder   = mfxU32(-1);
-        mfxU32   EncodedOrder   = mfxU32(-1);
-        bool     isLTR          = false; // is "long-term"
-        bool     isRejected     = false; // rejected ref frame should be refreshed asap
-        mfxU8    CodingType     = 0;
+        mfxU32   DisplayOrder = mfxU32(-1);
+        mfxU32   EncodedOrder = mfxU32(-1);
+        mfxU64   TimestampIn  = 0;
+        mfxU16   PicStructIn  = 0;
+        mfxU32   FrameOrderIn = mfxU32(-1);
+        bool     isLTR        = false; // is "long-term"
+        bool     isRejected   = false; // rejected ref frame should be refreshed asap
+        mfxU8    CodingType   = 0;
         Resource Raw;
         Resource Rec;
         mfxFrameSurface1* pSurfIn = nullptr; //input surface, may be opaque
@@ -754,6 +758,7 @@ namespace Base
         , INSERT_SPS            = (1 << 3)
         , INSERT_PPS            = (1 << 4)
         , INSERT_FRM_OBU        = (1 << 5)
+        , INSERT_HDR            = (1 << 6)
     };
 
     using DpbType = std::vector<std::shared_ptr<DpbFrame>>;
@@ -779,6 +784,7 @@ namespace Base
         mfxU16              SceneChange = 0;
 #if defined(MFX_ENABLE_ENCTOOLS)
         mfxU16              SpatialComplexity = 0;
+        mfxI8               QPDeltaExplicitModulation = 0;
         /* Persistence Map */
         mfxU16              PersistenceMapNZ;
         mfxU8               PersistenceMap[MFX_ENCTOOLS_PREENC_MAP_SIZE];
@@ -823,7 +829,8 @@ namespace Base
         bool              bSkip                  = false;
         bool              bResetBRC              = false;
         bool              bRecode                = false;
-        bool              bCachedTask            = false;
+        bool              bFreed                 = false;
+        bool              bCached                = false;
         mfxI32            PrevRAP                = -1;
         mfxU16            NumRecode              = 0;
         mfxU8             QpY                    = 0;
@@ -1023,6 +1030,7 @@ namespace Base
         PackedData SPS;
         PackedData PPS;
         PackedData TD;
+        PackedData HDR;
     };
 
     using DDIExecParam     = MfxEncodeHW::DDIExecParam;
@@ -1298,6 +1306,7 @@ namespace Base
         , FEATURE_QUERY_IMPL_DESC
         , FEATURE_ENCTOOLS
         , FEATURE_MAX_FRAME_SIZE
+        , FEATURE_HDR
         , NUM_FEATURES
     };
 
@@ -1357,14 +1366,23 @@ namespace Base
         static const StorageR::TKey NUM_KEYS = __LINE__ - _KD;
     };
 
+    using TUsedRefList = std::remove_reference<decltype(mfxExtAVCEncodedFrameInfo::UsedRefListL0)>::type;
+    struct EncodedInfoAv1
+    {
+        TUsedRefList UsedRefListL0 = {};
+        TUsedRefList UsedRefListL1 = {};
+        mfxU16       QpY           = 0;
+    };
+
     struct Task
     {
         static const  StorageR::TKey _KD = __LINE__ + 1;
-        using Common     = StorageVar<__LINE__ - _KD, TaskCommonPar>;
-        using FH         = StorageVar<__LINE__ - _KD, Base::FH>;
-        using Segment    = StorageVar<__LINE__ - _KD, mfxExtAV1Segmentation>;
-        using TileInfo   = StorageVar<__LINE__ - _KD, TileInfoAv1>;
-        using TileGroups = StorageVar<__LINE__ - _KD, TileGroupInfos>;
+        using Common      = StorageVar<__LINE__ - _KD, TaskCommonPar>;
+        using FH          = StorageVar<__LINE__ - _KD, Base::FH>;
+        using Segment     = StorageVar<__LINE__ - _KD, mfxExtAV1Segmentation>;
+        using EncodedInfo = StorageVar<__LINE__ - _KD, EncodedInfoAv1>;
+        using TileInfo    = StorageVar<__LINE__ - _KD, TileInfoAv1>;
+        using TileGroups  = StorageVar<__LINE__ - _KD, TileGroupInfos>;
         static const StorageR::TKey TaskEventKey = __LINE__ - _KD;
         static const StorageR::TKey NUM_KEYS = __LINE__ - _KD;
     };
