@@ -66,7 +66,7 @@ void ApplyHWLimitation_XeHpm(StorageW& global, StorageW& s_task, mfxExtAV1Segmen
         {
             // force map update if SegmentIdBlockSize is smaller than SB size
             fh.segmentation_params.segmentation_update_map = 1;
-        }                
+        }
     }
 }
 
@@ -154,7 +154,25 @@ static void CDEF(FH& bs_fh)
 
     cdef.cdef_damping = (qp >> 6) + 3;
 }
- 
+
+template<class T> struct ExtBufTypeToId {};
+#define BIND_EXTBUF_TYPE_TO_ID(TYPE, ID) template<> struct ExtBufTypeToId<TYPE> { enum { id = ID }; }
+BIND_EXTBUF_TYPE_TO_ID (mfxExtAVCRefListCtrl, MFX_EXTBUFF_AVC_REFLIST_CTRL);
+
+static void InitExtBufHeader_AV1(mfxExtRefListCtrl& extBuf)
+{
+    extBuf = {};
+    extBuf.Header.BufferId = ExtBufTypeToId<mfxExtAVCRefListCtrl>::id;
+    extBuf.Header.BufferSz = sizeof(mfxExtRefListCtrl);
+
+    for (mfxU32 i = 0; i < 32; i++)
+        extBuf.PreferredRefList[i].FrameOrder = mfxU32(MFX_FRAMEORDER_UNKNOWN);
+    for (mfxU32 i = 0; i < 16; i++)
+        extBuf.RejectedRefList[i].FrameOrder = mfxU32(MFX_FRAMEORDER_UNKNOWN);
+    for (mfxU32 i = 0; i < 16; i++)
+        extBuf.LongTermRefList[i].FrameOrder = mfxU32(MFX_FRAMEORDER_UNKNOWN);
+}
+
 void AV1EncTools::SetSupported(ParamSupport& blocks)
 {
     blocks.m_ebCopySupported[MFX_EXTBUFF_ENCTOOLS_CONFIG].emplace_back(
@@ -198,6 +216,7 @@ void AV1EncTools::SetSupported(ParamSupport& blocks)
 
         MFX_COPY_FIELD(AdaptiveCQM);
         MFX_COPY_FIELD(ScenarioInfo);
+        MFX_COPY_FIELD(ExtBrcAdaptiveLTR);
     });
 }
 
@@ -243,6 +262,8 @@ inline bool IsHwLookAhead(const mfxExtEncToolsConfig &config, bool bGameStreamin
 
 bool AV1EHW::Base::IsHwEncToolsOn(const mfxVideoParam& video)
 {
+
+
     const mfxExtCodingOption3* pExtOpt3 = ExtBuffer::Get(video);
     const mfxExtCodingOption2* pExtOpt2 = ExtBuffer::Get(video);
     const mfxExtEncToolsConfig* pExtConfig = ExtBuffer::Get(video);
@@ -273,6 +294,7 @@ inline bool IsSwEncToolsImplicit(const mfxVideoParam &video)
 
 bool AV1EHW::Base::IsSwEncToolsOn(const mfxVideoParam& video){
 
+
     if(IsHwEncToolsOn(video))
     {
         return false;
@@ -285,15 +307,15 @@ bool AV1EHW::Base::IsSwEncToolsOn(const mfxVideoParam& video){
         SetDefaultConfig(video, config, true);
 
         return
-              IsOn(config.AdaptiveI) | IsOn(config.AdaptiveB)
-            | IsOn(config.AdaptiveRefP) | IsOn(config.AdaptiveRefB)
-            | IsOn(config.SceneChange)
-            | IsOn(config.AdaptiveLTR)
-            | IsOn(config.AdaptivePyramidQuantP) | IsOn(config.AdaptivePyramidQuantB)
-            | IsOn(config.AdaptiveQuantMatrices)
-            | IsOn(config.AdaptiveMBQP)
-            | IsOn(config.BRCBufferHints)
-            | IsOn(config.BRC);
+              IsOn(config.AdaptiveI) || IsOn(config.AdaptiveB)
+            || IsOn(config.AdaptiveRefP) || IsOn(config.AdaptiveRefB)
+            || IsOn(config.SceneChange)
+            || IsOn(config.AdaptiveLTR)
+            || IsOn(config.AdaptivePyramidQuantP) || IsOn(config.AdaptivePyramidQuantB)
+            || IsOn(config.AdaptiveQuantMatrices)
+            || IsOn(config.AdaptiveMBQP)
+            || IsOn(config.BRCBufferHints)
+            || IsOn(config.BRC);
     }
     else
     {
@@ -327,7 +349,7 @@ bool IsEncToolsConfigDefined(const mfxExtEncToolsConfig *config){
     //this code is based on definition of MFX_CODINGOPTION_UNKNOWN=0 
     if(!config)
         return false;
-    
+
     return
           config->AdaptiveI | config->AdaptiveB
         | config->AdaptiveRefP | config->AdaptiveRefB
@@ -350,11 +372,13 @@ static bool isSWLACondition(const mfxVideoParam& video)
 
 void AV1EHW::Base::SetDefaultConfig(const mfxVideoParam &video, mfxExtEncToolsConfig &config, bool bMBQPSupport)
 {
+
+
     const mfxExtCodingOption2  *pExtOpt2 = ExtBuffer::Get(video);
     const mfxExtCodingOption3  *pExtOpt3 = ExtBuffer::Get(video);
     const mfxExtEncToolsConfig *pExtConfig = ExtBuffer::Get(video);
     const mfxExtAV1AuxData *pAuxData = ExtBuffer::Get(video);
-
+    const mfxExtCodingOptionDDI *pExtDdi = ExtBuffer::Get(video);
     bool bGameStreaming = pExtOpt3 && pExtOpt3->ScenarioInfo == MFX_SCENARIO_GAME_STREAMING;
 
     if (!IsEncToolsConfigDefined(pExtConfig))
@@ -403,11 +427,13 @@ void AV1EHW::Base::SetDefaultConfig(const mfxVideoParam &video, mfxExtEncToolsCo
             bool bAdaptiveI = !(pExtOpt2 && IsOff(pExtOpt2->AdaptiveI)) && !(video.mfx.GopOptFlag & MFX_GOP_STRICT);
             bool bHasB = video.mfx.GopRefDist > 1;
             bool bAdaptiveB = !(pExtOpt2 && IsOff(pExtOpt2->AdaptiveB)) && !(video.mfx.GopOptFlag & MFX_GOP_STRICT) && bHasB;
-        
+            bool bAdaptiveLTR = !(pExtDdi && pExtDdi->NumActiveRefP < 2) && !(video.mfx.GopOptFlag & MFX_GOP_STRICT) && (pExtOpt3 && IsOn(pExtOpt3->ExtBrcAdaptiveLTR));
+
             SetDefaultOpt(config.AdaptiveI, bAdaptiveI);
             SetDefaultOpt(config.AdaptiveB, bAdaptiveB);
             SetDefaultOpt(config.AdaptivePyramidQuantP, false);
             SetDefaultOpt(config.AdaptivePyramidQuantB, bHasB);
+            SetDefaultOpt(config.AdaptiveLTR, bAdaptiveLTR);
         }
         SetDefaultOpt(config.BRC, (video.mfx.RateControlMethod == MFX_RATECONTROL_CBR ||
             video.mfx.RateControlMethod == MFX_RATECONTROL_VBR));
@@ -422,7 +448,6 @@ void AV1EHW::Base::SetDefaultConfig(const mfxVideoParam &video, mfxExtEncToolsCo
         //these features are not supported for now, we will enable them in future
         config.AdaptiveRefP          = MFX_CODINGOPTION_OFF;
         config.AdaptiveRefB          = MFX_CODINGOPTION_OFF;
-        config.AdaptiveLTR           = MFX_CODINGOPTION_OFF;
         config.AdaptiveQuantMatrices = MFX_CODINGOPTION_OFF;
     }
 #ifdef MFX_ENABLE_ENCTOOLS_LPLA
@@ -457,10 +482,13 @@ inline mfxU32 CheckFlag(mfxU16 & flag, bool bCond)
 
 static mfxU32 CorrectVideoParams(mfxVideoParam & video, mfxExtEncToolsConfig & supportedConfig)
 {
+
+
     mfxExtCodingOption2   *pExtOpt2 = ExtBuffer::Get(video);
     mfxExtCodingOption3   *pExtOpt3 = ExtBuffer::Get(video);
     mfxExtBRC             *pBRC = ExtBuffer::Get(video);
     mfxExtEncToolsConfig  *pConfig = ExtBuffer::Get(video);
+    mfxExtCodingOptionDDI *pExtDdi = ExtBuffer::Get(video);
 
     mfxU32 changed = 0;
     bool bIsEncToolsEnabled = false;
@@ -473,6 +501,7 @@ static mfxU32 CorrectVideoParams(mfxVideoParam & video, mfxExtEncToolsConfig & s
         bool bHasB = video.mfx.GopRefDist > 1;
         bool bAdaptiveB = !(pExtOpt2 && IsOff(pExtOpt2->AdaptiveB)) && !(video.mfx.GopOptFlag & MFX_GOP_STRICT) && bHasB;
         bool bAdaptiveRef = false;
+        bool bAdaptiveLTR = !(pExtDdi && pExtDdi->NumActiveRefP < 2) && !(pExtOpt3 && IsOff(pExtOpt3->ExtBrcAdaptiveLTR)) && !(video.mfx.GopOptFlag & MFX_GOP_STRICT);        
 
         changed += CheckFlag(pConfig->AdaptiveI, bIsEncToolsEnabled && bAdaptiveI);
         changed += CheckFlag(pConfig->AdaptiveB, bIsEncToolsEnabled && bAdaptiveB);
@@ -481,7 +510,7 @@ static mfxU32 CorrectVideoParams(mfxVideoParam & video, mfxExtEncToolsConfig & s
 
         changed += CheckFlag(pConfig->AdaptiveRefP, bIsEncToolsEnabled  && bAdaptiveRef);
         changed += CheckFlag(pConfig->AdaptiveRefB, bIsEncToolsEnabled  && bAdaptiveRef);
-        changed += CheckFlag(pConfig->AdaptiveLTR, bIsEncToolsEnabled  && bAdaptiveRef);
+        changed += CheckFlag(pConfig->AdaptiveLTR, bIsEncToolsEnabled  && bAdaptiveLTR);
         changed += CheckFlag(pConfig->SceneChange, bIsEncToolsEnabled);
         changed += CheckFlag(pConfig->BRCBufferHints, bIsEncToolsEnabled);
         changed += CheckFlag(pConfig->AdaptiveQuantMatrices, bIsEncToolsEnabled);
@@ -553,7 +582,7 @@ static mfxStatus InitEncToolsCtrl(
     ctrl->MaxGopSize = par.mfx.GopPicSize;
     ctrl->MaxGopRefDist = par.mfx.GopRefDist;
     ctrl->MaxIDRDist = par.mfx.GopPicSize;
- 
+
     ctrl->BRefType = pCO2 ? pCO2->BRefType : 0;
 
     ctrl->ScenarioInfo = pCO3 ? pCO3->ScenarioInfo : 0;
@@ -565,6 +594,7 @@ static mfxStatus InitEncToolsCtrl(
     bool   BRC = (par.mfx.RateControlMethod == MFX_RATECONTROL_CBR ||
         par.mfx.RateControlMethod == MFX_RATECONTROL_VBR);
 
+
     ctrl->RateControlMethod = par.mfx.RateControlMethod;  //CBR, VBR, CRF,CQP
 
     if (!BRC)
@@ -602,22 +632,23 @@ static mfxStatus InitEncToolsCtrl(
         ctrl->PanicMode = pCO3 ? pCO3->BRCPanicMode : 0;
     }
 
+
     // LaScale here
     ctrl->LaScale = 0;
     ctrl->LaQp = 30;
-    if (ctrl->ScenarioInfo == MFX_SCENARIO_GAME_STREAMING) 
+    if (ctrl->ScenarioInfo == MFX_SCENARIO_GAME_STREAMING)
     {
         mfxU16 crW = par.mfx.FrameInfo.CropW ? par.mfx.FrameInfo.CropW : par.mfx.FrameInfo.Width;
         if (crW >= 720) ctrl->LaScale = 2;
     }
-    else 
+    else
     {
         mfxU16 crH = par.mfx.FrameInfo.CropH ? par.mfx.FrameInfo.CropH : par.mfx.FrameInfo.Height;
         mfxU16 crW = par.mfx.FrameInfo.CropW ? par.mfx.FrameInfo.CropW : par.mfx.FrameInfo.Width;
         mfxU16 maxDim = std::max(crH, crW);
         mfxU16 minDim = std::min(crH, crW);
         constexpr mfxU16 LaScale = 2;
-        if (maxDim >= 720 && 
+        if (maxDim >= 720 &&
             minDim >= (128 << LaScale)) //encoder limitation, 128 and up is fine
         {
             ctrl->LaScale = LaScale;
@@ -651,9 +682,9 @@ void AV1EncTools::Query1NoCaps(const FeatureBlocks& blocks, TPushQ1 Push)
                             pCO2->MBBRC :
                             bDisableMBQP ? MFX_CODINGOPTION_OFF : MFX_CODINGOPTION_ON);
                     }
-                    
+
                     return mfxU16(prev(par));
-                    
+
                 });
             return MFX_ERR_NONE;
         });
@@ -847,7 +878,7 @@ void AV1EncTools::QueryIOSurf(const FeatureBlocks&, TPushQIS Push)
 
         mfxU32 maxDelay = 0;
         pEncTools->GetDelayInFrames(pEncTools->Context, &config, &ctrl, &maxDelay);
-        
+
         mfxExtCodingOption2* pCO2 = ExtBuffer::Get(par);
         if (pCO2)
             maxDelay = (mfxU32)std::max<mfxI32>(0, maxDelay - pCO2->LookAheadDepth); //LA is used in base_legacy
@@ -870,19 +901,31 @@ mfxStatus AV1EncTools::SubmitPreEncTask(StorageW&  /*global*/, StorageW& s_task)
     auto&      task = Task::Common::Get(s_task);
     std::vector<mfxExtBuffer*> extParams;
     mfxEncToolsFrameToAnalyze extFrameData = {};
-    if (task.pSurfIn)
+
+    //"m_numPicBuffered > 0" indicates: there are some PreEnc frames buffered for async_depth > 1 case, while not queried
+    if (task.pSurfIn || m_numPicBuffered > 0)
     {
         extFrameData.Header.BufferId = MFX_EXTBUFF_ENCTOOLS_FRAME_TO_ANALYZE;
         extFrameData.Header.BufferSz = sizeof(extFrameData);
         extFrameData.Surface = task.pSurfIn;
         extParams.push_back(&extFrameData.Header);
         task_par.ExtParam = extParams.data();
+
+        if (!task.pSurfIn)
+        {
+            m_numPicBuffered--;
+        }
     }
     task_par.DisplayOrder = task.DisplayOrder;
     task_par.NumExtParam = (mfxU16)extParams.size();
 
     auto sts = m_pEncTools->Submit(m_pEncTools->Context, &task_par);
-    if (sts == MFX_ERR_MORE_DATA) sts = MFX_ERR_NONE;
+    if (sts == MFX_ERR_MORE_DATA)
+    {
+        m_numPicBuffered++; // current PreEnc frame buffered, while not queried
+        sts = MFX_ERR_NONE;
+    }
+
     return (sts);
 }
 
@@ -912,6 +955,10 @@ mfxStatus AV1EncTools::BRCGetCtrl(StorageW& global, StorageW& s_task,
         if (extFrameData.PersistenceMapNZ)
             memcpy(extFrameData.PersistenceMap, task.GopHints.PersistenceMap, sizeof(extFrameData.PersistenceMap));
 
+        if (task.InternalListCtrlPresent && task.InternalListCtrl.LongTermRefList[0].FrameOrder == task.DisplayOrder) {
+            extFrameData.LongTerm = 1;
+        }
+
         extParams.push_back(&extFrameData.Header);
 
         if (task.BrcHints.LaAvgEncodedBits)
@@ -930,6 +977,7 @@ mfxStatus AV1EncTools::BRCGetCtrl(StorageW& global, StorageW& s_task,
             extPreGop.Header.BufferId = MFX_EXTBUFF_ENCTOOLS_HINT_GOP;
             extPreGop.Header.BufferSz = sizeof(extPreGop);
             extPreGop.QPModulation = (mfxU16)task.GopHints.QPModulaton;
+            extPreGop.QPDeltaExplicitModulation = (mfxI8)task.GopHints.QPDeltaExplicitModulation;
             extPreGop.MiniGopSize = (mfxU16)task.GopHints.MiniGopSize;
             extParams.push_back(&extPreGop.Header);
         }
@@ -964,7 +1012,7 @@ mfxStatus AV1EncTools::BRCGetCtrl(StorageW& global, StorageW& s_task,
             // Allocate memory for segmentation, if not allocated yet
             if (m_pSegmentQPMap == nullptr)
                 AllocSegmentationData(par.mfx.FrameInfo.Width, par.mfx.FrameInfo.Height, caps.MinSegIdBlockSizeAccepted);
-            
+
             // Get QP map
             qpMapHint.Header.BufferId = MFX_EXTBUFF_ENCTOOLS_HINT_QPMAP;
             qpMapHint.Header.BufferSz = sizeof(qpMapHint);
@@ -984,14 +1032,14 @@ mfxStatus AV1EncTools::BRCGetCtrl(StorageW& global, StorageW& s_task,
             seg_enctools.SegmentIds = m_pSegmentIDMap;
             extParams.push_back(&seg_enctools.Header);
         }
- 
+
         task_par.NumExtParam = (mfxU16)extParams.size();
         task_par.ExtParam = extParams.data();
 
         auto sts = m_pEncTools->Query(m_pEncTools->Context, &task_par, ENCTOOLS_QUERY_TIMEOUT);
         MFX_CHECK_STS(sts);
 
-        task.bCUQPMap = qpMapHint.QpMapFilled ? true : false;  
+        task.bCUQPMap = qpMapHint.QpMapFilled ? true : false;
 
         mfxExtAV1Segmentation& seg_task = Task::Segment::Get(s_task);
 
@@ -1054,6 +1102,7 @@ mfxStatus AV1EncTools::QueryPreEncTask(StorageW&  /*global*/, StorageW& s_task)
     mfxEncToolsBRCBufferHint bufHint = {};
     mfxEncToolsHintQuantMatrix cqmHint = {};
     mfxEncToolsHintQPMap qpMapHint = {};
+    mfxEncToolsHintPreEncodeARefFrames aRef = {};
 
     bool isLABRC = (m_EncToolCtrl.ScenarioInfo == MFX_SCENARIO_UNKNOWN &&
                      IsOn(m_EncToolConfig.BRCBufferHints) &&
@@ -1098,11 +1147,17 @@ mfxStatus AV1EncTools::QueryPreEncTask(StorageW&  /*global*/, StorageW& s_task)
         extParams.push_back(&bufHint.Header);
     }
 
+    if (IsOn(m_EncToolConfig.AdaptiveLTR))
+    {
+        aRef.Header.BufferId = MFX_EXTBUFF_ENCTOOLS_HINT_AREF;
+        aRef.Header.BufferSz = sizeof(aRef);
+        extParams.push_back(&aRef.Header);
+    }
+
     task_par.ExtParam = extParams.data();
     task_par.NumExtParam = (mfxU16)extParams.size();
     MFX_CHECK(task_par.NumExtParam, MFX_ERR_NONE);
 
-    
     auto sts = m_pEncTools->Query(m_pEncTools->Context, &task_par, ENCTOOLS_QUERY_TIMEOUT);
     if (sts == MFX_ERR_MORE_DATA) sts = MFX_ERR_NONE;
     MFX_CHECK_STS(sts);
@@ -1149,8 +1204,11 @@ mfxStatus AV1EncTools::QueryPreEncTask(StorageW&  /*global*/, StorageW& s_task)
     else
 #endif
     {
-        if (IsOn(m_EncToolConfig.AdaptivePyramidQuantB) || IsOn(m_EncToolConfig.AdaptivePyramidQuantP))
+        if (IsOn(m_EncToolConfig.AdaptivePyramidQuantB) || IsOn(m_EncToolConfig.AdaptivePyramidQuantP)) {
             task.GopHints.QPModulaton = (mfxU8)preEncodeGOP.QPModulation;
+            //task.GopHints.QPModulaton = MFX_QP_MODULATION_EXPLICIT;
+            //task.GopHints.QPDeltaExplicitModulation = (mfxI8)preEncodeGOP.QPDeltaExplicitModulation;
+        }
 
         if (isLABRC)
         {
@@ -1158,6 +1216,36 @@ mfxStatus AV1EncTools::QueryPreEncTask(StorageW&  /*global*/, StorageW& s_task)
             task.BrcHints.LaCurEncodedBits = bufHint.CurEncodedSizeInBits;
             task.BrcHints.LaDistToNextI = bufHint.DistToNextI;
         }
+
+
+        if (IsOn(m_EncToolConfig.AdaptiveLTR))
+        {
+            InitExtBufHeader_AV1(task.InternalListCtrl);
+            task.InternalListCtrlPresent = true;
+            if (aRef.CurrFrameType == MFX_REF_FRAME_TYPE_LTR)
+            {
+                task.InternalListCtrl.LongTermRefList[0].FrameOrder = task.DisplayOrder;
+                task.InternalListCtrl.LongTermRefList[0].PicStruct = MFX_PICSTRUCT_PROGRESSIVE;
+            }
+
+            for (mfxU32 i = (aRef.CurrFrameType == MFX_REF_FRAME_TYPE_LTR) ? 1 : 0; i < std::min(aRef.LongTermRefListSize, (mfxU16)16); i++)
+            {
+                task.InternalListCtrl.LongTermRefList[i].FrameOrder = aRef.LongTermRefList[i];
+                task.InternalListCtrl.LongTermRefList[i].PicStruct = MFX_PICSTRUCT_PROGRESSIVE;
+            }
+
+            for (mfxU32 i = 0; i < std::min(aRef.PreferredRefListSize, (mfxU16)32); i++)
+            {
+                task.InternalListCtrl.PreferredRefList[i].FrameOrder = aRef.PreferredRefList[i];
+                task.InternalListCtrl.PreferredRefList[i].PicStruct = MFX_PICSTRUCT_PROGRESSIVE;
+            }
+
+            for (mfxU32 i = 0; i < std::min(aRef.RejectedRefListSize, (mfxU16)16); i++)
+            {
+                task.InternalListCtrl.RejectedRefList[i].FrameOrder = aRef.RejectedRefList[i];
+                task.InternalListCtrl.RejectedRefList[i].PicStruct = MFX_PICSTRUCT_PROGRESSIVE;
+            }
+        }
      }
     return sts;
 }
@@ -1212,7 +1300,7 @@ void AV1EncTools::AllocSegmentationData(mfxU16 frame_width, mfxU16 frame_height,
     m_SegmentationInfo.NumSegmentIdAlloc = numSegBlksInWidth * numSegBlksIHeight;
     m_SegmentationInfo.SegmentIdBlockSize = blockSize;
     m_SegmentationInfo.NumSegments = 8;   //enctools needs all 8 segments
-    
+
     m_pSegmentQPMap = new mfxU8[m_SegmentationInfo.NumSegmentIdAlloc];
     m_pSegmentIDMap = new mfxU8[m_SegmentationInfo.NumSegmentIdAlloc];
 }
@@ -1463,7 +1551,7 @@ void AV1EncTools::SubmitTask(const FeatureBlocks& /*blocks*/, TPushST Push)
         // Report BRC results to encoder
         auto&      task = Task::Common::Get(s_task);
         task.QpY = (mfxU8)quantCtrl.QpY;
-        
+
         auto&      fh = Task::FH::Get(s_task);
         fh.quantization_params.base_q_idx = task.QpY;
 
