@@ -1,4 +1,4 @@
-// Copyright (c) 2019-2020 Intel Corporation
+// Copyright (c) 2019-2023 Intel Corporation
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -61,7 +61,10 @@ protected:
     virtual void QueryTask(const FeatureBlocks& blocks, TPushQT Push) override = 0;
     virtual void ResetState(const FeatureBlocks& blocks, TPushRS Push) override = 0;
 
-    virtual mfxStatus SetDDIID(const mfxU16 bitDepth, const mfxU16 chromFormat) = 0;
+    virtual mfxStatus SetDDIID(const mfxU16 bitDepth
+        , const mfxU16 chromFormat
+        , const mfxU32 fourCC
+        , const mfxU16 targetChromaForamt) = 0;
 };
 
 } //Base
