@@ -1,4 +1,4 @@
-// Copyright (c) 2019-2022 Intel Corporation
+// Copyright (c) 2019-2023 Intel Corporation
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,11 +25,11 @@
 #include "av1ehw_base_task.h"
 #include <numeric>
 
-using namespace AV1EHW::Base;
-
 namespace AV1EHW
 {
 
+    namespace Base
+    {
 BitstreamWriter::BitstreamWriter(mfxU8* bs, mfxU32 size, mfxU8 bitOffset)
     : m_bsStart(bs)
     , m_bsEnd(bs + size)
@@ -273,45 +273,6 @@ void Packer::PackOBUHeader(BitstreamWriter& bs, AV1_OBU_TYPE obu_type, mfxU32 ob
     }
 }
 
-// leb128 - [in] Leb128Data to hold encoded data
-// value - [in] integer value to encoded as leb128
-// fixed_output_len - [optional in] fixed len for the output, WA for driver part (value = len, 0 - not used)
-// return - N/A
-inline void EncodeLeb128(Leb128Data& leb128, uint64_t value, const mfxU8 fixed_output_len = 0) {
-    mfxU8 *buf = reinterpret_cast<mfxU8 *>(&(leb128.buf));
-    mfxU8 &cnt = leb128.size;
-
-    cnt = 0;
-    if (!fixed_output_len)
-    {
-        // general encoding
-        do {
-            buf[cnt] = value & 0x7fU;
-            if (value >>= 7)
-            {
-                buf[cnt] |= 0x80U;
-            }
-            cnt++;
-        } while (value);
-    }
-    else
-    {
-        // WA to get fixed len of output
-        mfxU8 value_byte_count = 0;
-        do {
-            buf[value_byte_count++] = value & 0x7fU;
-            value >>= 7;
-        } while (value);
-
-        for (int i = 0; i < fixed_output_len - 1; i++)
-        {
-            buf[i] |= 0x80U;
-            cnt++;
-        }
-        cnt++;
-    }
-}
-
 void Packer::PackOBUHeaderSize(BitstreamWriter& bs, mfxU32 const obu_size_in_bytes, mfxU8 const fixed_output_len)
 {
     Leb128Data leb128 = {};
@@ -430,8 +391,8 @@ void Packer::PackSPS(BitstreamWriter& bs, SH const& sh, FH const& fh, ObuExtensi
 
     tmpBitstream.PutTrailingBits();
 
-    const mfxU32 obu_extension_flag = sh.operating_points_cnt_minus_1 ? 1 : 0;
-    PackOBUHeader(bs, OBU_SEQUENCE_HEADER, obu_extension_flag, oeh);
+    const bool ext = oeh.temporal_id | oeh.spatial_id;
+    PackOBUHeader(bs, OBU_SEQUENCE_HEADER, ext, oeh);
 
     mfxU32 const obu_size_in_bytes = (tmpBitstream.GetOffset() + 7) / 8;
     PackOBUHeaderSize(bs, obu_size_in_bytes);
@@ -486,12 +447,12 @@ inline void PackShowFrame(BitstreamWriter& bs, FH const& fh)
         bs.PutBit(fh.showable_frame); //showable_frame
 }
 
-inline void PackErrorResilientMode(BitstreamWriter& bs, FH const& fh, mfxU8 error_resilient_mode)
+inline void PackErrorResilientMode(BitstreamWriter& bs, FH const& fh)
 {
     if (fh.frame_type == SWITCH_FRAME || (fh.frame_type == KEY_FRAME && fh.show_frame))
-        error_resilient_mode = 1;
+        return;
     else
-        bs.PutBit(0); //error_resilient_mode
+        bs.PutBit(fh.error_resilient_mode); //error_resilient_mode
 }
 
 inline void PackOrderHint(BitstreamWriter& bs, SH const& sh, FH const& fh)
@@ -502,14 +463,11 @@ inline void PackOrderHint(BitstreamWriter& bs, SH const& sh, FH const& fh)
     bs.PutBits(sh.order_hint_bits_minus1 + 1, fh.order_hint); //order_hint
 }
 
-inline void PackRefFrameFlags(BitstreamWriter& bs, FH const& fh, mfxU8 const error_resilient_mode)
+inline void PackRefFrameFlags(BitstreamWriter& bs, FH const& fh)
 {
     const mfxU8 frameIsIntra = FrameIsIntra(fh);
 
-    mfxU8 primary_ref_frame = PRIMARY_REF_NONE;
-    if (frameIsIntra || error_resilient_mode)
-        primary_ref_frame = PRIMARY_REF_NONE;
-    else
+    if (!(frameIsIntra || fh.error_resilient_mode))
         bs.PutBits(3, 0); //primary_ref_frame
 
     if (!(fh.frame_type == SWITCH_FRAME || (fh.frame_type == KEY_FRAME && fh.show_frame)))
@@ -588,7 +546,7 @@ inline void PackFrameSizeWithRefs(
     }
 }
 
-static void PackFrameRefInfo(BitstreamWriter& bs, SH const& sh, FH const& fh, mfxU8 const error_resilient_mode)
+static void PackFrameRefInfo(BitstreamWriter& bs, SH const& sh, FH const& fh)
 {
     if (sh.enable_order_hint)
         bs.PutBit(0); //frame_refs_short_signaling
@@ -596,7 +554,7 @@ static void PackFrameRefInfo(BitstreamWriter& bs, SH const& sh, FH const& fh, mf
     for (mfxU8 ref = 0; ref < REFS_PER_FRAME; ref++)
         bs.PutBits(REF_FRAMES_LOG2, fh.ref_frame_idx[ref]);
 
-    if (fh.frame_size_override_flag && !error_resilient_mode)
+    if (fh.frame_size_override_flag && !fh.error_resilient_mode)
     {
         PackFrameSizeWithRefs(bs, sh, fh);
     }
@@ -616,6 +574,18 @@ static void PackFrameRefInfo(BitstreamWriter& bs, SH const& sh, FH const& fh, mf
         bs.PutBit(1); //use_ref_frame_mvs
 }
 
+static void PackRefOrderHint(BitstreamWriter& bs, SH const& sh, FH const& fh)
+{
+    if(fh.error_resilient_mode && sh.enable_order_hint)
+    {
+        for (mfxU8 ref = 0; ref < NUM_REF_FRAMES; ref++)
+        {
+            bs.PutBits(sh.order_hint_bits_minus1 + 1, fh.ref_order_hint[ref]); //ref_order_hint[i]
+        }
+
+    }
+}
+
 inline void PackUniformTile(BitstreamWriter& bs, TileInfoAv1 const& tileInfo)
 {
     assert(tileInfo.TileColsLog2 >= tileInfo.tileLimits.MinLog2TileCols);
@@ -905,8 +875,7 @@ inline void PackFrameHeader(
 
     PackShowFrame(bs, fh);
 
-    mfxU8 error_resilient_mode = 0;
-    PackErrorResilientMode(bs, fh, error_resilient_mode);
+    PackErrorResilientMode(bs, fh);
 
     bs.PutBit(fh.disable_cdf_update);
     bs.PutBit(fh.allow_screen_content_tools);
@@ -914,10 +883,14 @@ inline void PackFrameHeader(
 
     PackOrderHint(bs, sh, fh);
 
-    PackRefFrameFlags(bs, fh, error_resilient_mode);
+    PackRefFrameFlags(bs, fh);
+
+    const int allFrames = (1 << NUM_REF_FRAMES) - 1;
+    if(!frameIsIntra || fh.refresh_frame_flags != allFrames)
+        PackRefOrderHint(bs, sh, fh);
 
     if (!frameIsIntra)
-        PackFrameRefInfo(bs, sh, fh, error_resilient_mode);
+        PackFrameRefInfo(bs, sh, fh);
     else
     {
         PackFrameSize(bs, sh, fh);
@@ -987,22 +960,26 @@ void Packer::PackPPS(
     else
         PackFrameHeader(tmpBitstream, tmp_offsets, sh, fh);
 
-    const mfxU32 obu_extension_flag = sh.operating_points_cnt_minus_1 ? 1 : 0;
+    const bool obu_extension_flag = oeh.temporal_id | oeh.spatial_id;
     const mfxU32 obu_header_offset  = bs.GetOffset();
     if (insertHeaders & INSERT_FRM_OBU)
     {
-        tmp_offsets.FrameHdrOBUSizeInBits = tmpBitstream.GetOffset();
+        tmp_offsets.FrameHeaderOBUSizeInBits = tmpBitstream.GetOffset();
         tmpBitstream.PutAlignmentBits();
         PackOBUHeader(bs, OBU_FRAME, obu_extension_flag, oeh);
     }
     else
     {
-        tmp_offsets.FrameHdrOBUSizeInBits = tmpBitstream.GetOffset() + 1;  // trailing 1 bit is included
+        tmp_offsets.FrameHeaderOBUSizeInBits = tmpBitstream.GetOffset() + 1;  // trailing 1 bit is included
         tmpBitstream.PutTrailingBits(); //Trailing bit
         PackOBUHeader(bs, OBU_FRAME_HEADER, obu_extension_flag, oeh);
     }
 
-    offsets.FrameHdrOBUSizeByteOffset = (bs.GetOffset() >> 3);
+    offsets.FrameHeaderOBUSizeByteOffset = (bs.GetOffset() >> 3);
+    if (insertHeaders & INSERT_HDR)
+    {
+        offsets.FrameHeaderOBUSizeByteOffset += offsets.HDRHeaderByteOffset;
+    }
 
     const mfxU32 obu_size_in_bytes = (tmpBitstream.GetOffset() + 7) / 8;
     PackOBUHeaderSize(bs, obu_size_in_bytes, fh.show_existing_frame? 0: 4);
@@ -1016,7 +993,7 @@ void Packer::PackPPS(
         offsets.LoopFilterParamsBitOffset = obuPayloadOffset + tmp_offsets.LoopFilterParamsBitOffset;
         offsets.CDEFParamsBitOffset       = obuPayloadOffset + tmp_offsets.CDEFParamsBitOffset;
         offsets.CDEFParamsSizeInBits      = tmp_offsets.CDEFParamsSizeInBits;
-        offsets.FrameHdrOBUSizeInBits     = obuPayloadOffset + tmp_offsets.FrameHdrOBUSizeInBits;
+        offsets.FrameHeaderOBUSizeInBits  = obuPayloadOffset + tmp_offsets.FrameHeaderOBUSizeInBits;
     }
 
     bs.PutBitsBuffer(tmpBitstream.GetOffset(), tmpBitstream.GetStart());
@@ -1090,7 +1067,7 @@ void Packer::SubmitTask(const FeatureBlocks& blocks, TPushST Push)
         headerOffset = bitstream.GetOffset();
         if (task.InsertHeaders & INSERT_TD)
         {
-            mfxU32 ext   = sh.operating_points_cnt_minus_1 ? 1 : 0;
+            const bool ext = oeh.temporal_id | oeh.spatial_id;
             PackOBUHeader(bitstream, OBU_TEMPORAL_DELIMITER, ext, oeh);
             PackOBUHeaderSize(bitstream, 0);
         }
@@ -1118,28 +1095,43 @@ void Packer::SubmitTask(const FeatureBlocks& blocks, TPushST Push)
     });
 }
 
-inline void Packer::GenerateSPS(mfxVideoParam& out, const StorageR& global)
+inline mfxStatus Packer::GenerateSPS(mfxVideoParam& out, const StorageR& global)
 {
     mfxExtCodingOptionSPSPPS* dst = ExtBuffer::Get(out);
-    if (dst && dst->SPSBuffer)
+    MFX_CHECK(dst, MFX_ERR_NONE);
+
+    dst->PPSBufSize = 0;
+
+    if (dst->SPSBuffer)
     {
-        BitstreamWriter bs(dst->SPSBuffer, dst->SPSBufSize);
+        const mfxU16 tmpSize = 128;
+        std::vector<mfxU8> tmpBuf(tmpSize);
+        BitstreamWriter bs(tmpBuf.data(), tmpSize);
 
         const SH& sh = Glob::SH::Get(global);
         const FH& fh = Glob::FH::Get(global);
         ObuExtensionHeader oeh = {0};
 
         PackSPS(bs, sh, fh, oeh);
-        dst->SPSBufSize = mfxU16((bs.GetOffset() + 7) / 8);
+        const mfxU16 spsBufSize = mfxU16((bs.GetOffset() + 7) / 8);
+
+        // Only thrown status could be returned from GetVideoParam() which ignores return value
+        // (Check MFXVideoENCODEAV1_HW::GetVideoParam in av1ehw_base_impl.cpp)
+        ThrowIf(dst->SPSBufSize < spsBufSize, MFX_ERR_NOT_ENOUGH_BUFFER);
+
+        std::copy_n(tmpBuf.begin(), spsBufSize, dst->SPSBuffer);
+        dst->SPSBufSize = spsBufSize;
     }
+
+    return MFX_ERR_NONE;
 }
 
 void Packer::GetVideoParam(const FeatureBlocks& blocks, TPushGVP Push)
 {
     Push(BLK_GenerateSPS
-        , [this, &blocks](mfxVideoParam& out, StorageR& global) -> void
+        , [this, &blocks](mfxVideoParam& out, StorageR& global) -> mfxStatus
     {
-        GenerateSPS(out, global);
+        return GenerateSPS(out, global);
     });
 }
 
@@ -1203,7 +1195,7 @@ void Packer::PostReorderTask(const FeatureBlocks& blocks, TPushPostRT Push)
             if (IsOn(auxPar.InsertTemporalDelimiter))
             {
                 // Add temporal delimiter for shown frame
-                mfxU32 ext = sh.operating_points_cnt_minus_1 ? 1 : 0;
+                const bool ext = oeh.temporal_id | oeh.spatial_id;
                 PackOBUHeader(bitstream, OBU_TEMPORAL_DELIMITER, ext, oeh);
                 PackOBUHeaderSize(bitstream, 0);
             }
@@ -1248,4 +1240,6 @@ void Packer::QueryTask(const FeatureBlocks&, TPushQT Push)
 
 }
 
+}
+
 #endif //defined(MFX_ENABLE_AV1_VIDEO_ENCODE)
