@@ -1,4 +1,4 @@
-// Copyright (c) 2019-2020 Intel Corporation
+// Copyright (c) 2019-2023 Intel Corporation
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -36,6 +36,45 @@ namespace Base
         mfxU8  size;
     };
 
+    // leb128 - [in] Leb128Data to hold encoded data
+    // value - [in] integer value to encoded as leb128
+    // fixed_output_len - [optional in] fixed len for the output, WA for driver part (value = len, 0 - not used)
+    // return - N/A
+    inline void EncodeLeb128(Leb128Data& leb128, uint64_t value, const mfxU8 fixed_output_len = 0) {
+        mfxU8* buf = reinterpret_cast<mfxU8*>(&(leb128.buf));
+        mfxU8& cnt = leb128.size;
+
+        cnt = 0;
+        if (!fixed_output_len)
+        {
+            // general encoding
+            do {
+                buf[cnt] = value & 0x7fU;
+                if (value >>= 7)
+                {
+                    buf[cnt] |= 0x80U;
+                }
+                cnt++;
+            } while (value);
+        }
+        else
+        {
+            // WA to get fixed len of output
+            mfxU8 value_byte_count = 0;
+            do {
+                buf[value_byte_count++] = value & 0x7fU;
+                value >>= 7;
+            } while (value);
+
+            for (int i = 0; i < fixed_output_len - 1; i++)
+            {
+                buf[i] |= 0x80U;
+                cnt++;
+            }
+            cnt++;
+        }
+    }
+
     class BitstreamWriter
         : public IBsWriter
     {
@@ -130,13 +169,13 @@ namespace Base
         virtual void QueryTask(const FeatureBlocks& blocks, TPushQT Push) override;
         virtual void GetVideoParam(const FeatureBlocks& blocks, TPushGVP Push) override;
 
-        void PackIVF          (BitstreamWriter& bs, const FH& fh, mfxU32 insertHeaders, const mfxVideoParam& vp);
-        void PackOBUHeader    (BitstreamWriter& bs, AV1_OBU_TYPE obu_type, mfxU32 obu_extension_flag, const ObuExtensionHeader& oeh);
-        void PackOBUHeaderSize(BitstreamWriter& bs, const mfxU32 obu_size_in_bytes, const mfxU8 fixed_output_len = 0);
-        void PackSPS          (BitstreamWriter& bs, const SH& sh, const FH& fh, const ObuExtensionHeader& oeh);
-        void PackPPS          (BitstreamWriter& bs, BitOffsets& offsets, const SH& sh, const FH& fh, const ObuExtensionHeader& oeh, mfxU32 insertHeaders);
-        void GenerateSPS      (mfxVideoParam& out,  const StorageR& global);
+        void      PackIVF(BitstreamWriter& bs, const FH& fh, mfxU32 insertHeaders, const mfxVideoParam& vp);
+        void      PackSPS(BitstreamWriter& bs, const SH& sh, const FH& fh, const ObuExtensionHeader& oeh);
+        void      PackPPS(BitstreamWriter& bs, BitOffsets& offsets, const SH& sh, const FH& fh, const ObuExtensionHeader& oeh, mfxU32 insertHeaders);
+        mfxStatus GenerateSPS(mfxVideoParam& out,  const StorageR& global);
 
+        static void PackOBUHeader(BitstreamWriter& bs, AV1_OBU_TYPE obu_type, mfxU32 obu_extension_flag, const ObuExtensionHeader& oeh);
+        static void PackOBUHeaderSize(BitstreamWriter& bs, const mfxU32 obu_size_in_bytes, const mfxU8 fixed_output_len = 0);
         static bool PutBit (BitstreamWriter& bs, mfxU32 b) { bs.PutBit(!!b); return true; };
         static bool PutBits(BitstreamWriter& bs, mfxU32 n, mfxU32 b) { if (n) bs.PutBits(n, b); return !!n; };
     };
