@@ -189,6 +189,16 @@ void TaskManager::SetRecode(StorageW& task, bool bRecode) const
     Task::Common::Get(task).bRecode = bRecode;
 }
 
+bool TaskManager::GetFreed(const StorageR& task) const
+{
+    return Task::Common::Get(task).bFreed;
+}
+
+void TaskManager::SetFreed(StorageW& task, bool bFreed) const
+{
+    Task::Common::Get(task).bFreed = bFreed;
+}
+
 mfxU32 TaskManager::GetBsDataLength(const StorageR& task) const
 {
     return Task::Common::Get(task).BsDataLength;
@@ -204,14 +214,14 @@ void TaskManager::AddNumRecode(StorageW& task, mfxU16 n) const
     Task::Common::Get(task).NumRecode += n;
 }
 
-bool TaskManager::IsCachedTask(StorageW& task) const
+bool TaskManager::IsCached(StorageW& task) const
 {
-    return Task::Common::Get(task).bCachedTask;
+    return Task::Common::Get(task).bCached;
 }
 
-void TaskManager::SetCachedTask(StorageW& task, bool val) const
+void TaskManager::SetCached(StorageW& task, bool bCached) const
 {
-    Task::Common::Get(task).bCachedTask = val;
+    Task::Common::Get(task).bCached = bCached;
 }
 
 void TaskManager::ClearBRCUpdateFlag(StorageW& task) const
