@@ -26,11 +26,12 @@
 #include <algorithm>
 #include <numeric>
 
-using namespace AV1EHW::Base;
-
 namespace AV1EHW
 {
 
+namespace Base
+{
+
 inline bool IsValidTilesSize(
     const mfxU16 sbNum
     , const mfxU16 TileNum
@@ -209,7 +210,7 @@ inline mfxU16 GetMinTileCols(const mfxU16 sbCols)
     return  mfx::CeilDiv(sbCols, mfxU16(AV1_MAX_TILE_WIDTH_SB));
 }
 
-inline mfxU16 GetMaxTileCols(const mfxU16 sbCols)
+inline mfxU16 GetMaxNumTileCols(const mfxU16 sbCols)
 {
     return std::min(sbCols, mfxU16(AV1_MAX_NUM_TILE_COLS));
 }
@@ -375,7 +376,7 @@ mfxStatus CheckAndFixBuffers(
     }
 
     // Check number of tile columns
-    const mfxU16 maxTileCols = std::min(GetMaxTileCols(sbCols), maxTileColsByLevel);
+    const mfxU16 maxTileCols = std::min(GetMaxNumTileCols(sbCols), maxTileColsByLevel);
     const mfxU16 minTileCols = GetMinTileCols(sbCols);
     changed += CheckRangeOrClip(tilePar.NumTileColumns, minTileCols, maxTileCols);
 
@@ -750,6 +751,8 @@ void Tile::ResetState(const FeatureBlocks& blocks, TPushRS Push)
     });
 }
 
+}
+
 } //namespace AV1EHW
 
-#endif //defined(MFX_ENABLE_AV1_VIDEO_ENCODE)
+#endif //defined(MFX_ENABLE_AV1_VIDEO_ENCODE)
\ No newline at end of file
