@@ -26,30 +26,12 @@
 #include "av1ehw_ddi.h"
 #include "av1ehw_base_va_lin.h"
 #include "av1ehw_base_va_packer_lin.h"
+#include "av1ehw_struct_vaapi.h"
 
 using namespace AV1EHW;
 using namespace AV1EHW::Base;
 using namespace AV1EHW::Linux::Base;
 
-void VAPacker::Query1WithCaps(const FeatureBlocks&/*blocks*/, TPushQ1 Push)
-{
-    Push(BLK_HardcodeCaps
-        , [this](const mfxVideoParam&, mfxVideoParam&, StorageRW& strg) -> mfxStatus
-    {
-        eMFXHWType hw = Glob::VideoCore::Get(strg).GetHWType();
-        auto& caps    = Glob::EncodeCaps::Get(strg);
-
-        caps.msdk.CQPSupport = true;
-        caps.msdk.CBRSupport = true;
-        caps.msdk.VBRSupport = true;
-        caps.msdk.ICQSupport = true;
-
-        m_hwType = hw;
-
-        return MFX_ERR_NONE;
-    });
-}
-
 void InitSPS(
     const ExtBuffer::Param<mfxVideoParam>& par
     , const SH& bs_sh
@@ -346,7 +328,10 @@ static void InitSegMap(
 {
     const mfxExtAV1Segmentation& segPar = ExtBuffer::Get(par);
     if (segPar.NumSegments == 0)
+    {
+        segment_map.clear();
         return;
+    }
 
     InitSegMap(segPar, segment_map);
 }
@@ -442,8 +427,8 @@ void UpdatePPS(
 
     //offsets
     auto& offsets = task.Offsets;
-    pps.size_in_bits_frame_hdr_obu     = offsets.FrameHdrOBUSizeInBits;
-    pps.byte_offset_frame_hdr_obu_size = offsets.FrameHdrOBUSizeByteOffset;
+    pps.size_in_bits_frame_hdr_obu     = offsets.FrameHeaderOBUSizeInBits;
+    pps.byte_offset_frame_hdr_obu_size = offsets.FrameHeaderOBUSizeByteOffset;
     pps.bit_offset_loopfilter_params   = offsets.LoopFilterParamsBitOffset;
     pps.bit_offset_qindex              = offsets.QIndexBitOffset;
     pps.bit_offset_segmentation        = offsets.SegmentationBitOffset;
@@ -500,6 +485,7 @@ inline void AddVaMiscFR(
 inline void AddVaMiscRC(
     const Glob::VideoParam::TRef& par
     , const Glob::FH::TRef& bs_fh
+    , const Task::Common::TRef& task
     , std::list<std::vector<mfxU8>>& buf
     , bool bResetBRC = false)
 {
@@ -525,6 +511,18 @@ inline void AddVaMiscRC(
         rc.rc_flags.bits.mb_rate_control = IsOn(CO2->MBBRC) +IsOff(CO2->MBBRC) * 2;
     }
 
+    // TCBRC control
+#if VA_CHECK_VERSION(1, 10, 0)
+    rc.target_frame_size = task.TCBRCTargetFrameSize;
+#endif
+
+    const mfxExtCodingOption3* CO3 = ExtBuffer::Get(par);
+    if (CO3)
+    {
+        rc.rc_flags.bits.frame_tolerance_mode =
+            IsOn(CO3->LowDelayBRC) ? eFrameSizeTolerance_ExtremelyLow : eFrameSizeTolerance_Normal;
+    }
+
     rc.ICQ_quality_factor = 0;
     rc.initial_qp         = bs_fh.quantization_params.base_q_idx;
 }
@@ -616,13 +614,17 @@ void VAPacker::InitAlloc(const FeatureBlocks& /*blocks*/, TPushIA Push)
             AddVaMiscTemporalLayer(par, data);
             return true;
         });
-        cc.AddPerSeqMiscData[VAEncMiscParameterTypeRateControl].Push([this, &par, &bs_fh](
+        cc.AddPerPicMiscData[VAEncMiscParameterTypeRateControl].Push([this](
             VAPacker::CallChains::TAddMiscData::TExt
             , const StorageR& strg
-            , const StorageR& local
+            , const StorageR& s_task
             , std::list<std::vector<mfxU8>>& data)
         {
-            AddVaMiscRC(par, bs_fh, data);
+            const auto& par   = Glob::VideoParam::Get(strg);
+            const auto& bs_fh = Glob::FH::Get(strg);
+            const auto& task  = Task::Common::Get(s_task);
+
+            AddVaMiscRC(par, bs_fh, task, data);
             return true;
         });
         cc.AddPerSeqMiscData[VAEncMiscParameterTypeFrameRate].Push([this, &par](
@@ -734,13 +736,17 @@ void VAPacker::ResetState(const FeatureBlocks& /*blocks*/, TPushRS Push)
             AddVaMiscTemporalLayer(par, data);
             return true;
         });
-        cc.AddPerSeqMiscData[VAEncMiscParameterTypeRateControl].Push([this, &par, &bs_fh](
+        cc.AddPerPicMiscData[VAEncMiscParameterTypeRateControl].Push([this](
             VAPacker::CallChains::TAddMiscData::TExt
             , const StorageR& strg
-            , const StorageR& local
+            , const StorageR& s_task
             , std::list<std::vector<mfxU8>>& data)
         {
-            AddVaMiscRC(par, bs_fh, data, !!(Glob::ResetHint::Get(strg).Flags & RF_BRC_RESET));
+            const auto& par   = Glob::VideoParam::Get(strg);
+            const auto& bs_fh = Glob::FH::Get(strg);
+            const auto& task  = Task::Common::Get(s_task);
+
+            AddVaMiscRC(par, bs_fh, task, data, !!(Glob::ResetHint::Get(strg).Flags & RF_BRC_RESET));
             return true;
         });
         cc.AddPerSeqMiscData[VAEncMiscParameterTypeFrameRate].Push([this, &par](
@@ -846,6 +852,15 @@ void VAPacker::SubmitTask(const FeatureBlocks& blocks, TPushST Push)
         AddPackedHeaderIf(!!(task.InsertHeaders & INSERT_PPS)
             , ph.PPS, par, VAEncPackedHeaderAV1_PPS);
 
+        for (auto& AddMisc : cc.AddPerPicMiscData)
+        {
+            if (AddMisc.second(global, s_task, m_vaPerPicMiscData))
+            {
+                auto& misc = m_vaPerPicMiscData.back();
+                par.push_back(PackVaBuffer(VAEncMiscParameterBufferType, misc.data(), (mfxU32)misc.size()));
+            }
+        }
+
         SetFeedback(task.StatusReportId, *(VASurfaceID*)task.HDLRaw.first, GetResources(RES_BS).at(task.BS.Idx));
 
         return MFX_ERR_NONE;
