@@ -49,6 +49,10 @@
 #include "ipps.h"
 #include "mfx_enc_common.h"
 
+#ifdef MFX_ENABLE_ENCODE_STATS
+#include "mfxencodestats.h"
+#endif
+
 #define D3DFMT_NV12 (D3DFORMAT)(MFX_MAKEFOURCC('N', 'V', '1', '2'))
 #define D3DDDIFMT_NV12 (D3DDDIFORMAT)(MFX_MAKEFOURCC('N', 'V', '1', '2'))
 #define D3DDDIFMT_YU12 (D3DDDIFORMAT)(MFX_MAKEFOURCC('Y', 'U', '1', '2'))
@@ -211,6 +215,7 @@ namespace MfxHwH264Encode
 #if defined (MFX_ENABLE_PARTIAL_BITSTREAM_OUTPUT)
     BIND_EXTBUF_TYPE_TO_ID(mfxExtPartialBitstreamParam,  MFX_EXTBUFF_PARTIAL_BITSTREAM_PARAM );
 #endif
+    BIND_EXTBUF_TYPE_TO_ID(mfxExtVPPDenoise2,           MFX_EXTBUFF_VPP_DENOISE2);
 #if defined (MFX_ENABLE_ENCTOOLS)
     BIND_EXTBUF_TYPE_TO_ID(mfxEncTools, MFX_EXTBUFF_ENCTOOLS);
     BIND_EXTBUF_TYPE_TO_ID(mfxEncToolsBRCFrameParams, MFX_EXTBUFF_ENCTOOLS_BRC_FRAME_PARAM);
@@ -230,6 +235,10 @@ namespace MfxHwH264Encode
 #endif
 
 
+#ifdef MFX_ENABLE_ENCODE_STATS
+    BIND_EXTBUF_TYPE_TO_ID(mfxExtEncodeStatsOutput, MFX_EXTBUFF_ENCODESTATS);
+#endif
+
 #undef BIND_EXTBUF_TYPE_TO_ID
 
     template <class T> inline void InitExtBufHeader(T & extBuf)
@@ -608,9 +617,9 @@ namespace MfxHwH264Encode
 
     private:
 #if defined(MFX_ENABLE_ENCTOOLS)
-        mfxExtBuffer *              m_extParam[40];
+        mfxExtBuffer *              m_extParam[41];
 #else
-        mfxExtBuffer *              m_extParam[35];
+        mfxExtBuffer *              m_extParam[36];
 #endif
         // external, documented
         mfxExtCodingOption          m_extOpt;
@@ -647,6 +656,7 @@ namespace MfxHwH264Encode
         mfxEncToolsCtrlExtDevice        m_extDevice;
         mfxEncToolsCtrlExtAllocator     m_extAllocator;
 #endif
+        mfxExtVPPDenoise2               m_extVppHVS;
 
 #if defined(MFX_ENABLE_ENCTOOLS_LPLA)
         mfxExtLplaParam            m_extLowpowerLA;
@@ -741,7 +751,7 @@ namespace MfxHwH264Encode
 
     mfxU8 GetCabacInitIdc(mfxU32 targetUsage);
 
-    bool IsMctfSupported(
+    bool IsDenoiserSupported(
         MfxVideoParam const & video,
         eMFXHWType            platform);
 
