@@ -242,7 +242,7 @@ inline bool IsEncToolsImplicit(const mfxVideoParam &video)
 bool isSWLACondition(const mfxVideoParam& video)
 {
     const mfxExtCodingOption2* pExtOpt2 = ExtBuffer::Get(video);
-    return (pExtOpt2 && 
+    return (pExtOpt2 &&
         (pExtOpt2->LookAheadDepth > video.mfx.GopRefDist));
 }
 
@@ -562,6 +562,8 @@ static  bool isEncTools(const mfxVideoParam& par)
 
     return bEncTools;
 }
+
+
 void HevcEncTools::Query1NoCaps(const FeatureBlocks& blocks, TPushQ1 Push)
 {
     Push(BLK_SetDefaultsCallChain,
@@ -589,8 +591,9 @@ void HevcEncTools::Query1NoCaps(const FeatureBlocks& blocks, TPushQ1 Push)
             return MFX_ERR_NONE;
         });
     Push(BLK_Check,
-        [&blocks](const mfxVideoParam&, mfxVideoParam& par, StorageW& ) -> mfxStatus
+        [&blocks](const mfxVideoParam&, mfxVideoParam& par, StorageW&) -> mfxStatus
     {
+
         bool bEncTools = isEncTools(par);
         mfxU32 changed = 0;
         MFX_CHECK(bEncTools, MFX_ERR_NONE);
@@ -793,19 +796,31 @@ mfxStatus HevcEncTools::SubmitPreEncTask(StorageW&  /*global*/, StorageW& s_task
     auto&      task = Task::Common::Get(s_task);
     std::vector<mfxExtBuffer*> extParams;
     mfxEncToolsFrameToAnalyze extFrameData = {};
-    if (task.pSurfIn)
+
+    //"m_numPicBuffered > 0" indicates: there are some PreEnc frames buffered for async_depth > 1 case, while not queried
+    if (task.pSurfIn || m_numPicBuffered > 0)
     {
         extFrameData.Header.BufferId = MFX_EXTBUFF_ENCTOOLS_FRAME_TO_ANALYZE;
         extFrameData.Header.BufferSz = sizeof(extFrameData);
         extFrameData.Surface = task.pSurfIn;
         extParams.push_back(&extFrameData.Header);
         task_par.ExtParam = extParams.data();
+
+        if (!task.pSurfIn)
+        {
+            m_numPicBuffered--;
+        }
     }
     task_par.DisplayOrder = task.DisplayOrder;
     task_par.NumExtParam = (mfxU16)extParams.size();
 
     auto sts = m_pEncTools->Submit(m_pEncTools->Context, &task_par);
-    if (sts == MFX_ERR_MORE_DATA) sts = MFX_ERR_NONE;
+    if (sts == MFX_ERR_MORE_DATA)
+    {
+        m_numPicBuffered++; // current PreEnc frame buffered, while not queried
+        sts = MFX_ERR_NONE;
+    }
+
     return (sts);
 }
 
@@ -853,6 +868,7 @@ mfxStatus HevcEncTools::BRCGetCtrl(StorageW& global , StorageW& s_task,
             extPreGop.Header.BufferId = MFX_EXTBUFF_ENCTOOLS_HINT_GOP;
             extPreGop.Header.BufferSz = sizeof(extPreGop);
             extPreGop.QPModulation = (mfxU16)task.GopHints.QPModulaton;
+            extPreGop.QPDeltaExplicitModulation = (mfxI8)task.GopHints.QPDeltaExplicitModulation;
             extPreGop.MiniGopSize = (mfxU16)task.GopHints.MiniGopSize;
             extParams.push_back(&extPreGop.Header);
         }
@@ -1053,8 +1069,15 @@ mfxStatus HevcEncTools::QueryPreEncTask(StorageW&  global, StorageW& s_task)
     else
 #endif
     {
-        if (IsOn(m_EncToolConfig.AdaptivePyramidQuantB) || IsOn(m_EncToolConfig.AdaptivePyramidQuantP))
-            task.GopHints.QPModulaton = (mfxU8)preEncodeGOP.QPModulation;
+        if (IsOn(m_EncToolConfig.AdaptivePyramidQuantB)) {
+            if (preEncodeGOP.MiniGopSize <= 8) {
+                task.GopHints.QPModulaton = MFX_QP_MODULATION_EXPLICIT;
+                task.GopHints.QPDeltaExplicitModulation = (mfxI8)preEncodeGOP.QPDeltaExplicitModulation;
+            }
+            else {
+                task.GopHints.QPModulaton = (mfxU8)preEncodeGOP.QPModulation;
+            }
+        }
 
         if (isLABRC)
         {
@@ -1116,6 +1139,8 @@ void HevcEncTools::InitInternal(const FeatureBlocks& /*blocks*/, TPushII Push)
         auto& caps = Glob::EncodeCaps::Get(strg);
 
         mfxExtEncToolsConfig* pConfig = ExtBuffer::Get(par);
+
+
         bool bEncTools = (pConfig) ?
             IsEncToolsOptOn(*pConfig, IsGameStreaming(par)) :
             false;
@@ -1151,10 +1176,12 @@ void HevcEncTools::InitInternal(const FeatureBlocks& /*blocks*/, TPushII Push)
         auto sts = InitEncToolsCtrl(par, &m_EncToolCtrl);
         MFX_CHECK_STS(sts);
 
+
         m_bEncToolsInner = false;
         if (!(encTools && encTools->Context))
         {
             encTools = MFXVideoENCODE_CreateEncTools(par);
+
             m_bEncToolsInner = !!encTools;
         }
         if (encTools)
@@ -1163,6 +1190,7 @@ void HevcEncTools::InitInternal(const FeatureBlocks& /*blocks*/, TPushII Push)
 
             encTools->GetSupportedConfig(encTools->Context, &supportedConfig, &m_EncToolCtrl);
 
+
             if (CorrectVideoParams(par, supportedConfig))
                 MFX_RETURN(MFX_ERR_INCOMPATIBLE_VIDEO_PARAM);
 
