@@ -273,7 +273,7 @@ void AddVaMiscRC(
         const mfxExtCodingOption3& CO3 = ExtBuffer::Get(par);
         rc.min_qp = task.m_minQP - 6*(CO3.TargetBitDepthLuma - 8);
         if ((rc.min_qp < 0) || (rc.min_qp > 51))
-            rc.min_qp = 1;
+            rc.min_qp = 10;
 
         rc.max_qp = task.m_maxQP - 6*(CO3.TargetBitDepthLuma - 8);
         if ((rc.max_qp < 0) || (rc.max_qp > 51))
@@ -873,6 +873,12 @@ void VAPacker::SubmitTask(const FeatureBlocks& /*blocks*/, TPushST Push)
         par.push_back(PackVaBuffer(VAEncSequenceParameterBufferType, m_sps));
         par.push_back(PackVaBuffer(VAEncPictureParameterBufferType, m_pps));
 
+        if(m_sps.seq_fields.bits.scaling_list_enabled_flag)
+        {
+            m_qm = {};
+            par.push_back(PackVaBuffer(VAQMatrixBufferType, m_qm));
+        }
+
         std::transform(m_slices.begin(), m_slices.end(), std::back_inserter(par)
             , [&](VAEncSliceParameterBufferHEVC& s) { return PackVaBuffer(VAEncSliceParameterBufferType, s); });
 
