@@ -34,15 +34,15 @@ namespace MfxEncodeHW
     public:
         mfxU32  DisplayOrder = 0;
         mfxU32  BsDataLength = 0;
-        std::shared_ptr<mfxU8*> Data;
+        std::shared_ptr<std::vector<mfxU8>> Data;
         bool isHiden = true;
         CachedBitstream(mfxU32 length, mfxU8* pData=nullptr)
         {
-            Data = std::make_shared<mfxU8*>(new mfxU8[length]);
+            Data = std::make_shared<std::vector<mfxU8>>(std::vector<mfxU8>(length));
             BsDataLength = length;
             if (pData != nullptr)
             {
-                std::copy(pData, pData + length, *Data.get());
+                std::copy(pData, pData + length, Data->data());
             }
         }
     };
@@ -76,14 +76,16 @@ namespace MfxEncodeHW
         virtual void          SetBS                (StorageW& /*task*/, mfxBitstream* /*pBS*/) const = 0;
         virtual bool          GetRecode            (const StorageR& /*task*/) const = 0;
         virtual void          SetRecode            (StorageW& /*task*/, bool) const = 0;
+        virtual bool          GetFreed             (const StorageR& /*task*/) const = 0;
+        virtual void          SetFreed             (StorageW& /*task*/, bool) const = 0;
         virtual mfxU32        GetBsDataLength      (const StorageR& /*task*/) const = 0;
         virtual void          SetBsDataLength      (StorageW& /*task*/, mfxU32) const = 0;
         virtual void          AddNumRecode         (StorageW& /*task*/, mfxU16) const = 0;
 
         virtual TTaskIt GetDestToPushQuery(TTaskIt begin, TTaskIt /*end*/, StorageW& /*task*/) { return begin; }
 
-        virtual bool IsCachedTask(StorageW& /*task*/) const { return false; }
-        virtual void SetCachedTask(StorageW& /*task*/, bool) const { }
+        virtual bool IsCached(StorageW& /*task*/) const { return false; }
+        virtual void SetCached(StorageW& /*task*/, bool) const { }
         virtual void ClearBRCUpdateFlag(StorageW& /*task*/) const { }
 
         virtual mfxStatus RunQueueTaskAlloc(StorageRW& /*task*/) = 0;
