@@ -259,8 +259,8 @@ void SetReconInfo(VP9MfxVideoParam const &par, mfxFrameInfo &fi)
     mfxU16 format = opt3.TargetChromaFormatPlus1 - 1;
     mfxU16 depth = opt3.TargetBitDepthLuma;
 
-    fi.Width  = mfx::align2_value(fi.Width,  64);
-    fi.Height = mfx::align2_value(fi.Height, 64);
+    fi.Width  = mfx::align2_value(fi.Width,  8);
+    fi.Height = mfx::align2_value(fi.Height, 8);
 
     if (format == MFX_CHROMAFORMAT_YUV444 && depth == BITDEPTH_10)
     {
@@ -820,7 +820,13 @@ mfxStatus MFXVideoENCODEVP9_HW::ConfigTask(Task &task)
         mfxU8 idxGold = task.m_frameParam.refList[REF_GOLD];
         mfxU8 idxAlt = task.m_frameParam.refList[REF_ALT];
         task.m_pRecRefFrames[REF_LAST] = m_dpb[idxLast];
-        task.m_pRecRefFrames[REF_GOLD] = m_dpb[idxGold] != m_dpb[idxLast] ? m_dpb[idxGold] : 0;
+        if (VP9ECaps::IsDefaultMultiRefUsed(platform)) {
+            bool multiref = m_dpb.size() > 1;
+            task.m_pRecRefFrames[REF_GOLD] = m_dpb[idxGold] != m_dpb[idxLast] || multiref ? m_dpb[idxGold] : 0;
+        }
+        else {
+            task.m_pRecRefFrames[REF_GOLD] = m_dpb[idxGold] != m_dpb[idxLast] ? m_dpb[idxGold] : 0;
+        }
         task.m_pRecRefFrames[REF_ALT] = m_dpb[idxAlt] != m_dpb[idxLast] && m_dpb[idxAlt] != m_dpb[idxGold] ? m_dpb[idxAlt] : 0;
     }
 
