@@ -37,9 +37,18 @@ namespace CommonCaps {
         return platform >= MFX_HW_MTL;
     }
 
-    inline bool HasNativeDX9Support(eMFXHWType platform)
+    inline bool IsVppSkipQuerySupported(eMFXHWType platform, mfxU16 deviceId)
     {
-        return platform < MFX_HW_ADL_S;
+
+        return (!CommonCaps::IsPreSiPlatform(platform, deviceId) || MFX_HW_MTL == platform) &&
+            MFX_HW_MTL >= platform &&
+            MFX_HW_DG2 <= platform;
+    }
+
+    inline bool HasNativeDX9Support(eMFXHWType platform, int deviceId)
+    {
+        // Enable native DX9 for ATSM
+        return platform < MFX_HW_ADL_S || deviceId == 0x56C0 || deviceId == 0x56C1;
     }
 
     inline bool IsVplHW(eMFXHWType hw, mfxU32 deviceId)
@@ -105,6 +114,16 @@ namespace VP9ECaps {
     {
         return (platform >= MFX_HW_DG2);
     }
+
+    inline bool IsTableBasedLfLevelUsed(eMFXHWType platform) 
+    {
+        return (platform >= MFX_HW_MTL);
+    }
+
+    inline bool IsDefaultMultiRefUsed(eMFXHWType platform) 
+    {
+        return (platform >= MFX_HW_MTL);
+    }
 }
 #endif
 
@@ -124,8 +143,7 @@ namespace VppCaps
 
     inline bool IsVideoSignalSupported(eMFXHWType platform)
     {
-        return 
-        platform >= MFX_HW_DG2;
+        return platform >= MFX_HW_ADL_S;
     }
 
     inline bool IsSwFieldProcessingSupported(eMFXHWType platform)
