@@ -29,14 +29,17 @@
 
 mfxStatus MFXVideoCORE_SyncOperation(mfxSession session, mfxSyncPoint syncp, mfxU32 wait)
 {
+    PERF_UTILITY_AUTO(__FUNCTION__, PERF_LEVEL_API);
     mfxStatus mfxRes = MFX_ERR_NONE;
     TRACE_EVENT(MFX_TRACE_API_SYNC_OPERATION_TASK, EVENT_TYPE_START, TR_KEY_MFX_API, make_event_data(FrameIndex, session, syncp, wait));
 
     MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_API, __FUNCTION__);
+    MFX_LTRACE_1(MFX_TRACE_LEVEL_API_PARAMS, "In:  session = ", MFX_TRACE_FORMAT_P, session);
+    MFX_LTRACE_1(MFX_TRACE_LEVEL_API_PARAMS, "In:  syncp = ", MFX_TRACE_FORMAT_P, syncp);
     MFX_CHECK(session, MFX_ERR_INVALID_HANDLE);
     MFX_CHECK(syncp, MFX_ERR_NULL_PTR);
 
-    MFX_LTRACE_I(MFX_TRACE_LEVEL_API, wait);
+    MFX_LTRACE_1(MFX_TRACE_LEVEL_API_PARAMS, "In:  wait = ", MFX_TRACE_FORMAT_D, wait);
 
     try {
         {
