@@ -24,6 +24,7 @@
 mfxStatus MFXQueryIMPL(mfxSession session, mfxIMPL *impl)
 {
     MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_API, __FUNCTION__);
+    MFX_LTRACE_1(MFX_TRACE_LEVEL_API_PARAMS, "In:  session = ", MFX_TRACE_FORMAT_P, session);
     mfxIMPL currentImpl;
 
     // check error(s)
@@ -49,7 +50,7 @@ mfxStatus MFXQueryIMPL(mfxSession session, mfxIMPL *impl)
 
     // save the current implementation type
     *impl = currentImpl;
-
+    MFX_LTRACE_1(MFX_TRACE_LEVEL_API_PARAMS, "Out:  impl = ", MFX_TRACE_FORMAT_D, *impl);
     return MFX_ERR_NONE;
 
 } // mfxStatus MFXQueryIMPL(mfxSession session, mfxIMPL *impl)
@@ -57,6 +58,7 @@ mfxStatus MFXQueryIMPL(mfxSession session, mfxIMPL *impl)
 mfxStatus MFXQueryVersion(mfxSession session, mfxVersion *pVersion)
 {
     MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_API, __FUNCTION__);
+    MFX_LTRACE_1(MFX_TRACE_LEVEL_API_PARAMS, "In:  session = ", MFX_TRACE_FORMAT_P, session);
     if (0 == session)
     {
         return MFX_ERR_INVALID_HANDLE;
@@ -68,6 +70,7 @@ mfxStatus MFXQueryVersion(mfxSession session, mfxVersion *pVersion)
 
     // set the library's version
     *pVersion = session->m_versionToReport;
+    MFX_TRACE_2("Out:  MFX_API version = ", "%d.%d", pVersion->Major, pVersion->Minor);
 
     return MFX_ERR_NONE;
 
