@@ -187,6 +187,7 @@ mfxStatus cBRCParams::Init(mfxVideoParam* par, bool bField)
             HRDConformance = MFX_BRC_HRD_WEAK;
     }
 
+    bufferSizeInBytes  = (k*par->mfx.BufferSizeInKB*1000); // Bitstream size is Buffer size if specified
     if (HRDConformance != MFX_BRC_NO_HRD)
     {
         bufferSizeInBytes  = ((k*par->mfx.BufferSizeInKB*1000) >> (cpb_size_scale + 1)) << (cpb_size_scale + 1);
@@ -205,8 +206,8 @@ mfxStatus cBRCParams::Init(mfxVideoParam* par, bool bField)
 
     chromaFormat = par->mfx.FrameInfo.ChromaFormat == 0 ?  MFX_CHROMAFORMAT_YUV420 : par->mfx.FrameInfo.ChromaFormat ;
     bitDepthLuma = par->mfx.FrameInfo.BitDepthLuma == 0 ?  8 : par->mfx.FrameInfo.BitDepthLuma;
-
-    quantOffset   = 6 * (bitDepthLuma - 8);
+    mfxI32 bitdepthOffset = (6 * (bitDepthLuma - 8));
+    quantOffset = IsOn(par->mfx.LowPower) ? 0 : bitdepthOffset;
 
     inputBitsPerFrame    = targetbps / frameRate;
     maxInputBitsPerFrame = maxbps / frameRate;
@@ -232,21 +233,29 @@ mfxStatus cBRCParams::Init(mfxVideoParam* par, bool bField)
         bPanic = 1;
     }
 
+    mfxI32 minQPI = 1;
+    mfxI32 maxQPI = IsOn(par->mfx.LowPower) ? 51 : (51 + bitdepthOffset);
+    mfxI32 minQPP = 1;
+    mfxI32 maxQPP = IsOn(par->mfx.LowPower) ? 51 : (51 + bitdepthOffset);
+    mfxI32 minQPB = 1;
+    mfxI32 maxQPB = IsOn(par->mfx.LowPower) ? 51 : (51 + bitdepthOffset);
+    mfxI32 minmaxOffset = IsOn(par->mfx.LowPower) ? bitdepthOffset : 0;
+
     if (pExtCO2
-        && pExtCO2->MaxQPI <=51 && pExtCO2->MaxQPI > pExtCO2->MinQPI && pExtCO2->MinQPI >=1
-        && pExtCO2->MaxQPP <=51 && pExtCO2->MaxQPP > pExtCO2->MinQPP && pExtCO2->MinQPP >=1
-        && pExtCO2->MaxQPB <=51 && pExtCO2->MaxQPB > pExtCO2->MinQPB && pExtCO2->MinQPB >=1 )
+        && pExtCO2->MaxQPI <= maxQPI && pExtCO2->MaxQPI > pExtCO2->MinQPI && pExtCO2->MinQPI >= minQPI
+        && pExtCO2->MaxQPP <= maxQPP && pExtCO2->MaxQPP > pExtCO2->MinQPP && pExtCO2->MinQPP >= minQPP
+        && pExtCO2->MaxQPB <= maxQPB && pExtCO2->MaxQPB > pExtCO2->MinQPB && pExtCO2->MinQPB >= minQPB)
     {
-        quantMaxI = pExtCO2->MaxQPI + quantOffset;
-        quantMinI = pExtCO2->MinQPI;
-        quantMaxP = pExtCO2->MaxQPP + quantOffset;
-        quantMinP = pExtCO2->MinQPP;
-        quantMaxB = pExtCO2->MaxQPB + quantOffset;
-        quantMinB = pExtCO2->MinQPB;
+        quantMaxI = pExtCO2->MaxQPI - minmaxOffset;
+        quantMinI = pExtCO2->MinQPI - minmaxOffset;
+        quantMaxP = pExtCO2->MaxQPP - minmaxOffset;
+        quantMinP = pExtCO2->MinQPP - minmaxOffset;
+        quantMaxB = pExtCO2->MaxQPB - minmaxOffset;
+        quantMinB = pExtCO2->MinQPB - minmaxOffset;
     }
     else
     {
-        quantMaxI = quantMaxP = quantMaxB = 51 + quantOffset;
+        quantMaxI = quantMaxP = quantMaxB = maxQPB;
         quantMinI = quantMinP = quantMinB = 1;
     }
 
@@ -259,8 +268,8 @@ mfxStatus cBRCParams::Init(mfxVideoParam* par, bool bField)
         WinBRCSize = pExtCO3->WinBRCSize;
     }
 
-    mRawFrameSizeInBits = GetRawFrameSize(width * height, chromaFormat, bitDepthLuma);
-    mRawFrameSizeInPixs = mRawFrameSizeInBits / bitDepthLuma;
+    mRawFrameSizeInBits = GetRawFrameSize(width * height, chromaFormat, IsOn(par->mfx.LowPower) ? 8 : bitDepthLuma);
+    mRawFrameSizeInPixs = mRawFrameSizeInBits / (IsOn(par->mfx.LowPower) ? 8 : bitDepthLuma);
     iDQp0 = 0;
 
     mNumRefsInGop = (mfxU32)(std::max(1.0, (!bPyr ? (mfxF64)gopPicSize / (mfxF64)gopRefDist : (mfxF64)gopPicSize / 2.0)));
@@ -535,7 +544,7 @@ mfxStatus ExtBRC::Init (mfxVideoParam* par)
     m_ctx.fAbLong  = m_par.inputBitsPerFrame;
     m_ctx.fAbShort = m_par.inputBitsPerFrame;
 
-    mfxI32 rawSize = GetRawFrameSize(m_par.width * m_par.height ,m_par.chromaFormat, m_par.bitDepthLuma);
+    mfxI32 rawSize = GetRawFrameSize(m_par.width * m_par.height ,m_par.chromaFormat, m_par.quantOffset ? m_par.bitDepthLuma : 8);
     mfxI32 qp = GetNewQP(rawSize, m_par.inputBitsPerFrame, m_par.quantMinI, m_par.quantMaxI, 1 , m_par.quantOffset, 0.5, false, false);
 
     UpdateQPParams(qp,MFX_FRAMETYPE_IDR , m_ctx, 0, m_par.quantMinI, m_par.quantMaxI, 0, m_par.iDQp, MFX_FRAMETYPE_REF, 0);
@@ -974,6 +983,12 @@ mfxStatus ExtBRC::Update(mfxBRCFrameParam* frame_par, mfxBRCFrameCtrl* frame_ctr
         e2pe = (m_ctx.eRate == 0) ? (BRC_SCENE_CHANGE_RATIO2 + 1) : eRate / m_ctx.eRate;
     }
     mfxU32 frameSizeLim    = 0xfffffff ; // sliding window limitation or external frame size limitation
+    // HEVC / AV1 do not have external re-encode loop to prevent bitstream copy size violation.
+    // For NO_HRD this will ensure encoded picture fits in bitstream memory.
+    // Bitstsream size is bufferSize if specified.
+    mfxU32 bitstreamSizeLim = frameSizeLim;
+    if(m_par.codecId != MFX_CODEC_AVC && m_par.HRDConformance == MFX_BRC_NO_HRD && m_par.bufferSizeInBytes)
+        bitstreamSizeLim = m_par.bufferSizeInBytes * 8;
 
     bool  bSHStart = false;
     bool  bNeedUpdateQP = false;
@@ -1105,7 +1120,12 @@ mfxStatus ExtBRC::Update(mfxBRCFrameParam* frame_par, mfxBRCFrameCtrl* frame_ctr
             mfxF64 maxFrameSizeHrd = m_hrdSpec->GetMaxFrameSizeInBits(frame_par->EncodedOrder,bIdr);
             mfxF64 bufOccupy = LTR_BUF(picType, m_par.iDQp, ((picType == MFX_FRAMETYPE_IDR) ? m_par.mIntraBoost : false), ParSceneChange, bSHStart, m_par.mVeryLowDelay);
             mfxF64 maxFrameSizeHRDBalanced = bufOccupy / 9.* maxFrameSizeHrd + (9.0 - bufOccupy) / 9.*targetFrameSize;
-            if (m_ctx.encOrder == 0)
+
+            if (m_par.mVeryLowDelay && frame_par->NumRecode)
+            {
+                maxFrameSize = std::min(maxFrameSize, maxFrameSizeHrd); // very low delay also in low latency, avoid 2nd recode if possible
+            }
+            else if (m_ctx.encOrder == 0)
             {
                 // modify buf limits for VCM like encode for init only
                 mfxF64 maxFrameSizeGood = 6.5 * m_par.inputBitsPerFrame;
@@ -1114,7 +1134,9 @@ mfxStatus ExtBRC::Update(mfxBRCFrameParam* frame_par, mfxBRCFrameCtrl* frame_ctr
                 maxFrameSize = std::min(maxFrameSize, maxFrameSizeInit);
             }
             else
+            {
                 maxFrameSize = std::min(maxFrameSize, maxFrameSizeHRDBalanced);
+            }
 
             quantMax = std::min(m_hrdSpec->GetMaxQuant(), quantMax);
             quantMin = std::max(m_hrdSpec->GetMinQuant(), quantMin);
@@ -1124,7 +1146,7 @@ mfxStatus ExtBRC::Update(mfxBRCFrameParam* frame_par, mfxBRCFrameCtrl* frame_ctr
 
         if (bitsEncoded >  maxFrameSize && quant < quantMax)
         {
-            mfxI32 quant_new = GetNewQP(bitsEncoded, (mfxU32)maxFrameSize, quantMin , quantMax, quant ,m_par.quantOffset, 1);
+            mfxI32 quant_new = GetNewQP(bitsEncoded, (mfxU32)maxFrameSize, quantMin , quantMax, quant ,m_par.quantOffset, m_par.mVeryLowDelay ? 1.24 : 1.0, false, m_par.mVeryLowDelay ? false : true);
             if (quant_new > quant)
             {
                 bNeedUpdateQP = false;
@@ -1213,7 +1235,8 @@ mfxStatus ExtBRC::Update(mfxBRCFrameParam* frame_par, mfxBRCFrameCtrl* frame_ctr
             }
         }//m_par.HRDConformance
     }
-    if (((m_par.HRDConformance != MFX_BRC_NO_HRD && brcSts != MFX_BRC_OK) || (bitsEncoded > (mfxI32)frameSizeLim)) && m_par.bRec)
+    if ((((m_par.HRDConformance != MFX_BRC_NO_HRD && brcSts != MFX_BRC_OK) || (bitsEncoded > (mfxI32)frameSizeLim)) && m_par.bRec)
+        || (bitsEncoded > (mfxI32)bitstreamSizeLim))
     {
         mfxI32 quant = qpY;
         mfxI32 quant_new = quant;
@@ -1222,6 +1245,11 @@ mfxStatus ExtBRC::Update(mfxBRCFrameParam* frame_par, mfxBRCFrameCtrl* frame_ctr
             brcSts = MFX_BRC_BIG_FRAME;
             quant_new = GetNewQP(bitsEncoded, frameSizeLim, m_ctx.QuantMin , m_ctx.QuantMax,quant,m_par.quantOffset, 1, true);
         }
+        else if (bitsEncoded > (mfxI32)bitstreamSizeLim)
+        {
+            brcSts = MFX_BRC_BIG_FRAME;
+            quant_new = GetNewQP(bitsEncoded, bitstreamSizeLim, m_ctx.QuantMin , m_ctx.QuantMax,quant,m_par.quantOffset, 1, true);
+        }
         else if (brcSts == MFX_BRC_BIG_FRAME || brcSts == MFX_BRC_SMALL_FRAME)
         {
             mfxF64 targetSize = GetFrameTargetSize(brcSts,
