@@ -54,12 +54,19 @@ mfxExtBuffer* GetExtendedBufferInternal(mfxExtBuffer** extBuf, mfxU32 numExtBuf,
     return result;
 }
 
-mfxStatus CheckFrameInfoCommon(mfxFrameInfo  *info, mfxU32 /* codecId */)
+mfxStatus CheckFrameInfoCommon(mfxFrameInfo  *info, mfxU32 codecId)
 {
     MFX_CHECK_NULL_PTR1(info);
 
     MFX_CHECK(info->Width && info->Width % 16 == 0, MFX_ERR_INVALID_VIDEO_PARAM);
-    MFX_CHECK(info->Height && info->Height % 16 == 0, MFX_ERR_INVALID_VIDEO_PARAM);
+    if (codecId == MFX_CODEC_JPEG)
+    {
+        MFX_CHECK(info->Height && info->Height % 8 == 0, MFX_ERR_INVALID_VIDEO_PARAM);
+    }
+    else
+    {
+        MFX_CHECK(info->Height && info->Height % 16 == 0, MFX_ERR_INVALID_VIDEO_PARAM);
+    }
 
     switch (info->FourCC)
     {
@@ -495,6 +502,7 @@ mfxStatus CheckFramePointers(mfxFrameInfo const& info, mfxFrameData const& data)
         case MFX_FOURCC_AYUV_RGB4:
         case MFX_FOURCC_RGB4:
         case MFX_FOURCC_BGR4:
+        case MFX_FOURCC_ABGR16F:
         case MFX_FOURCC_ARGB16:
         case MFX_FOURCC_ABGR16:      MFX_CHECK(data.R && data.G && data.B && data.A, MFX_ERR_UNDEFINED_BEHAVIOR); break;
 
