@@ -435,6 +435,9 @@ mfxStatus VideoVPPBase::GetVideoParam(mfxVideoParam *par)
 
 #ifdef MFX_ENABLE_MCTF
                     case MFX_EXTBUFF_VPP_MCTF:
+#endif
+#ifdef ONEVPL_EXPERIMENTAL
+                    case MFX_EXTBUFF_VPP_PERC_ENC_PREFILTER:
 #endif
                     {
                         if(numUsedFilters + 1 > pVPPHint->NumAlg)
@@ -870,6 +873,15 @@ mfxStatus VideoVPPBase::Query(VideoCORE * core, mfxVideoParam *in, mfxVideoParam
         if ( out->vpp.In.FourCC  != MFX_FOURCC_P010 &&
              out->vpp.In.FourCC  != MFX_FOURCC_P210 &&
              out->vpp.In.FourCC  != MFX_FOURCC_A2RGB10 &&
+             out->vpp.In.FourCC  != MFX_FOURCC_Y210 &&
+             out->vpp.In.FourCC  != MFX_FOURCC_Y410 &&
+             out->vpp.In.FourCC  != MFX_FOURCC_BGRA &&
+             out->vpp.In.FourCC  != MFX_FOURCC_P016 &&
+             out->vpp.In.FourCC  != MFX_FOURCC_YUY2 &&
+             out->vpp.In.FourCC  != MFX_FOURCC_NV12 &&
+             out->vpp.In.FourCC  != MFX_FOURCC_Y416 &&
+             out->vpp.In.FourCC  != MFX_FOURCC_Y216 &&
+             out->vpp.In.FourCC  != MFX_FOURCC_AYUV &&
              out->vpp.Out.FourCC == MFX_FOURCC_A2RGB10 ){
             if( out->vpp.In.FourCC )
             {
@@ -889,7 +901,10 @@ mfxStatus VideoVPPBase::Query(VideoCORE * core, mfxVideoParam *in, mfxVideoParam
              out->vpp.Out.FourCC != MFX_FOURCC_AYUV &&
              out->vpp.Out.FourCC != MFX_FOURCC_Y210 &&
              out->vpp.Out.FourCC != MFX_FOURCC_Y410 &&
-             out->vpp.Out.FourCC != MFX_FOURCC_RGB4)
+             out->vpp.Out.FourCC != MFX_FOURCC_RGB4 &&
+             out->vpp.Out.FourCC != MFX_FOURCC_Y416 &&
+             out->vpp.Out.FourCC != MFX_FOURCC_Y216 &&
+             out->vpp.Out.FourCC != MFX_FOURCC_P016)
         {
             if( out->vpp.In.FourCC )
             {
@@ -910,6 +925,7 @@ mfxStatus VideoVPPBase::Query(VideoCORE * core, mfxVideoParam *in, mfxVideoParam
             out->vpp.In.FourCC != MFX_FOURCC_ABGR16F &&
             out->vpp.In.FourCC != MFX_FOURCC_P010 &&
             out->vpp.In.FourCC != MFX_FOURCC_UYVY &&
+            out->vpp.In.FourCC != MFX_FOURCC_I420 &&
             out->vpp.In.FourCC != MFX_FOURCC_P210 &&
             out->vpp.In.FourCC != MFX_FOURCC_Y210 &&
             out->vpp.In.FourCC != MFX_FOURCC_Y410 &&
@@ -917,8 +933,10 @@ mfxStatus VideoVPPBase::Query(VideoCORE * core, mfxVideoParam *in, mfxVideoParam
             out->vpp.In.FourCC != MFX_FOURCC_Y216 &&
             out->vpp.In.FourCC != MFX_FOURCC_Y416 &&
             out->vpp.In.FourCC != MFX_FOURCC_AYUV &&
+            out->vpp.In.FourCC != MFX_FOURCC_R16 &&
+            out->vpp.In.FourCC != MFX_FOURCC_ARGB16 &&
             // A2RGB10 supported as input in case of passthru copy
-            out->vpp.In.FourCC != MFX_FOURCC_A2RGB10 )
+            out->vpp.In.FourCC != MFX_FOURCC_A2RGB10)
         {
             if( out->vpp.In.FourCC )
             {
@@ -979,6 +997,8 @@ mfxStatus VideoVPPBase::Query(VideoCORE * core, mfxVideoParam *in, mfxVideoParam
 #ifdef MFX_ENABLE_RGBP
             out->vpp.Out.FourCC != MFX_FOURCC_RGBP &&
 #endif
+            out->vpp.Out.FourCC != MFX_FOURCC_UYVY &&
+            out->vpp.Out.FourCC != MFX_FOURCC_I420 &&
             out->vpp.Out.FourCC != MFX_FOURCC_BGRP &&
             out->vpp.Out.FourCC != MFX_FOURCC_P010 &&
             out->vpp.Out.FourCC != MFX_FOURCC_P210 &&
@@ -988,7 +1008,8 @@ mfxStatus VideoVPPBase::Query(VideoCORE * core, mfxVideoParam *in, mfxVideoParam
             out->vpp.Out.FourCC != MFX_FOURCC_Y216 &&
             out->vpp.Out.FourCC != MFX_FOURCC_Y416 &&
             out->vpp.Out.FourCC != MFX_FOURCC_AYUV &&
-            out->vpp.Out.FourCC != MFX_FOURCC_A2RGB10 )
+            out->vpp.Out.FourCC != MFX_FOURCC_ARGB16 &&
+            out->vpp.Out.FourCC != MFX_FOURCC_A2RGB10)
         {
             out->vpp.Out.FourCC = 0;
             mfxSts = MFX_ERR_UNSUPPORTED;
