@@ -110,7 +110,23 @@ const mfxU32 g_TABLE_CONFIG [] =
     MFX_EXTBUFF_VIDEO_SIGNAL_INFO_OUT,
     MFX_EXTBUFF_CONTENT_LIGHT_LEVEL_INFO,
     MFX_EXTBUFF_MASTERING_DISPLAY_COLOUR_VOLUME_IN,
-    MFX_EXTBUFF_MASTERING_DISPLAY_COLOUR_VOLUME_OUT
+    MFX_EXTBUFF_MASTERING_DISPLAY_COLOUR_VOLUME_OUT,
+    MFX_EXTBUF_CAM_PIPECONTROL,
+    MFX_EXTBUF_CAM_3DLUT,
+    MFX_EXTBUF_CAM_FORWARD_GAMMA_CORRECTION,
+    MFX_EXTBUF_CAM_WHITE_BALANCE,
+    MFX_EXTBUF_CAM_BLACK_LEVEL_CORRECTION,
+    MFX_EXTBUF_CAM_BAYER_DENOISE,
+    MFX_EXTBUF_CAM_HOT_PIXEL_REMOVAL,
+    MFX_EXTBUF_CAM_VIGNETTE_CORRECTION,
+    MFX_EXTBUF_CAM_COLOR_CORRECTION_3X3,
+    MFX_EXTBUF_CAM_PADDING,
+    MFX_EXTBUF_CAM_LENS_GEOM_DIST_CORRECTION,
+    MFX_EXTBUF_CAM_TOTAL_COLOR_CONTROL,
+    MFX_EXTBUF_CAM_CSC_YUV_RGB
+#if defined (ONEVPL_EXPERIMENTAL)
+    , MFX_EXTBUFF_VPP_PERC_ENC_PREFILTER
+#endif
 };
 
 
@@ -149,7 +165,20 @@ const mfxU32 g_TABLE_EXT_PARAM [] =
     MFX_EXTBUFF_MASTERING_DISPLAY_COLOUR_VOLUME_OUT,
     MFX_EXTBUF_CAM_PIPECONTROL,
     MFX_EXTBUF_CAM_3DLUT,
-    MFX_EXTBUF_CAM_FORWARD_GAMMA_CORRECTION
+    MFX_EXTBUF_CAM_FORWARD_GAMMA_CORRECTION,
+    MFX_EXTBUF_CAM_WHITE_BALANCE,
+    MFX_EXTBUF_CAM_BLACK_LEVEL_CORRECTION,
+    MFX_EXTBUF_CAM_BAYER_DENOISE,
+    MFX_EXTBUF_CAM_HOT_PIXEL_REMOVAL,
+    MFX_EXTBUF_CAM_VIGNETTE_CORRECTION,
+    MFX_EXTBUF_CAM_COLOR_CORRECTION_3X3,
+    MFX_EXTBUF_CAM_PADDING,
+    MFX_EXTBUF_CAM_LENS_GEOM_DIST_CORRECTION,
+    MFX_EXTBUF_CAM_TOTAL_COLOR_CONTROL,
+    MFX_EXTBUF_CAM_CSC_YUV_RGB
+#if defined (ONEVPL_EXPERIMENTAL)
+    , MFX_EXTBUFF_VPP_PERC_ENC_PREFILTER
+#endif
 };
 
 PicStructMode GetPicStructMode(mfxU16 inPicStruct, mfxU16 outPicStruct)
@@ -691,6 +720,13 @@ void ShowPipeline( std::vector<mfxU32> pipelineList )
                 fprintf(stderr, "VPP_MCTF\n");
                 break;
             }
+#endif
+#if defined (ONEVPL_EXPERIMENTAL)
+            case MFX_EXTBUFF_VPP_PERC_ENC_PREFILTER:
+            {
+                fprintf(stderr, "VPP_PERC_ENC_PREFILTER\n");
+                break;
+            }
 #endif
             case (mfxU32)MFX_EXTBUFF_VPP_3DLUT:
             {
@@ -935,6 +971,15 @@ void ReorderPipelineListForQuality( std::vector<mfxU32> & pipelineList )
         index++;
     }
 #endif
+
+#if defined (ONEVPL_EXPERIMENTAL)
+    if (IsFilterFound(&pipelineList[0], (mfxU32)pipelineList.size(), MFX_EXTBUFF_VPP_PERC_ENC_PREFILTER))
+    {
+        newList[index] = MFX_EXTBUFF_VPP_PERC_ENC_PREFILTER;
+        index++;
+    }
+#endif
+
     // [1] update
     pipelineList.resize(index);
     for( index = 0; index < (mfxU32)pipelineList.size(); index++ )
@@ -1341,6 +1386,14 @@ mfxStatus GetPipelineList(
         }
     }
 
+#if defined (ONEVPL_EXPERIMENTAL)
+    if (    IsFilterFound(&configList[0], configCount, MFX_EXTBUFF_VPP_PERC_ENC_PREFILTER)
+        && !IsFilterFound(&pipelineList[0], (mfxU32)pipelineList.size(), MFX_EXTBUFF_VPP_PERC_ENC_PREFILTER))
+    {
+        pipelineList.push_back(MFX_EXTBUFF_VPP_PERC_ENC_PREFILTER);
+    }
+#endif
+
     searchCount = sizeof(g_TABLE_CONFIG) / sizeof(*g_TABLE_CONFIG);
     fCount      = configCount;
     for(fIdx = 0; fIdx < fCount; fIdx++)
@@ -2325,6 +2378,56 @@ void ConvertCaps2ListDoUse(MfxHwVideoProcessing::mfxVppCaps& caps, std::vector<m
         list.push_back(MFX_EXTBUF_CAM_3DLUT);
     }
 
+    if (caps.cameraCaps.uWhiteBalance)
+    {
+        list.push_back(MFX_EXTBUF_CAM_WHITE_BALANCE);
+    }
+
+    if (caps.cameraCaps.uBlackLevelCorrection)
+    {
+        list.push_back(MFX_EXTBUF_CAM_BLACK_LEVEL_CORRECTION);
+    }
+
+    if (caps.cameraCaps.uBayerDenoise)
+    {
+        list.push_back(MFX_EXTBUF_CAM_BAYER_DENOISE);
+    }
+
+    if (caps.cameraCaps.uHotPixelCheck)
+    {
+        list.push_back(MFX_EXTBUF_CAM_HOT_PIXEL_REMOVAL);
+    }
+
+    if (caps.cameraCaps.uVignetteCorrection)
+    {
+        list.push_back(MFX_EXTBUF_CAM_VIGNETTE_CORRECTION);
+    }
+
+    if (caps.cameraCaps.uColorCorrectionMatrix)
+    {
+        list.push_back(MFX_EXTBUF_CAM_COLOR_CORRECTION_3X3);
+    }
+
+    if (caps.cameraCaps.uPadding)
+    {
+        list.push_back(MFX_EXTBUF_CAM_PADDING);
+    }
+
+    if (caps.cameraCaps.uLensGeomDistCorrection)
+    {
+        list.push_back(MFX_EXTBUF_CAM_LENS_GEOM_DIST_CORRECTION);
+    }
+
+    if (caps.cameraCaps.uTotalColorControl)
+    {
+        list.push_back(MFX_EXTBUF_CAM_TOTAL_COLOR_CONTROL);
+    }
+
+    if (caps.cameraCaps.uCscYuvRgb)
+    {
+        list.push_back(MFX_EXTBUF_CAM_CSC_YUV_RGB);
+    }
+
     /*ColorFill is always present*/
     list.push_back(MFX_EXTBUFF_VPP_COLORFILL);
     /* Field weaving is always present*/
