@@ -58,7 +58,8 @@ enum {
     MFX_EXTBUFF_ENCTOOLS_BRC_ENCODE_RESULT = MFX_MAKEFOURCC('E', 'B', 'E', 'R'),
     MFX_EXTBUFF_ENCTOOLS_BRC_STATUS = MFX_MAKEFOURCC('E', 'B', 'S', 'T'),
     MFX_EXTBUFF_ENCTOOLS_HINT_MATRIX = MFX_MAKEFOURCC('E', 'H', 'Q', 'M'),
-    MFX_EXTBUFF_ENCTOOLS_HINT_QPMAP  = MFX_MAKEFOURCC('E', 'H', 'Q', 'P')
+    MFX_EXTBUFF_ENCTOOLS_HINT_QPMAP  = MFX_MAKEFOURCC('E', 'H', 'Q', 'P'),
+    MFX_EXTBUFF_ENCTOOLS_HINT_SALIENCY_MAP  = MFX_MAKEFOURCC('E', 'H', 'S', 'M')
 };
 
 enum
@@ -250,6 +251,9 @@ enum
     MFX_QP_MODULATION_MEDIUM,           /* Use medium pyramid delta QP for this frame. This type of content prefers medium delta QP between P/B Layers. */
     MFX_QP_MODULATION_HIGH,             /* Use high pyramid delta QP for this frame. This type of content prefers high delta QP between P/B Layers. */
     MFX_QP_MODULATION_MIXED,            /* Use pyramid delta QP appropriate for mixed content. */
+#if defined(MFX_ENABLE_ENCTOOLS)
+    MFX_QP_MODULATION_EXPLICIT,         /* Use explicit pyramid delta QP. */
+#endif
     MFX_QP_MODULATION_RESERVED0
 };
 MFX_PACK_BEGIN_USUAL_STRUCT()
@@ -264,6 +268,27 @@ typedef struct {
 } mfxEncToolsHintQPMap;
 MFX_PACK_END()
 
+MFX_PACK_BEGIN_STRUCT_W_PTR()
+/*
+This buffer can be used by encoder to get saliency map from enctools. Encoder should allocate 
+sufficient "SaliencyMap" buffer and set its size in "AllocatedSize" before calling enctools. 
+Enctools fill this buffer with saliency map and set "Width", "Height" and "BlockSize". If buffer
+size is not sufficient, enctools do not modify "SaliencyMap", but set "Width", "Height", 
+"BlockSize" and return MFX_ERR_NOT_ENOUGH_BUFFER. Encoder should reallocate buffer and 
+call enctools one more time.
+*/ 
+typedef struct {
+    mfxExtBuffer      Header;        /* MFX_EXTBUFF_ENCTOOLS_HINT_SALIENCY_MAP */
+    mfxStructVersion  Version;
+    mfxU32            Width;         /* width of the map in blocks, set by enctools */
+    mfxU32            Height;        /* height of the map in blocks, set by enctools */
+    mfxU32            BlockSize;     /* block size of the saliency map in pixels, set by enctools */
+    mfxU32            AllocatedSize; /* number of elements (blocks) allocated in "SaliencyMap" array, set by encoder */
+    mfxF32*           SaliencyMap;   /* saliency map, in 0..1 range, allocated by encoder */
+    mfxU32            reserved[64];
+} mfxEncToolsHintSaliencyMap;
+MFX_PACK_END()
+
 MFX_PACK_BEGIN_USUAL_STRUCT()
 typedef struct {
     mfxExtBuffer      Header;
@@ -273,6 +298,10 @@ typedef struct {
     mfxI16            QPDelta;
     mfxU16            QPModulation;    /* enum */
     mfxU16            MiniGopSize;     /* Adaptive GOP decision for the frame */
+#if defined(MFX_ENABLE_ENCTOOLS)
+    mfxI8             QPDeltaExplicitModulation;     /* Explicit adaptive QP offset */
+    mfxU8             reserved8bits;
+#endif
     mfxU16            reserved2[5];
 } mfxEncToolsHintPreEncodeGOP;
 MFX_PACK_END()
@@ -400,6 +429,7 @@ MFX_PACK_END()
 
 #define MFX_ENCTOOLS_BRCSTATUS_VERSION MFX_STRUCT_VERSION(1, 0)
 
+
 MFX_PACK_BEGIN_STRUCT_W_PTR()
 typedef struct {
     mfxExtBuffer      Header;
