@@ -1,4 +1,4 @@
-// Copyright (c) 2007-2020 Intel Corporation
+﻿// Copyright (c) 2007-2023 Intel Corporation
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -58,6 +58,7 @@ namespace mfxDefaultAllocator
     mfxStatus UnlockFrame(mfxHDL pthis, mfxMemId mid, mfxFrameData *ptr=0);
     mfxStatus FreeFrames(mfxHDL pthis, mfxFrameAllocResponse *response);
 
+    mfxStatus GetSurfaceSizeInBytes(mfxU32 pitch, mfxU32 height, mfxU32 fourCC, mfxU32& nBytes);
     mfxStatus GetNumBytesRequired(const mfxFrameInfo& Info, mfxU32& nbytes, size_t power_of_2_alignment = BASE_SIZE_ALIGN);
 
     struct BufferStruct
@@ -256,6 +257,9 @@ static bool RequiredHWallocator(mfxU16 memtype)
 class FrameAllocatorWrapper
 {
 public:
+    FrameAllocatorWrapper(bool delayed_allocation)
+        : m_delayed_allocation(delayed_allocation)
+    {}
 
     mfxStatus Alloc(mfxFrameAllocRequest& request, mfxFrameAllocResponse& response, bool ext_alloc_hint = false)
     {
@@ -272,12 +276,13 @@ public:
             {
 
                MFX_SAFE_CALL(allocator_ext->Alloc(request, response));
-
-               if (response.NumFrameActual < request.NumFrameMin)
-               {
-                   std::ignore = MFX_STS_TRACE(allocator_ext->Free(response));
-                   MFX_RETURN(MFX_ERR_MEMORY_ALLOC);
-               }
+               // In delay allocate mode, response frame num only need >= 0.
+               // Delay allocate mode not work with D3D9, D3D9 will use legacy allocator logical
+                if(!m_delayed_allocation && (response.NumFrameActual < request.NumFrameMin))
+                {
+                    std::ignore = MFX_STS_TRACE(allocator_ext->Free(response));
+                    MFX_RETURN(MFX_ERR_MEMORY_ALLOC);
+                }
 
                CacheMids(response, *allocator_ext);
                return MFX_ERR_NONE;
@@ -458,6 +463,7 @@ private:
 
     std::shared_timed_mutex                 m_mutex;
     std::map<mfxMemId, FrameAllocatorBase*> m_mid_to_allocator;
+    bool                                    m_delayed_allocation;
 };
 
 inline mfxU16 AdjustTypeInternal(mfxU16 type)
