@@ -111,9 +111,9 @@ public:
     virtual void INeedMoreThreadsInside(const void *pComponent) override;
 
     virtual mfxStatus DoFastCopy(mfxFrameSurface1 *pDst, mfxFrameSurface1 *pSrc)                      override;
-    virtual mfxStatus DoFastCopyExtended(mfxFrameSurface1 *pDst, mfxFrameSurface1 *pSrc, bool = true) override;
+    virtual mfxStatus DoFastCopyExtended(mfxFrameSurface1 *pDst, mfxFrameSurface1 *pSrc, mfxU32 = MFX_COPY_USE_ANY) override;
 
-    virtual mfxStatus DoFastCopyWrapper(mfxFrameSurface1 *pDst, mfxU16 dstMemType, mfxFrameSurface1 *pSrc, mfxU16 srcMemType, bool = true) override;
+    virtual mfxStatus DoFastCopyWrapper(mfxFrameSurface1 *pDst, mfxU16 dstMemType, mfxFrameSurface1 *pSrc, mfxU16 srcMemType, mfxU32 = MFX_COPY_USE_ANY) override;
 
     // DEPRECATED
     virtual bool IsFastCopyEnabled()              override { return true; }
@@ -121,6 +121,8 @@ public:
     virtual bool IsExternalFrameAllocator() const override;
     virtual eMFXHWType GetHWType()                override { return MFX_HW_UNKNOWN; }
 
+    virtual mfxU16    GetHWDeviceId()             override { return 0; }
+
     virtual mfxStatus CopyFrame(mfxFrameSurface1 *dst, mfxFrameSurface1 *src) override;
 
     virtual mfxStatus CopyBuffer(mfxU8 *, mfxU32, mfxFrameSurface1 *)         override { MFX_RETURN(MFX_ERR_UNKNOWN); }
@@ -242,11 +244,12 @@ protected:
 
     API_1_19_Adapter                           m_API_1_19;
 
-    mfxU16                                     m_deviceId;
 #if defined(MFX_ENABLE_PXP)
     mfxHDL                                     m_pPXPCtxHdl;
 #endif // MFX_ENABLE_PXP
 
+    mfxU16                                     m_deviceId;
+
     CommonCORE & operator = (const CommonCORE &) = delete;
 };
 
@@ -340,9 +343,9 @@ public:
     mfxStatus SwitchMemidInSurface(mfxFrameSurface1 & surf, mfxHDLPair& handle_pair);
     mfxStatus DeriveMemoryType(const mfxFrameSurface1& surf, mfxU16& derived_memtype);
 
-    virtual mfxStatus DoFastCopyExtended(mfxFrameSurface1 *pDst, mfxFrameSurface1 *pSrc, bool = true)                                      override;
+    virtual mfxStatus DoFastCopyExtended(mfxFrameSurface1 *pDst, mfxFrameSurface1 *pSrc, mfxU32 = MFX_COPY_USE_ANY)                                      override;
 
-    virtual mfxStatus DoFastCopyWrapper(mfxFrameSurface1 *pDst, mfxU16 dstMemType, mfxFrameSurface1 *pSrc, mfxU16 srcMemType, bool = true) override;
+    virtual mfxStatus DoFastCopyWrapper(mfxFrameSurface1 *pDst, mfxU16 dstMemType, mfxFrameSurface1 *pSrc, mfxU16 srcMemType, mfxU32 = MFX_COPY_USE_ANY) override;
 
     virtual bool IsExternalFrameAllocator() const                             override;
 
