@@ -99,6 +99,7 @@ struct VaGuidMapper
 };
 
 class CmCopyWrapper;
+class VACopyWrapper;
 
 // disable the "conditional expression is constant" warning
 #ifdef _MSVC_LANG
@@ -139,9 +140,9 @@ public:
         CMEnabledCoreAdapter(VAAPIVideoCORE_T *pVAAPICore): m_pVAAPICore(pVAAPICore)
         {
         }
-        virtual void SetCmCopyStatus(bool enable) override
+        virtual void SetCmCopyMode(mfxU16 cm_copy_mode) override
         {
-            m_pVAAPICore->SetCmCopyStatus(enable);
+            m_pVAAPICore->SetCmCopyMode(cm_copy_mode);
         }
     protected:
         VAAPIVideoCORE_T *m_pVAAPICore;
@@ -194,7 +195,7 @@ public:
 
     mfxStatus            GetVAService(VADisplay *pVADisplay);
 
-    void                 SetCmCopyStatus(bool enable);
+    void                 SetCmCopyMode(mfxU16 cm_copy_mode);
 
 protected:
     VAAPIVideoCORE_T(const mfxU32 adapterNum, const AffinityMaskType& affinityMask, const mfxU32 numThreadsAvailable, const mfxSession session = nullptr);
@@ -210,7 +211,7 @@ protected:
 
     bool                   IsCmSupported();
     bool                   IsCmCopyEnabledByDefault();
-    mfxStatus              TryInitializeCm();
+    mfxStatus              TryInitializeCm(bool force_cm_device_creation);
 
     std::unique_ptr<UMC::LinuxVideoAccelerator> m_pVA;
     std::shared_ptr<VADisplayWrapper>           m_p_display_wrapper;
@@ -226,8 +227,10 @@ protected:
     eMFXHWType                                  m_HWType;
     eMFXGTConfig                                m_GTConfig;
 
-    mfxU32                                      m_ForcedCmState = MFX_GPUCOPY_DEFAULT;
+    mfxU32                                      m_ForcedGpuCopyState = MFX_GPUCOPY_DEFAULT;
     std::unique_ptr<CmCopyWrapper>              m_pCmCopy;
+    std::unique_ptr<VACopyWrapper>              m_pVaCopy;
+
 #if defined (MFX_ENABLE_VPP)
     VPPHWResMng                                 m_vpp_hw_resmng;
 #endif
@@ -238,8 +241,6 @@ private:
     std::unique_ptr<CMEnabledCoreAdapter>       m_pCmAdapter;
 };
 
-using VAAPIVideoCORE = VAAPIVideoCORE_T<CommonCORE>;
-
 
 // Refactored MSDK 2.0 core
 
