@@ -54,8 +54,7 @@ typedef unsigned int mfxTraceU32;
 typedef __UINT64 mfxTraceU64;
 
 /*------------------------------------------------------------------------------*/
-extern mfxTraceU32 EnableEventTrace;
-extern mfxTraceU32 EventCfg;
+extern mfxTraceU64 EventCfg;
 extern mfxTraceU32 LogConfig;
 extern int32_t FrameIndex;
 
@@ -228,11 +227,7 @@ typedef enum _MEDIA_EVENT_FILTER_KEYID
     TR_KEY_PIPELINE_STICKER,
 } MEDIA_EVENT_FILTER_KEYID;
 
-typedef enum _MEDIA_EVENT_LOG_KEYID
-{
-    MFX_ETWLOG_ALL_LEVEL = 16,   //include API Func, API PARAMS and internal Func
-    MFX_ETWLOG_API_LEVEL,   //include API Func
-} MEDIA_EVENT_LOG_KEYID;
+#define MFX_ETWLOG_ENABLE 16
 
 // delete the following levels completely
 #define MFX_TRACE_LEVEL_SCHED       MFX_TRACE_LEVEL_10
@@ -307,6 +302,12 @@ typedef union
     mfxTraceLevel level;
 } mfxTraceHandle;
 
+typedef struct
+{
+    uint64_t callCount;
+    double   totalTime;
+}TimeStampInfo;
+
 typedef struct
 {
     mfxTraceChar* category;
@@ -321,6 +322,8 @@ typedef struct
     mfxTraceHandle sd7;
     // reserved for itt
     mfxTraceHandle itt1;
+    //timeStamp
+    TimeStampInfo  tick;
 } mfxTraceStaticHandle;
 
 typedef struct
@@ -479,7 +482,7 @@ public:
 };
 
 #define TRACE_CHECK(keyWord)   \
-    (EventCfg & (1 << keyWord) || keyWord == TR_KEY_MFX_API || keyWord == TR_KEY_DDI_API) && EnableEventTrace
+    (EventCfg & (1 << keyWord)) || keyWord == TR_KEY_MFX_API || keyWord == TR_KEY_DDI_API
 
 // This macro is recommended to use instead creating RT Info ScopedTrace object directly
 #define TRACE_BUFFER_EVENT(task, level, keyWord, pData, funcName, structType)   \
@@ -596,13 +599,13 @@ extern "C" {
 #endif
 
 #ifdef MFX_TRACE_ENABLE
-#define MFX_LTRACE_BUFFER(_level, _buffer) \
+#define MFX_LTRACE_BUFFER(_level, _message, _buffer) \
 { \
     if (0 != LogConfig && _buffer) \
     { \
         DumpContext context; \
         std::string _str = context.dump(#_buffer, *_buffer); \
-        MFX_LTRACE_1(_level, "", "\n%s", _str.c_str()) \
+        MFX_LTRACE_1(_level, "\n" _message, "%s", _str.c_str()) \
     } \
     else { \
         MFX_LTRACE_BUFFER_S(_level, #_buffer, _buffer, sizeof(*_buffer)) \
@@ -738,26 +741,42 @@ class MFXLTraceI
 {
 public:
     template <typename T>
-    void mfx_ltrace_i(mfxTraceLevel _level, const char* _mesg, const char* _function, T _arg1)
+    void mfx_ltrace_i(mfxTraceLevel _level, const char* _mesg, const char* _function, const char* _filename, mfxTraceU32 _line, T _arg1)
     {
         std::stringstream ss;
+        if (_arg1 > 0)
+        {
+            ss << "[warning]  ";
+        }
+        else if (_arg1 < 0)
+        {
+            ss << "[critical]  ";
+        }
         ss << _mesg << " = ";
-        MFX_LTRACE((&_trace_static_handle, __FILE__, __LINE__, _function, MFX_TRACE_CATEGORY, _level, ss.str().c_str(), MFX_TRACE_FORMAT_I, _arg1))
+        MFX_LTRACE((&_trace_static_handle, _filename, _line, _function, MFX_TRACE_CATEGORY, _level, ss.str().c_str(), MFX_TRACE_FORMAT_I, _arg1))
     }
 
-    void mfx_ltrace_i(mfxTraceLevel _level, const char* _mesg, const char* _function, mfxStatus _arg1)
+    void mfx_ltrace_i(mfxTraceLevel _level, const char* _mesg, const char* _function, const char* _filename, mfxTraceU32 _line, mfxStatus _arg1)
     {
         std::error_code code = mfx::make_error_code(_arg1);
         std::stringstream ss;
+        if (_arg1 > 0) 
+        {
+            ss << "[warning]  ";
+        }
+        else if (_arg1 < 0) 
+        {
+            ss << "[critical]  ";
+        }
         ss << _mesg << " = ";
-        MFX_LTRACE((&_trace_static_handle, __FILE__, __LINE__, _function, MFX_TRACE_CATEGORY, _level, ss.str().c_str(), MFX_TRACE_FORMAT_S, code.message().c_str()))
+        MFX_LTRACE((&_trace_static_handle, _filename, _line, _function, MFX_TRACE_CATEGORY, _level, ss.str().c_str(), MFX_TRACE_FORMAT_S, code.message().c_str()))
     }
 };
 
 #define MFX_LTRACE_I(_level, _arg1) \
 { \
     MFXLTraceI mFXLTraceI; \
-    mFXLTraceI.mfx_ltrace_i(_level, #_arg1, __FUNCTION__, _arg1); \
+    mFXLTraceI.mfx_ltrace_i(_level, #_arg1, __FUNCTION__, __FILE__, __LINE__,_arg1); \
 }
 #else
 #define MFX_LTRACE_I(_level, _arg1) \
