@@ -31,6 +31,7 @@
 #include "umc_structures.h"
 #include "mfx_trace.h"
 #include "mfx_utils_logging.h"
+#include "mfx_utils_perf.h"
 #include "mfx_timing.h"
 #include "mfxsurfacepool.h"
 #include "mfx_error.h"
@@ -56,15 +57,17 @@ template <
 static inline T mfx_sts_trace(const char* fileName, const uint32_t lineNum, const char* funcName, T sts)
 {
     const std::string stsString = GetMFXStatusInString(sts);
+    std::string mfxSts;
     if (sts < MFX_ERR_NONE)
     {
         MFX_LOG(LEVEL_ERROR, fileName, lineNum, "%s: returns %s\n", funcName, stsString.c_str());
+        mfxSts = "[critical]  mfxRes = ";
     }
     else if (sts > MFX_ERR_NONE)
     {
         MFX_LOG(LEVEL_WARN, fileName, lineNum, "%s: returns %s\n", funcName, stsString.c_str());
+        mfxSts = "[warning]  mfxRes = ";
     }
-
     return sts;
 }
 template <
@@ -128,6 +131,8 @@ mfxStatus ConvertStatusUmc2Mfx(UMC::Status umcStatus)
     case UMC::UMC_ERR_UNSUPPORTED:       return MFX_ERR_UNSUPPORTED;
     case UMC::UMC_ERR_ALLOC:             return MFX_ERR_MEMORY_ALLOC;
     case UMC::UMC_ERR_LOCK:              return MFX_ERR_LOCK_MEMORY;
+    case UMC::UMC_ERR_NOT_IMPLEMENTED:   return MFX_ERR_NOT_IMPLEMENTED;
+    case UMC::UMC_ERR_GPU_HANG:          return MFX_ERR_GPU_HANG;
     case UMC::UMC_ERR_NOT_ENOUGH_BUFFER: return MFX_ERR_NOT_ENOUGH_BUFFER;
     case UMC::UMC_ERR_NOT_ENOUGH_DATA:   return MFX_ERR_MORE_DATA;
     case UMC::UMC_ERR_SYNC:              return MFX_ERR_MORE_DATA; // need to skip bad frames
@@ -135,6 +140,25 @@ mfxStatus ConvertStatusUmc2Mfx(UMC::Status umcStatus)
     }
 }
 
+inline
+UMC::Status ConvertStatusMfx2Umc(mfxStatus mfxStatus)
+{
+    switch (mfxStatus)
+    {
+    case MFX_ERR_NONE:              return UMC::UMC_OK;
+    case MFX_ERR_NULL_PTR:          return UMC::UMC_ERR_NULL_PTR;
+    case MFX_ERR_UNSUPPORTED:       return UMC::UMC_ERR_UNSUPPORTED;
+    case MFX_ERR_MEMORY_ALLOC:      return UMC::UMC_ERR_ALLOC;
+    case MFX_ERR_LOCK_MEMORY:       return UMC::UMC_ERR_LOCK;
+    case MFX_ERR_NOT_ENOUGH_BUFFER: return UMC::UMC_ERR_NOT_ENOUGH_BUFFER;
+    case MFX_ERR_MORE_DATA:         return UMC::UMC_ERR_NOT_ENOUGH_DATA;
+    case MFX_ERR_NOT_IMPLEMENTED:   return UMC::UMC_ERR_NOT_IMPLEMENTED;
+    case MFX_ERR_GPU_HANG:          return UMC::UMC_ERR_GPU_HANG;
+    case MFX_ERR_UNKNOWN:
+    default:
+        return UMC::UMC_ERR_FAILED;
+    }
+}
 
 inline
 mfxF64 GetUmcTimeStamp(mfxU64 ts)
