@@ -20,6 +20,7 @@
 
 #include "mfxdefs.h"
 #include "mfx_trace.h"
+#include "mfx_utils_perf.h"
 
 static mfx_reflect::AccessibleTypesCollection g_Reflection;
 
@@ -97,8 +98,7 @@ struct mfxTraceAlgorithm
 
 static mfxTraceU32      g_OutputMode = MFX_TRACE_OUTPUT_TRASH;
 static mfxTraceU32      g_Level      = MFX_TRACE_LEVEL_DEFAULT;
-mfxTraceU32      EnableEventTrace = 0;
-mfxTraceU32      EventCfg = 0;
+mfxTraceU64      EventCfg = 0;
 mfxTraceU32      LogConfig = 0;
 int32_t FrameIndex = -1;
 static volatile uint32_t  g_refCounter = 0;
@@ -213,14 +213,23 @@ mfxTraceU32 MFXTrace_GetEnvParams(void)
             g_Level = LogConfig;
         }
     }
-    //Enable event capture according to VPL_EVENT_TRACE
-    const char* g_eventTrace = std::getenv("VPL_EVENT_TRACE");
-    char* endEvent = nullptr;
-    if (g_eventTrace != nullptr)
+    //get VPL perf log environment variable
+    const char* PerflogChar = std::getenv("VPL_PERF_LOG");
+    const char* PerfPathChar = std::getenv("VPL_PERF_PATH");
+    char* pEndPerf = nullptr;
+    if (PerflogChar != nullptr)
     {
-        EnableEventTrace = std::strtol(g_eventTrace, &endEvent, 10);
-        g_OutputMode |= MFX_TRACE_OUTPUT_ETW;
+        g_perfutility->dwPerfUtilityIsEnabled = std::strtol(PerflogChar, &pEndPerf, 10);
+        if (PerfPathChar != nullptr)
+        {
+            g_perfutility->perfFilePath = PerfPathChar;
+        }
+        else
+        {
+            g_perfutility->perfFilePath = "/tmp/";
+        }
     }
+
     //Capture different info according to VPL_EVENT_TRACE_CFG
     const char* g_eventCfg = std::getenv("VPL_EVENT_TRACE_CFG");
     char* endEventCfg = nullptr;
@@ -228,7 +237,6 @@ mfxTraceU32 MFXTrace_GetEnvParams(void)
     {
         EventCfg = std::strtol(g_eventCfg, &endEventCfg, 16);
     }
-
     return 0;
 }
 
@@ -289,17 +297,10 @@ inline bool MFXTrace_IsPrintableCategoryAndLevel(mfxTraceU32 m_OutputInitilized,
     }
     else if(m_OutputInitilized == MFX_TRACE_OUTPUT_ETW)
     {
-        if (EventCfg & (1 << MFX_ETWLOG_ALL_LEVEL))
+        if (EventCfg & (1 << MFX_ETWLOG_ENABLE))
         {
             logFlag = true;
         }
-        else if (EventCfg & (1 << MFX_ETWLOG_API_LEVEL))
-        {
-            if (level == MFX_TRACE_LEVEL_API)
-            {
-                logFlag = true;
-            }
-        }
     }
 
     return logFlag;
