@@ -1,4 +1,4 @@
-// Copyright (c) 2010-2020 Intel Corporation
+// Copyright (c) 2010-2022 Intel Corporation
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -19,6 +19,7 @@
 // SOFTWARE.
 
 #include "mfx_trace.h"
+#include "mfx_utils_perf.h"
 
 #ifdef MFX_TRACE_ENABLE_TEXTLOG
 extern "C"
@@ -41,6 +42,9 @@ static mfxTraceU32 g_PrintfSuppress =
     MFX_TRACE_TEXTLOG_SUPPRESS_LINE_NUM |
     MFX_TRACE_TEXTLOG_SUPPRESS_LEVEL;
 
+bool trace_bEnable = false;
+std::string trace_autotag = "intialized";
+
 /*------------------------------------------------------------------------------*/
 
 
@@ -141,7 +145,7 @@ mfxTraceU32 MFXTraceTextLog_DebugMessage(mfxTraceStaticHandle* static_handle,
 
 /*------------------------------------------------------------------------------*/
 
-mfxTraceU32 MFXTraceTextLog_vDebugMessage(mfxTraceStaticHandle* /*static_handle*/,
+mfxTraceU32 MFXTraceTextLog_vDebugMessage(mfxTraceStaticHandle* static_handle,
                                     const char *file_name, mfxTraceU32 line_num,
                                     const char *function_name,
                                     mfxTraceChar* category, mfxTraceLevel level,
@@ -158,11 +162,11 @@ mfxTraceU32 MFXTraceTextLog_vDebugMessage(mfxTraceStaticHandle* /*static_handle*
     strncpy(strfile_name, file_name, MFX_TRACE_MAX_LINE_LENGTH-1);
     strfile_name[MFX_TRACE_MAX_LINE_LENGTH - 1] = 0;
     char* g_fimeName = strrchr(strfile_name, '/') + 1;
-    if (g_fimeName && !(g_PrintfSuppress & MFX_TRACE_TEXTLOG_SUPPRESS_FILE_NAME) && ((strcmp(format, exitChr) == 0) || (strcmp(format, enterChr) == 0)))
+    if (g_fimeName && !(g_PrintfSuppress & MFX_TRACE_TEXTLOG_SUPPRESS_FILE_NAME))
     {
-        p_str = mfx_trace_sprintf(p_str, len, "=====>%s: ", g_fimeName);
+        p_str = mfx_trace_sprintf(p_str, len, "=====>%-40s: ", g_fimeName);
     }
-    if (line_num && !(g_PrintfSuppress & MFX_TRACE_TEXTLOG_SUPPRESS_LINE_NUM) && ((strcmp(format, exitChr) == 0) || (strcmp(format, enterChr) == 0)))
+    if (line_num && !(g_PrintfSuppress & MFX_TRACE_TEXTLOG_SUPPRESS_LINE_NUM))
     {
         p_str = mfx_trace_sprintf(p_str, len, "%-10d: ", line_num);
     }
@@ -174,19 +178,36 @@ mfxTraceU32 MFXTraceTextLog_vDebugMessage(mfxTraceStaticHandle* /*static_handle*
     {
         p_str = mfx_trace_sprintf(p_str, len, "LEV_%d: ", level);
     }
-    if (function_name && (g_PrintfSuppress & MFX_TRACE_TEXTLOG_SUPPRESS_FUNCTION_NAME))
+    if (function_name && !(g_PrintfSuppress & MFX_TRACE_TEXTLOG_SUPPRESS_FUNCTION_NAME) && !(format && ((strcmp(format, exitChr) == 0) || (strcmp(format, enterChr) == 0))))
     {
-        p_str = mfx_trace_sprintf(p_str, len, "%-40s: ", function_name);
+        p_str = mfx_trace_sprintf(p_str, len, "%-60s: ", function_name);
     }
     if (message && strlen(message) != 0)
     {
-        p_str = mfx_trace_sprintf(p_str, len, "%s: ", message);
+        if (format && ((strcmp(format, exitChr) == 0) || (strcmp(format, enterChr) == 0)))
+        {
+            p_str = mfx_trace_sprintf(p_str, len, "%-40s", message);
+        }
+        else
+        {
+            p_str = mfx_trace_sprintf(p_str, len, "%s", message);
+        }
     }
     if (format)
     {
         p_str = mfx_trace_vsprintf(p_str, len, format, args);
         if (strcmp(format, exitChr) == 0)
         {
+            if (static_handle->tick.totalTime)
+            {
+                p_str = mfx_trace_sprintf(p_str, len, "\t\tExec Time: %5.4fms\t\t", static_handle->tick.totalTime);
+            }
+
+            if (static_handle->tick.callCount)
+            {
+                p_str = mfx_trace_sprintf(p_str, len, "\tCall Count: %-d", static_handle->tick.callCount);
+            }
+
             p_str = mfx_trace_sprintf(p_str, len, "\n");
         }
     }
@@ -214,6 +235,8 @@ mfxTraceU32 MFXTraceTextLog_BeginTask(mfxTraceStaticHandle *static_handle,
         handle->fd3.str    = (char*)function_name;
         handle->fd4.str    = (char*)task_name;
     }
+
+
     return MFXTraceTextLog_DebugMessage(static_handle,
                                        file_name, line_num,
                                        function_name,
@@ -243,6 +266,8 @@ mfxTraceU32 MFXTraceTextLog_EndTask(mfxTraceStaticHandle *static_handle,
         function_name = handle->fd3.str;
         task_name     = handle->fd4.str;
     }
+
+
     return MFXTraceTextLog_DebugMessage(static_handle,
                                        file_name, line_num,
                                        function_name,
