@@ -46,6 +46,9 @@ FUNCTION_IMPL(CORE, GetHandle, (mfxSession session, mfxHandleType type, mfxHDL *
 
 mfxStatus MFXVideoCORE_QueryPlatform(mfxSession session, mfxPlatform* platform)
 {
+    MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_API, __FUNCTION__);
+    MFX_LTRACE_1(MFX_TRACE_LEVEL_API_PARAMS, "In:  session = ", MFX_TRACE_FORMAT_P, session);
+
     MFX_CHECK(session,                MFX_ERR_INVALID_HANDLE);
     MFX_CHECK(session->m_pCORE.get(), MFX_ERR_NOT_INITIALIZED);
     MFX_CHECK_NULL_PTR1(platform);
@@ -1435,6 +1438,8 @@ mfxStatus CommonCORE_VPL::UnlockExternalFrame(mfxMemId mid, mfxFrameData *ptr, b
 
 CommonCORE_VPL::CommonCORE_VPL(const mfxU32 numThreadsAvailable, const mfxSession session)
     : deprecate_from_base<CommonCORE>(numThreadsAvailable, session)
+    // At this point only object of CommonCORE_VPL exists, so it is CommonCORE_VPL::IsSupportedDelayAlloc being called
+    , m_frame_allocator_wrapper(IsSupportedDelayAlloc())
 {
     m_frame_allocator_wrapper.allocator_sw.reset(new FlexibleFrameAllocatorSW(nullptr, m_session));
 }
