@@ -106,6 +106,569 @@ mfx_device_item getDeviceItem(VADisplay pVaDisplay)
     return retDeviceItem;
 } // eMFXHWType getDeviceItem (VADisplay pVaDisplay)
 
+class VACopyWrapper
+{
+public:
+    enum eMode
+    {
+        VACOPY_UNSUPPORTED = -1
+        , VACOPY_VIDEO_TO_VIDEO
+        , VACOPY_SYSTEM_TO_VIDEO
+        , VACOPY_VIDEO_TO_SYSTEM
+    };
+
+    enum eEngine
+    {
+        INVALID = uint32_t(-1)
+        , BLT = VA_EXEC_MODE_POWER_SAVING
+        , VE = VA_EXEC_MODE_DEFAULT
+        , EU = VA_EXEC_MODE_PERFORMANCE
+        , DEFAULT = 0xff
+    };
+
+    struct FCCDesc
+    {
+        uint32_t VAFourcc;
+        std::function<void(const mfxFrameSurface1&, VASurfaceAttribExternalBuffers&, bool)> SetBuffers;
+        std::function<bool(const mfxFrameSurface1&)> CheckPlanes;
+    };
+
+    struct Buffer
+    {
+        bool bLocked = false;
+        std::vector<uint8_t> Buffer;
+    };
+
+    class SurfaceWrapper
+    {
+    public:
+        SurfaceWrapper(VADisplay dpy, const mfxFrameSurface1& surf, Buffer* pStagingBuffer, uint32_t copyEngine)
+            : m_dpy(dpy)
+        {
+            if (copyEngine == EU || copyEngine == BLT)
+                m_pitchAlign = 16;
+            else if(copyEngine == VE)
+                m_pitchAlign = 64;
+
+            if (pStagingBuffer)
+            {
+                m_pBuffer = &pStagingBuffer->Buffer;
+                AcquireSurface(surf);
+            }
+            else
+            {
+                m_id = *(VASurfaceID*)((mfxHDLPair*)surf.Data.MemId)->first;
+            }
+        }
+
+        ~SurfaceWrapper()
+        {
+            if (m_id != VA_INVALID_SURFACE && m_bDestroySurface)
+                std::ignore = MFX_STS_TRACE(vaDestroySurfaces(m_dpy, &m_id, 1));
+        }
+
+        VASurfaceID GetId() const
+        {
+            return m_id;
+        }
+
+        void CopyUserToStaging()
+        {
+            if (m_bUseStaging)
+                Copy(m_user, m_staging);
+        }
+
+        void CopyStagingToUser()
+        {
+            if (m_bUseStaging)
+                Copy(m_staging, m_user);
+        }
+
+    protected:
+        void AcquireSurface(const mfxFrameSurface1& surf)
+        {
+            auto& fcc = FccMap.at(surf.Info.FourCC);
+            VASurfaceAttrib attrib[3] = {};
+            VASurfaceAttribExternalBuffers eb = {};
+
+            attrib[0].flags         = VA_SURFACE_ATTRIB_SETTABLE;
+            attrib[0].type          = VASurfaceAttribPixelFormat;
+            attrib[0].value.type    = VAGenericValueTypeInteger;
+            attrib[0].value.value.i = fcc.VAFourcc;
+
+            attrib[1].flags         = VA_SURFACE_ATTRIB_SETTABLE;
+            attrib[1].type          = VASurfaceAttribMemoryType;
+            attrib[1].value.type    = VAGenericValueTypeInteger;
+            attrib[1].value.value.i = VA_SURFACE_ATTRIB_MEM_TYPE_USER_PTR;
+
+            attrib[2].flags         = VA_SURFACE_ATTRIB_SETTABLE;
+            attrib[2].type          = VASurfaceAttribExternalBufferDescriptor;
+            attrib[2].value.type    = VAGenericValueTypePointer;
+            attrib[2].value.value.p = (void*)&eb;
+
+            eb = SetBuffers(surf, fcc);
+
+            auto vaSts = vaCreateSurfaces(m_dpy, eb.pixel_format, eb.width, eb.height, &m_id, 1, attrib, 3);
+
+            if (vaSts != VA_STATUS_SUCCESS)
+                m_id = VA_INVALID_SURFACE;
+            else
+                m_bDestroySurface = true;
+        }
+
+        VASurfaceAttribExternalBuffers SetBuffers(const mfxFrameSurface1& surf, const VACopyWrapper::FCCDesc& fcc)
+        {
+            auto GetPlane0Size = [](const VASurfaceAttribExternalBuffers& eb)
+            {
+                return (eb.num_planes > 1 ? eb.offsets[1] : eb.data_size) - eb.offsets[0];
+            };
+            auto upBase        = uintptr_t(GetFramePointer(surf));
+            m_user.pixel_format = fcc.VAFourcc;
+            m_user.width        = surf.Info.Width;
+            m_user.height       = surf.Info.Height;
+            m_user.flags        = VA_SURFACE_ATTRIB_MEM_TYPE_USER_PTR;
+            m_user.buffers      = m_buffersUser;
+            m_user.buffers[0]   = (upBase - (upBase % BASE_ADDR_ALIGN));
+            m_user.offsets[0]   = (upBase - m_user.buffers[0]);
+
+            m_user.pitches[0]   = VACopyWrapper::GetPitch(surf);
+            m_user.num_buffers  = 1;
+
+            m_staging = m_user;
+
+            fcc.SetBuffers(surf, m_user, true);
+
+            m_bUseStaging =
+                   (!m_bOffsetSupported && m_user.offsets[0])                       // data offset from mem page start
+                || (!m_bOffsetSupported && (m_user.data_size % BASE_ADDR_ALIGN))    // data size alignment
+                || (m_user.pitches[0] % m_pitchAlign)                               // H-pitch
+                || ((GetPlane0Size(m_user) / m_user.pitches[0]) % m_pitchAlign)     // V-pitch
+                || !fcc.CheckPlanes(surf);                                          // continuous planes allocation
+
+            if (!m_bUseStaging)
+            {
+                m_staging = {};
+                return m_user;
+            }
+
+            m_staging.offsets[0] = 0;
+            m_staging.pitches[0] = mfx::align2_value(m_user.pitches[0], m_pitchAlign);
+
+            fcc.SetBuffers(surf, m_staging, false);
+
+            if(m_pBuffer->size() < (m_staging.data_size + BASE_ADDR_ALIGN))
+                m_pBuffer->resize(m_staging.data_size + BASE_ADDR_ALIGN);
+
+            m_staging.buffers    = m_buffersStaging;
+            m_staging.buffers[0] = uintptr_t(mfx::align2_value(uintptr_t(m_pBuffer->data()), BASE_ADDR_ALIGN));
+            m_staging.data_size  = mfx::align2_value(m_staging.data_size, BASE_ADDR_ALIGN);
+
+            return m_staging;
+        }
+
+        void Copy(const VASurfaceAttribExternalBuffers& src, VASurfaceAttribExternalBuffers& dst)
+        {
+            for (uint32_t plane = 0; plane < dst.num_planes; ++plane)
+            {
+                auto pSrc = (uint8_t*)(src.buffers[0] + src.offsets[plane]);
+                auto pDst = (uint8_t*)(dst.buffers[0] + dst.offsets[plane]);
+                auto hpitchSrc = src.pitches[plane];
+                auto hpitchDst = dst.pitches[plane];
+                auto vpitchSrc = (src.num_planes > (plane + 1))
+                    ? (src.offsets[plane + 1] - src.offsets[plane]) / hpitchSrc
+                    : (src.data_size - src.offsets[plane]) / hpitchSrc;
+                auto vpitchDst = (dst.num_planes > (plane + 1))
+                    ? (dst.offsets[plane + 1] - dst.offsets[plane]) / hpitchDst
+                    : (dst.data_size - dst.offsets[plane]) / hpitchDst;
+                auto roiW = std::min(hpitchSrc, hpitchDst);
+                auto roiH = std::min(vpitchSrc, vpitchDst);
+
+                for (uint32_t y = 0; y < roiH; ++y)
+                {
+                    std::copy(pSrc, pSrc + roiW, pDst);
+                    pSrc += hpitchSrc;
+                    pDst += hpitchDst;
+                }
+            }
+        }
+
+        static const uint32_t BASE_ADDR_ALIGN = 0x1000; // vaCreateSurfaces requires user ptr data to be aligned to memory page
+        bool m_bOffsetSupported = false; // is copy engine supports data offset from mem page start
+                                         // it looks like is unsupported by vaCreateSurfaces atm
+        uint32_t m_pitchAlign = 64; // copy engine requirements to both h-pitch and v-pitch
+        VADisplay m_dpy = nullptr;
+        VASurfaceID m_id = VA_INVALID_SURFACE;
+        VASurfaceAttribExternalBuffers m_user = {}, m_staging = {};
+        uintptr_t m_buffersUser[1] = {}, m_buffersStaging[1] = {};
+        bool m_bUseStaging = false;
+        std::vector<uint8_t>* m_pBuffer = nullptr;
+        bool m_bDestroySurface = false;
+    };
+
+    static const std::map<mfxU32, FCCDesc> FccMap;
+    VADisplay  m_dpy = nullptr;
+    uint32_t   m_copyEngine = INVALID;
+    uint32_t   m_copyEngineSupported = 0;
+
+    VACopyWrapper(VADisplay dpy)
+        : m_dpy(dpy)
+    {
+        int nAttr = vaMaxNumDisplayAttributes(m_dpy);
+
+        std::vector<VADisplayAttribute> attrs(nAttr);
+
+        if (VA_STATUS_SUCCESS != vaQueryDisplayAttributes(m_dpy, attrs.data(), &nAttr))
+            nAttr = 0;
+
+        auto itEnd = std::next(attrs.begin(), nAttr);
+        auto it = std::find_if(attrs.begin(), itEnd
+            , [](const VADisplayAttribute& attr) { return attr.type == VADisplayAttribCopy; });
+
+        if (it != itEnd)
+        {
+            m_copyEngineSupported = it->value;
+
+            if (m_copyEngineSupported & (1 << EU))
+                m_copyEngine = EU;
+            else if (m_copyEngineSupported & (1 << BLT))
+                m_copyEngine = BLT;
+            else if (m_copyEngineSupported & (1 << VE))
+                m_copyEngine = VE;
+        }
+    }
+
+    bool IsSupported() const
+    {
+        return m_dpy && m_copyEngine != INVALID;
+    }
+
+    eMode GetMode(const mfxFrameSurface1& src, const mfxFrameSurface1& dst) const
+    {
+        bool bSupported =
+               IsSupported()
+            && dst.Info.FourCC == src.Info.FourCC
+            && !dst.Info.Shift == !src.Info.Shift
+            && FccMap.count(dst.Info.FourCC)
+            ;
+
+        if (bSupported)
+        {
+            auto pSrc   = GetFramePointer(src);
+            auto pDst   = GetFramePointer(dst);
+            auto midSrc = src.Data.MemId;
+            auto midDst = dst.Data.MemId;
+
+            if (midSrc && midDst)
+                return VACOPY_VIDEO_TO_VIDEO;
+
+            if (pSrc && midDst)
+                return VACOPY_SYSTEM_TO_VIDEO;
+
+            if (midSrc && pDst)
+                return VACOPY_VIDEO_TO_SYSTEM;
+        }
+
+        return VACOPY_UNSUPPORTED;
+    }
+
+    mfxStatus Copy(const mfxFrameSurface1& src, const mfxFrameSurface1& dst, eEngine forceEngine = DEFAULT)
+    {
+        uint32_t copyEngine = (forceEngine == DEFAULT) ? m_copyEngine : uint32_t(forceEngine);
+
+        auto copyMode = GetMode(src, dst);
+        MFX_CHECK(copyMode != VACOPY_UNSUPPORTED, MFX_ERR_UNSUPPORTED);
+        MFX_CHECK(forceEngine == DEFAULT || ((1 << forceEngine) & m_copyEngineSupported), MFX_ERR_UNSUPPORTED);
+
+        if (   src.Info.Width != dst.Info.Width
+            || src.Info.Height != dst.Info.Height)
+            copyEngine = BLT;
+
+        auto pSrcBuffer = GetSrcBuffer(copyMode);
+        mfx::OnExit releaseSrc([&] { Release(pSrcBuffer); });
+
+        auto pDstBuffer = GetDstBuffer(copyMode);
+        mfx::OnExit releaseDst([&] { Release(pDstBuffer); });
+
+        SurfaceWrapper surfSrc(m_dpy, src, pSrcBuffer, copyEngine);
+        MFX_CHECK(surfSrc.GetId() != VA_INVALID_SURFACE, MFX_ERR_DEVICE_FAILED);
+
+        SurfaceWrapper surfDst(m_dpy, dst, pDstBuffer, copyEngine);
+        MFX_CHECK(surfDst.GetId() != VA_INVALID_SURFACE, MFX_ERR_DEVICE_FAILED);
+
+        surfSrc.CopyUserToStaging();
+
+        VACopyObject objSrc = {}, objDst = {};
+        VACopyOption opt = {};
+
+        objSrc.obj_type          = VACopyObjectSurface;
+        objSrc.object.surface_id = surfSrc.GetId();
+
+        objDst.obj_type          = VACopyObjectSurface;
+        objDst.object.surface_id = surfDst.GetId();
+
+        opt.bits.va_copy_mode = copyEngine;
+        opt.bits.va_copy_sync = VA_EXEC_SYNC;
+
+        auto vaCopySts = vaCopy(m_dpy, &objDst, &objSrc, opt);
+        MFX_CHECK(vaCopySts == VA_STATUS_SUCCESS, MFX_ERR_DEVICE_FAILED);
+
+        surfDst.CopyStagingToUser();
+
+        return MFX_ERR_NONE;
+    }
+
+    static bool IsSupportedByPlatform(eMFXHWType hw_type)
+    {
+        switch (hw_type)
+        {
+        case MFX_HW_PVC:
+        case MFX_HW_MTL:
+        case MFX_HW_DG2:
+            return true;
+        default:
+            return false;
+        }
+    }
+
+    static void SetBuffersNV12(const mfxFrameSurface1& surf, VASurfaceAttribExternalBuffers& eb, bool bUsePtrs)
+    {
+        eb.offsets[1] =
+            bUsePtrs
+            ? uint32_t(uintptr_t(surf.Data.UV) - eb.buffers[0])
+            : uint32_t(eb.pitches[0] * eb.height);
+        eb.pitches[1] = eb.pitches[0];
+        eb.num_planes = 2;
+        eb.data_size = eb.offsets[1] + (eb.height * eb.pitches[1] / 2);
+    }
+
+    static void SetBuffersYV12(const mfxFrameSurface1& surf, VASurfaceAttribExternalBuffers& eb, bool bUsePtrs)
+    {
+        eb.pitches[1] = eb.pitches[0] / 2;
+        eb.pitches[2] = eb.pitches[0] / 2;
+        if (bUsePtrs)
+        {
+            eb.offsets[1] = uint32_t(uintptr_t(surf.Data.V) - eb.buffers[0]);
+            eb.offsets[2] = uint32_t(uintptr_t(surf.Data.U) - eb.buffers[0]);
+        }
+        else
+        {
+            eb.offsets[1] = eb.offsets[0] + uint32_t(eb.height * eb.pitches[1] / 2);
+            eb.offsets[2] = eb.offsets[1] + uint32_t(eb.height * eb.pitches[2] / 2);
+        }
+        eb.num_planes = 3;
+        eb.data_size = eb.offsets[2] + (eb.height * eb.pitches[2] / 2);
+    }
+
+    static void SetBuffersOnePlane(const mfxFrameSurface1& surf, VASurfaceAttribExternalBuffers& eb, bool /*bUsePtrs*/)
+    {
+        eb.num_planes = 1;
+        eb.data_size = eb.offsets[0] + (eb.height * eb.pitches[0]);
+    }
+
+    template<uint32_t N>
+    static void SetBuffersNPlanes444(const mfxFrameSurface1& surf, VASurfaceAttribExternalBuffers& eb, bool bUsePtrs)
+    {
+        eb.num_planes = N;
+        if (bUsePtrs)
+        {
+            std::list<uintptr_t> ptrs({ uintptr_t(surf.Data.A), uintptr_t(surf.Data.B), uintptr_t(surf.Data.G), uintptr_t(surf.Data.R) });
+
+            ptrs.sort();
+            while (ptrs.size() >= N)
+                ptrs.pop_front();
+
+            for (uint32_t plane = 1; plane < eb.num_planes; ++plane)
+            {
+                eb.pitches[plane] = eb.pitches[0];
+                eb.offsets[plane] = uint32_t(ptrs.front() - eb.buffers[0]);
+                ptrs.pop_front();
+            }
+        }
+        else
+        {
+            for (uint32_t plane = 1; plane < eb.num_planes; ++plane)
+            {
+                eb.pitches[plane] = eb.pitches[0];
+                eb.offsets[plane] = uint32_t(eb.pitches[0] * eb.height);
+            }
+        }
+
+        eb.data_size = eb.offsets[N - 1] + (eb.height * eb.pitches[0]);
+    }
+
+    static uint32_t GetPitch(const mfxFrameSurface1& surf)
+    {
+        return (surf.Data.PitchHigh << 16) + surf.Data.PitchLow;
+    }
+
+    static bool CheckPlanesNV12(const mfxFrameSurface1& surf)
+    {
+        uint32_t  pitch = GetPitch(surf);
+        ptrdiff_t offset = surf.Data.UV - (surf.Data.Y + surf.Info.Height * pitch);
+        return offset == 0;
+    }
+
+    static bool CheckPlanesYV12(const mfxFrameSurface1& surf)
+    {
+        uint32_t  pitch   = GetPitch(surf);
+        ptrdiff_t offsetV = surf.Data.V - (surf.Data.Y + surf.Info.Height * pitch);
+        ptrdiff_t offsetU = surf.Data.U - (surf.Data.V + surf.Info.Height * pitch / 4);
+        return offsetV == 0 && offsetU == 0;
+    }
+
+    static bool CheckPlanes444(const mfxFrameSurface1& surf)
+    {
+        uint32_t pitch = GetPitch(surf);
+        std::list<uintptr_t> ptrs({ uintptr_t(surf.Data.A), uintptr_t(surf.Data.B), uintptr_t(surf.Data.G), uintptr_t(surf.Data.R) });
+        ptrs.sort();
+        ptrs.remove(0);
+
+        while (ptrs.size() >= 2)
+        {
+            uintptr_t ptr0 = ptrs.front();
+            ptrs.pop_front();
+
+            if (ptrs.front() != (ptr0 + pitch * surf.Info.Height))
+                return false;
+        }
+
+        return true;
+    }
+
+    static bool CheckPlanesOne(const mfxFrameSurface1&)
+    {
+        return true;
+    }
+
+    static bool IsTwoPlanesFormat(mfxU32 fourcc)
+    {
+        return fourcc == MFX_FOURCC_NV12
+            || fourcc == MFX_FOURCC_P010
+            || fourcc == MFX_FOURCC_P016;
+    }
+
+    static bool IsVaCopySupportSurface(const mfxFrameSurface1& dst_surface, const mfxFrameSurface1& src_surface)
+    {
+        auto CheckOneSurface = [](const mfxFrameSurface1& sw_surface)
+        {
+            // Only start addresses with 4k aligment for UsrPtr surface are supported, refer: https://dri.freedesktop.org/docs/drm/gpu/driver-uapi.html#c.drm_i915_gem_userptr
+            if ((size_t)sw_surface.Data.Y % BASE_ADDR_ALIGN)
+                return false;
+
+            // Pitch should be 16-aligned
+            if (sw_surface.Data.Pitch % 16)
+                return false;
+
+            // Pixel data is stored continuously for chroma and Luma for multiplane format.
+            if (!IsTwoPlanesFormat(sw_surface.Info.FourCC))
+                return true;
+
+            // Two planes format
+            size_t luma_size_in_bytes_aligned = sw_surface.Data.Pitch * mfx::align2_value(sw_surface.Info.Height, 32);
+            size_t luma_size_in_bytes         = sw_surface.Data.Pitch * mfx::align2_value(sw_surface.Info.Height, 1);
+            // Assume that frame data is stored in continuous chunk (Chroma right after Luma)
+            // use relative offset between UV and Y, not pitch * height
+            // Two cases need to be checked:
+            // 1. Height 32 aligned, e.g, internal allocator need this path
+            // 2. Height not aligned, i.e., app uses specific allocator without alignment.
+            // vaCopy can't support the two planes' formats which are not stored continuously.
+            // App need copy each plane as 1 plane format if it still keep Luma/ chroma plan using noncontinuous chunk.
+
+            return (sw_surface.Data.Y + luma_size_in_bytes_aligned == sw_surface.Data.UV)
+                || (sw_surface.Data.Y + luma_size_in_bytes         == sw_surface.Data.UV);
+        };
+
+        // SW to SW copy is not supported
+        if (dst_surface.Data.Y && src_surface.Data.Y)
+            return false;
+
+        // If dst surface is in SW memory, check it's data layout
+        if (dst_surface.Data.Y && !CheckOneSurface(dst_surface))
+            return false;
+
+        // If src surface is in SW memory, check it's data layout
+        if (src_surface.Data.Y && !CheckOneSurface(src_surface))
+            return false;
+
+        return true;
+    }
+
+protected:
+    static const uint32_t VACOPY_CACHE_SIZE    = 3;
+    static const uint32_t VACOPY_CACHE_WAIT_MS = 2000;
+    std::mutex m_mtx;
+    std::condition_variable m_cv;
+    Buffer m_buffer[VACOPY_CACHE_SIZE];
+
+    Buffer* GetBuffer()
+    {
+        std::unique_lock<std::mutex> lock(m_mtx);
+        Buffer* pBuffer = nullptr;
+        auto FindFreeBuffer = [&]()
+        {
+            for (auto& buf : m_buffer)
+            {
+                if (!buf.bLocked)
+                {
+                    buf.bLocked = true;
+                    pBuffer = &buf;
+                    return true;
+                }
+            }
+            return false;
+        };
+
+        auto waitTime = std::chrono::milliseconds(VACOPY_CACHE_WAIT_MS);
+        MFX_CHECK_WITH_THROW_STS(m_cv.wait_for(lock, waitTime, FindFreeBuffer), MFX_ERR_UNKNOWN);
+
+        return pBuffer;
+    }
+
+    Buffer* GetSrcBuffer(eMode mode)
+    {
+        if (mode == VACOPY_SYSTEM_TO_VIDEO)
+            return GetBuffer();
+        return nullptr;
+    }
+
+    Buffer* GetDstBuffer(eMode mode)
+    {
+        if (mode == VACOPY_VIDEO_TO_SYSTEM)
+            return GetBuffer();
+        return nullptr;
+    }
+
+    void Release(Buffer* pBuffer)
+    {
+        if (pBuffer)
+        {
+            {
+                std::unique_lock<std::mutex> lock(m_mtx);
+                pBuffer->bLocked = false;
+            }
+            m_cv.notify_one();
+        }
+    }
+};
+
+const std::map<mfxU32, VACopyWrapper::FCCDesc> VACopyWrapper::FccMap =
+{
+      { MFX_FOURCC_NV12,    { VA_FOURCC_NV12,        SetBuffersNV12,          CheckPlanesNV12 } }
+    , { MFX_FOURCC_YV12,    { VA_FOURCC_YV12,        SetBuffersYV12,          CheckPlanesYV12 } }
+    , { MFX_FOURCC_P010,    { VA_FOURCC_P010,        SetBuffersNV12,          CheckPlanesNV12 } }
+    , { MFX_FOURCC_P016,    { VA_FOURCC_P016,        SetBuffersNV12,          CheckPlanesNV12 } }
+    , { MFX_FOURCC_YUY2,    { VA_FOURCC_YUY2,        SetBuffersOnePlane,      CheckPlanesOne } }
+    , { MFX_FOURCC_RGB565,  { VA_FOURCC_RGB565,      SetBuffersOnePlane,      CheckPlanesOne } }
+    , { MFX_FOURCC_RGBP,    { VA_FOURCC_RGBP,        SetBuffersNPlanes444<3>, CheckPlanes444 } }
+    , { MFX_FOURCC_BGRP,    { VA_FOURCC_BGRP,        SetBuffersNPlanes444<3>, CheckPlanes444 } }
+    , { MFX_FOURCC_A2RGB10, { VA_FOURCC_A2R10G10B10, SetBuffersOnePlane,      CheckPlanesOne } }
+    , { MFX_FOURCC_AYUV,    { VA_FOURCC_AYUV,        SetBuffersOnePlane,      CheckPlanesOne } }
+    , { MFX_FOURCC_Y210,    { VA_FOURCC_Y210,        SetBuffersOnePlane,      CheckPlanesOne } }
+    , { MFX_FOURCC_Y216,    { VA_FOURCC_Y216,        SetBuffersOnePlane,      CheckPlanesOne } }
+    , { MFX_FOURCC_Y410,    { VA_FOURCC_Y410,        SetBuffersOnePlane,      CheckPlanesOne } }
+    , { MFX_FOURCC_Y416,    { VA_FOURCC_Y416,        SetBuffersOnePlane,      CheckPlanesOne } }
+};
+
 template <class Base>
 VAAPIVideoCORE_T<Base>::VAAPIVideoCORE_T(
     const mfxU32 adapterNum,
@@ -262,7 +825,16 @@ mfxStatus VAAPIVideoCORE_T<Base>::SetHandle(
             m_GTConfig       = devItem.config;
             this->m_deviceId = mfxU16(devItem.device_id);
 
-            std::ignore = MFX_STS_TRACE(TryInitializeCm());
+            std::ignore = MFX_STS_TRACE(TryInitializeCm(false));
+
+            if (VACopyWrapper::IsSupportedByPlatform(m_HWType))
+            {
+                this->m_pVaCopy.reset(new VACopyWrapper(*m_p_display_wrapper));
+                if (!this->m_pVaCopy->IsSupported())
+                {
+                    this->m_pVaCopy.reset();
+                }
+            }
         }
             break;
 
@@ -286,25 +858,42 @@ bool VAAPIVideoCORE_T<Base>::IsCmSupported()
 template <class Base>
 bool VAAPIVideoCORE_T<Base>::IsCmCopyEnabledByDefault()
 {
-    // For Linux by default CM copy is ON on RKL/ADL
-    return IsCmSupported() && GetHWType() != MFX_HW_DG1 && GetHWType() != MFX_HW_TGL_LP;
+    // For Linux by default CM copy is ON on RKL/ADL-S
+    return IsCmSupported() && GetHWType() != MFX_HW_DG1 && GetHWType() != MFX_HW_TGL_LP && GetHWType() != MFX_HW_ADL_P;
 }
 
 template <class Base>
-mfxStatus VAAPIVideoCORE_T<Base>::TryInitializeCm()
+mfxStatus VAAPIVideoCORE_T<Base>::TryInitializeCm(bool force_cm_device_creation)
 {
     if (m_pCmCopy)
         return MFX_ERR_NONE;
 
-    // Return immediately if user requested to turn OFF GPU copy
-    if (m_ForcedCmState == MFX_GPUCOPY_OFF)
+    // Return immediately if user requested to turn OFF GPU copy.
+    // Device creation may be forced, since other components may need the device for non-copy kernels
+    if (m_ForcedGpuCopyState == MFX_GPUCOPY_OFF && !force_cm_device_creation)
     {
         return MFX_ERR_NONE;
     }
 
     MFX_CHECK(IsCmSupported(), MFX_WRN_INCOMPATIBLE_VIDEO_PARAM);
 
-    std::unique_ptr<CmCopyWrapper> tmp_cm(new CmCopyWrapper);
+    // Copy wrapper creation can be forced, since CM device depends on copy wrapper. Other component may require CM device.
+    // VPP is calling QueryCoreInterface<CmDevice>, if copy wrapper isn't created, then CM device cannot be obtained.
+    // If copy force state is default and CM copy disabled by default, set copy force state as off.
+    if (m_ForcedGpuCopyState == MFX_GPUCOPY_DEFAULT && !IsCmCopyEnabledByDefault())
+    {
+        m_ForcedGpuCopyState = MFX_GPUCOPY_OFF;
+    }
+/*
+// Uncomment after additional changes
+#ifdef ONEVPL_EXPERIMENTAL
+    bool use_cm_buffer_cache = m_ForcedGpuCopyState != MFX_GPUCOPY_SAFE;
+#else
+    bool use_cm_buffer_cache = true;
+#endif
+*/
+    bool use_cm_buffer_cache = false;
+    std::unique_ptr<CmCopyWrapper> tmp_cm(new CmCopyWrapper(use_cm_buffer_cache));
 
     MFX_CHECK_NULL_PTR1(tmp_cm->GetCmDevice(*m_p_display_wrapper));
 
@@ -525,12 +1114,12 @@ mfxStatus VAAPIVideoCORE_T<Base>::GetVAService(
 } // mfxStatus VAAPIVideoCORE_T<Base>::GetVAService(...)
 
 template <class Base>
-void VAAPIVideoCORE_T<Base>::SetCmCopyStatus(bool enable)
+void VAAPIVideoCORE_T<Base>::SetCmCopyMode(mfxU16 cm_copy_mode)
 {
     UMC::AutomaticUMCMutex guard(this->m_guard);
 
-    m_ForcedCmState = enable ? MFX_GPUCOPY_ON : MFX_GPUCOPY_OFF;
-} // void VAAPIVideoCORE_T<Base>::SetCmCopyStatus(...)
+    m_ForcedGpuCopyState = cm_copy_mode;
+} // void VAAPIVideoCORE_T<Base>::SetCmCopyMode(...)
 
 template <class Base>
 mfxStatus VAAPIVideoCORE_T<Base>::CreateVideoAccelerator(
@@ -590,6 +1179,7 @@ mfxStatus VAAPIVideoCORE_T<Base>::CreateVideoAccelerator(
     m_pVA->m_Platform   = UMC::VA_LINUX;
     m_pVA->m_Profile    = (VideoAccelerationProfile)profile;
     m_pVA->m_HWPlatform = m_HWType;
+    m_pVA->m_HWDeviceID = this->m_deviceId;
 
     Status st = m_pVA->Init(&params);
     MFX_CHECK(st == UMC_OK, MFX_ERR_UNSUPPORTED);
@@ -809,8 +1399,8 @@ mfxStatus VAAPIVideoCORE_T<Base>::DoFastCopyExtended(
         return MFX_ERR_UNDEFINED_BEHAVIOR;
     }
 
-    // For Linux, if CM copy is forced to be used, or if choose to use default copy method and CM copy is enabled by default, use CM copy.
-    bool canUseCMCopy = (gpuCopyMode & MFX_COPY_USE_CM) && m_pCmCopy && (m_ForcedCmState == MFX_GPUCOPY_ON || (m_ForcedCmState == MFX_GPUCOPY_DEFAULT && IsCmCopyEnabledByDefault())) && CmCopyWrapper::CanUseCmCopy(pDst, pSrc);
+    // Check if requested copy backend is CM and CM is capable to perform copy
+    bool canUseCMCopy = (gpuCopyMode & MFX_COPY_USE_CM) && m_pCmCopy && (m_ForcedGpuCopyState != MFX_GPUCOPY_OFF) && CmCopyWrapper::CanUseCmCopy(pDst, pSrc);
 
     if (NULL != pSrc->Data.MemId && NULL != pDst->Data.MemId)
     {
@@ -819,7 +1409,7 @@ mfxStatus VAAPIVideoCORE_T<Base>::DoFastCopyExtended(
             // If CM copy failed, fallback to VA copy
             MFX_RETURN_IF_ERR_NONE(m_pCmCopy->CopyVideoToVideo(pDst, pSrc));
             // Remove CM adapter in case of failed copy
-            this->SetCmCopyStatus(false);
+            this->SetCmCopyMode(MFX_GPUCOPY_OFF);
         }
 
         VASurfaceID *va_surf_src = (VASurfaceID*)(((mfxHDLPair *)pSrc->Data.MemId)->first);
@@ -828,19 +1418,25 @@ mfxStatus VAAPIVideoCORE_T<Base>::DoFastCopyExtended(
 
         VAImage va_img_src = {};
         VAStatus va_sts;
-
-        va_sts = vaDeriveImage(*m_p_display_wrapper, *va_surf_src, &va_img_src);
+        {
+            PERF_UTILITY_AUTO("vaDeriveImage", PERF_LEVEL_DDI);
+            va_sts = vaDeriveImage(*m_p_display_wrapper, *va_surf_src, &va_img_src);
+        }
         MFX_CHECK(VA_STATUS_SUCCESS == va_sts, MFX_ERR_DEVICE_FAILED);
 
         {
             MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_EXTCALL, "vaPutImage");
+            PERF_UTILITY_AUTO("vaPutImage", PERF_LEVEL_DDI);
             va_sts = vaPutImage(*m_p_display_wrapper, *va_surf_dst, va_img_src.image_id,
                                 0, 0, roi.width, roi.height,
                                 0, 0, roi.width, roi.height);
         }
         MFX_CHECK(VA_STATUS_SUCCESS == va_sts, MFX_ERR_DEVICE_FAILED);
 
-        va_sts = vaDestroyImage(*m_p_display_wrapper, va_img_src.image_id);
+        {
+            PERF_UTILITY_AUTO("vaDestroyImage", PERF_LEVEL_DDI);
+            va_sts = vaDestroyImage(*m_p_display_wrapper, va_img_src.image_id);
+        }
         MFX_CHECK(VA_STATUS_SUCCESS == va_sts, MFX_ERR_DEVICE_FAILED);
     }
     else if (nullptr != pSrc->Data.MemId && nullptr != dstPtr)
@@ -852,7 +1448,7 @@ mfxStatus VAAPIVideoCORE_T<Base>::DoFastCopyExtended(
                 // If CM copy failed, fallback to VA copy
                 MFX_RETURN_IF_ERR_NONE(m_pCmCopy->CopyVideoToSys(pDst, pSrc));
                 // Remove CM adapter in case of failed copy
-                this->SetCmCopyStatus(false);
+                this->SetCmCopyMode(MFX_GPUCOPY_OFF);
             }
 
             VASurfaceID *va_surface = (VASurfaceID*)(((mfxHDLPair *)pSrc->Data.MemId)->first);
@@ -865,6 +1461,7 @@ mfxStatus VAAPIVideoCORE_T<Base>::DoFastCopyExtended(
 
             {
                 MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_EXTCALL, "vaMapBuffer");
+                PERF_UTILITY_AUTO("vaMapBuffer", PERF_LEVEL_DDI);
                 va_sts = vaMapBuffer(*m_p_display_wrapper, va_image.buf, (void **) &pBits);
             }
             MFX_CHECK(VA_STATUS_SUCCESS == va_sts, MFX_ERR_DEVICE_FAILED);
@@ -887,11 +1484,14 @@ mfxStatus VAAPIVideoCORE_T<Base>::DoFastCopyExtended(
 
             {
                 MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_EXTCALL, "vaUnmapBuffer");
+                PERF_UTILITY_AUTO("vaUnmapBuffer", PERF_LEVEL_DDI);
                 va_sts = vaUnmapBuffer(*m_p_display_wrapper, va_image.buf);
             }
             MFX_CHECK(VA_STATUS_SUCCESS == va_sts, MFX_ERR_DEVICE_FAILED);
-
-            va_sts = vaDestroyImage(*m_p_display_wrapper, va_image.image_id);
+            {
+                PERF_UTILITY_AUTO("vaDestroyImage", PERF_LEVEL_DDI);
+                va_sts = vaDestroyImage(*m_p_display_wrapper, va_image.image_id);
+            }
             MFX_CHECK(VA_STATUS_SUCCESS == va_sts, MFX_ERR_DEVICE_FAILED);
         }
 
@@ -911,7 +1511,7 @@ mfxStatus VAAPIVideoCORE_T<Base>::DoFastCopyExtended(
             // If CM copy failed, fallback to VA copy
             MFX_RETURN_IF_ERR_NONE(m_pCmCopy->CopySysToVideo(pDst, pSrc));
             // Remove CM adapter in case of failed copy
-            this->SetCmCopyStatus(false);
+            this->SetCmCopyMode(MFX_GPUCOPY_OFF);
         }
 
         VAStatus va_sts = VA_STATUS_SUCCESS;
@@ -924,6 +1524,7 @@ mfxStatus VAAPIVideoCORE_T<Base>::DoFastCopyExtended(
 
         {
             MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_EXTCALL, "vaMapBuffer");
+            PERF_UTILITY_AUTO("vaMapBuffer", PERF_LEVEL_DDI);
             va_sts = vaMapBuffer(*m_p_display_wrapper, va_image.buf, (void **) &pBits);
         }
         MFX_CHECK(VA_STATUS_SUCCESS == va_sts, MFX_ERR_DEVICE_FAILED);
@@ -947,12 +1548,16 @@ mfxStatus VAAPIVideoCORE_T<Base>::DoFastCopyExtended(
 
         {
             MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_EXTCALL, "vaUnmapBuffer");
+            PERF_UTILITY_AUTO("vaUnmapBuffer", PERF_LEVEL_DDI);
             va_sts = vaUnmapBuffer(*m_p_display_wrapper, va_image.buf);
         }
         MFX_CHECK(VA_STATUS_SUCCESS == va_sts, MFX_ERR_DEVICE_FAILED);
 
         // vaDestroyImage
-        va_sts = vaDestroyImage(*m_p_display_wrapper, va_image.image_id);
+        {
+            PERF_UTILITY_AUTO("vaDestroyImage", PERF_LEVEL_DDI);
+            va_sts = vaDestroyImage(*m_p_display_wrapper, va_image.image_id);
+        }
         MFX_CHECK(VA_STATUS_SUCCESS == va_sts, MFX_ERR_DEVICE_FAILED);
     }
     else
@@ -1098,7 +1703,7 @@ void* VAAPIVideoCORE_T<Base>::QueryCoreInterface(const MFX_GUID &guid)
         if (!m_pCmCopy)
         {
             UMC::AutomaticUMCMutex guard(this->m_guard);
-            MFX_CHECK_STS_RET_NULL(TryInitializeCm());
+            MFX_CHECK_STS_RET_NULL(TryInitializeCm(true));
         }
 
         return m_pCmCopy ? (void*)m_pCmCopy->GetCmDevice(*m_p_display_wrapper) : nullptr;
@@ -1109,7 +1714,7 @@ void* VAAPIVideoCORE_T<Base>::QueryCoreInterface(const MFX_GUID &guid)
         if (!m_pCmCopy)
         {
             UMC::AutomaticUMCMutex guard(this->m_guard);
-            MFX_CHECK_STS_RET_NULL(TryInitializeCm());
+            MFX_CHECK_STS_RET_NULL(TryInitializeCm(false));
         }
 
         return (void*)m_pCmCopy.get();
@@ -1302,8 +1907,32 @@ VAAPIVideoCORE_VPL::DoFastCopyExtended(
     // check that region of interest is valid
     MFX_CHECK(roi.width && roi.height, MFX_ERR_UNDEFINED_BEHAVIOR);
 
-    // For Linux, if CM copy is forced to be used, or if choose to use default copy method and CM copy is enabled by default, use CM copy.
-    bool canUseCMCopy = (gpuCopyMode & MFX_COPY_USE_CM) && m_pCmCopy && (m_ForcedCmState == MFX_GPUCOPY_ON || (m_ForcedCmState == MFX_GPUCOPY_DEFAULT && IsCmCopyEnabledByDefault())) && CmCopyWrapper::CanUseCmCopy(pDst, pSrc);
+    // Check if requested copy backend is CM and CM is capable to perform copy
+    bool canUseCMCopy = (gpuCopyMode & MFX_COPY_USE_CM) && m_pCmCopy && (m_ForcedGpuCopyState != MFX_GPUCOPY_OFF) && CmCopyWrapper::CanUseCmCopy(pDst, pSrc);
+
+    if (m_pVaCopy && (VACopyWrapper::IsVaCopySupportSurface(*pDst, *pSrc)) && (gpuCopyMode & MFX_COPY_USE_VACOPY_ANY) && (m_ForcedGpuCopyState != MFX_GPUCOPY_OFF))
+    {
+        auto vacopyMode =
+            ((gpuCopyMode & MFX_COPY_USE_VACOPY_ANY) == MFX_COPY_USE_VACOPY_ANY) ? VACopyWrapper::DEFAULT
+            : (gpuCopyMode & MFX_COPY_USE_VACOPY_EU) ? VACopyWrapper::EU
+            : (gpuCopyMode & MFX_COPY_USE_VACOPY_BLT) ? VACopyWrapper::BLT
+            : VACopyWrapper::VE
+            ;
+
+        if (m_HWType == MFX_HW_DG2)
+        {
+            vacopyMode = VACopyWrapper::BLT;
+        }
+
+        auto vaCopySts = m_pVaCopy->Copy(*pSrc, *pDst, vacopyMode);
+        MFX_RETURN_IF_ERR_NONE(vaCopySts);
+
+        if (vaCopySts == MFX_ERR_DEVICE_FAILED)
+        {
+            UMC::AutomaticUMCMutex guard(this->m_guard);
+            m_pVaCopy.reset(); //once failed, don't try to use it anymore
+        }
+    }
 
     if (NULL != pSrc->Data.MemId && NULL != pDst->Data.MemId)
     {
@@ -1313,7 +1942,7 @@ VAAPIVideoCORE_VPL::DoFastCopyExtended(
             // If CM copy failed, fallback to VA copy
             MFX_RETURN_IF_ERR_NONE(m_pCmCopy->CopyVideoToVideo(pDst, pSrc));
             // Remove CM adapter in case of failed copy
-            this->SetCmCopyStatus(false);
+            this->SetCmCopyMode(MFX_GPUCOPY_OFF);
         }
         // Fallback to VA copy in case of failed CM copy
 
@@ -1329,6 +1958,7 @@ VAAPIVideoCORE_VPL::DoFastCopyExtended(
 
         {
             MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_EXTCALL, "vaPutImage");
+            PERF_UTILITY_AUTO("vaPutImage", PERF_LEVEL_DDI);
             VAStatus va_sts = vaPutImage(*m_p_display_wrapper, *va_surf_dst, src_lock.m_image.image_id,
                 0, 0, roi.width, roi.height,
                 0, 0, roi.width, roi.height);
@@ -1346,7 +1976,7 @@ VAAPIVideoCORE_VPL::DoFastCopyExtended(
             // If CM copy failed, fallback to VA copy
             MFX_RETURN_IF_ERR_NONE(m_pCmCopy->CopyVideoToSys(pDst, pSrc));
             // Remove CM adapter in case of failed copy
-            this->SetCmCopyStatus(false);
+            this->SetCmCopyMode(MFX_GPUCOPY_OFF);
         }
         // Fallback to SW copy in case of failed CM copy
 
@@ -1398,7 +2028,7 @@ VAAPIVideoCORE_VPL::DoFastCopyExtended(
             // If CM copy failed, fallback to VA copy
             MFX_RETURN_IF_ERR_NONE(m_pCmCopy->CopySysToVideo(pDst, pSrc));
             // Remove CM adapter in case of failed copy
-            this->SetCmCopyStatus(false);
+            this->SetCmCopyMode(MFX_GPUCOPY_OFF);
         }
         // Fallback to SW copy in case of failed CM copy
 
@@ -1449,7 +2079,6 @@ mfxStatus VAAPIVideoCORE_VPL::CreateSurface(mfxU16 type, const mfxFrameInfo& inf
     return m_frame_allocator_wrapper.CreateSurface(type, info, surf);
 }
 
-template class VAAPIVideoCORE_T<CommonCORE  >;
 template class VAAPIVideoCORE_T<CommonCORE_VPL>;
 
 /* EOF */
