@@ -165,6 +165,11 @@ namespace UMC_AV1_DECODER
         void Displayed(bool d)
         { displayed = d; }
 
+        bool DpbUpdated() const
+        { return dpb_updated; }
+        void DpbUpdated(bool u)
+        { dpb_updated = u; }
+
         bool Repeated() const
         { return repeated; }
         void Repeated(bool d)
@@ -257,6 +262,7 @@ namespace UMC_AV1_DECODER
                                                      // after it frame still may remain in [AV1Decoder::dpb], but only as reference
 
         bool                              repeated;
+        bool                              dpb_updated;
         bool                              decoding_started;     // set in [application thread] right after frame submission to the driver started
         bool                              decoding_completed;   // set in [scheduler thread] after getting driver status report for the frame
 
