@@ -499,7 +499,11 @@ namespace UMC_AV1_DECODER
         // Identify the nearest forward and backward references.
         for (int32_t i = 0; i < INTER_REFS; ++i)
         {
-            FrameHeader const& refHdr = frameDpb[fh.ref_frame_idx[i]]->GetFrameHeader();
+            AV1DecoderFrame *pFrame = frameDpb[fh.ref_frame_idx[i]];
+            if (!pFrame || pFrame->UID == -1)
+                continue;
+
+            FrameHeader const& refHdr = pFrame->GetFrameHeader();
             const uint32_t refOrderHint = refHdr.order_hint;
 
             if (av1_get_relative_dist(sh, refOrderHint, fh.order_hint) < 0)
@@ -1697,6 +1701,7 @@ namespace UMC_AV1_DECODER
 
         AV1D_LOG("[+]: %d", (uint32_t)BitsDecoded());
 
+        fh.current_frame_id = PreFrame_id;
         if (sh.reduced_still_picture_header)
         {
             fh.frame_type = KEY_FRAME;
@@ -1722,11 +1727,11 @@ namespace UMC_AV1_DECODER
                         assert("Frame_to_show is absent in DPB or invalid!");
                     }
 
-                    fh.current_frame_id = fh.display_frame_id;
                 }
 
                 if (refHdr.frame_type == KEY_FRAME)
                 {
+                    fh.current_frame_id = refHdr.current_frame_id;
                     refHdr.refresh_frame_flags = 255;
                 }
 
@@ -1735,7 +1740,7 @@ namespace UMC_AV1_DECODER
                 fh.FrameHeight = refHdr.FrameHeight;
 
                 fh.show_frame = 1;
-
+                PreFrame_id = fh.current_frame_id;
                 AV1D_LOG("[-]: %d", (uint32_t)BitsDecoded());
 
                 return;
@@ -1761,7 +1766,10 @@ namespace UMC_AV1_DECODER
         if (fh.frame_type == KEY_FRAME && !frameDpb.empty())
         {
             for (int i = 0; i < NUM_REF_FRAMES; i++)
-                frameDpb[i]->SetRefValid(false);
+                if (frameDpb[i] != nullptr)
+                {
+                    frameDpb[i]->SetRefValid(false);
+                }                
         }
 
         if (fh.frame_type != KEY_FRAME)
