@@ -102,6 +102,7 @@ namespace UMC_AV1_DECODER
     {
         error = 0;
         displayed = false;
+        dpb_updated = false;
         repeated = false;
         outputted = false;
         decoded   = false;
@@ -113,8 +114,8 @@ namespace UMC_AV1_DECODER
         data[SURFACE_RECON].reset();
         tile_sets.resize(0);
 
-        *seq_header.get() = SequenceHeader{};
-        *header.get() = FrameHeader{};
+        seq_header.reset(new SequenceHeader{});
+        header.reset(new FrameHeader{});
         header->display_frame_id = (std::numeric_limits<uint32_t>::max)();
 
         ResetRefCounter();
