@@ -214,6 +214,7 @@ enum // usual int
     MAX_NUM_REF_FRAMES  = 32,
     MAX_NUM_REF_FIELDS  = 32,
 
+    MAX_NUM_MMCO_ENTRIES = 35,
     MAX_REF_FRAMES_IN_POC_CYCLE = 256,
 
     MAX_NUM_SLICE_GROUPS        = 8,
@@ -789,8 +790,8 @@ struct RefPicListReorderInfo
 struct AdaptiveMarkingInfo
 {
     uint32_t       num_entries;                 // number of currently valid mmco,value pairs
-    uint8_t        mmco[UMC::MAX_NUM_REF_FRAMES];    // memory management control operation id
-    uint32_t       value[UMC::MAX_NUM_REF_FRAMES*2]; // operation-dependent data, max 2 per operation
+    uint8_t        mmco[UMC::MAX_NUM_MMCO_ENTRIES];    // memory management control operation id
+    uint32_t       value[UMC::MAX_NUM_MMCO_ENTRIES *2]; // operation-dependent data, max 2 per operation
 };
 
 struct PredWeightTable
