@@ -240,12 +240,12 @@ mfxStatus MFXTaskSupplier::RunThread(mfxU32 threadNumber)
     if (sts == UMC_ERR_NOT_ENOUGH_DATA)
         return MFX_TASK_BUSY;
     else if(sts == UMC_ERR_DEVICE_FAILED)
-        return MFX_ERR_DEVICE_FAILED;
+        MFX_RETURN(MFX_ERR_DEVICE_FAILED)
     else if (sts == UMC_ERR_GPU_HANG)
-        return MFX_ERR_GPU_HANG;
+        MFX_RETURN(MFX_ERR_GPU_HANG);
 
     if (sts != UMC_OK)
-        return MFX_ERR_UNDEFINED_BEHAVIOR;
+        MFX_RETURN(MFX_ERR_UNDEFINED_BEHAVIOR);
 
     return MFX_TASK_WORKING;
 }
@@ -385,6 +385,7 @@ Status MFXTaskSupplier::DecodeSEI(NalUnit *nalUnit)
         swapper->SwapMemory(&swappedMem, &mem, DEFAULT_NU_HEADER_TAIL_VALUE);
 
         bitStream.Reset((uint8_t*)swappedMem.GetPointer(), (uint32_t)swappedMem.GetDataSize());
+        bitStream.SetTailBsSize(DEFAULT_NU_TAIL_SIZE);
 
         NAL_Unit_Type nal_unit_type = NAL_UT_UNSPECIFIED;
         uint32_t nal_ref_idc = 0;
@@ -1177,12 +1178,12 @@ mfxStatus MFX_Utility::Query(VideoCORE *core, mfxVideoParam *in, mfxVideoParam *
             int codecProfile = in->mfx.CodecProfile & 0xFF;
             if (    (codecProfile == MFX_PROFILE_AVC_STEREO_HIGH) ||
                     (codecProfile == MFX_PROFILE_AVC_MULTIVIEW_HIGH))
-                return MFX_ERR_UNSUPPORTED;
+                MFX_RETURN(MFX_ERR_UNSUPPORTED);
 
 #ifdef MFX_ENABLE_SVC_VIDEO_DECODE
             if (    (codecProfile == MFX_PROFILE_AVC_SCALABLE_BASELINE) ||
                     (codecProfile == MFX_PROFILE_AVC_SCALABLE_HIGH) )
-                return MFX_ERR_UNSUPPORTED;
+                MFX_RETURN(MFX_ERR_UNSUPPORTED);
 #endif
         }
 
@@ -1592,7 +1593,7 @@ mfxStatus MFX_Utility::Query(VideoCORE *core, mfxVideoParam *in, mfxVideoParam *
         if (GetPlatform(core, out) != core->GetPlatformType() && sts == MFX_ERR_NONE)
         {
             assert(GetPlatform(core, out) == MFX_PLATFORM_SOFTWARE);
-            sts = MFX_WRN_PARTIAL_ACCELERATION;
+            sts = MFX_ERR_UNSUPPORTED;
         }
 #ifndef MFX_DEC_VIDEO_POSTPROCESS_DISABLE
         /*SFC*/
