@@ -405,6 +405,7 @@ Status LinuxVideoAccelerator::Init(VideoAcceleratorParams* pInfo)
         {
             va_profiles    = new VAProfile[va_max_num_profiles];
             va_entrypoints = new VAEntrypoint[va_max_num_entrypoints];
+            PERF_UTILITY_AUTO("vaQueryConfigProfiles", PERF_LEVEL_DDI);
             va_res = vaQueryConfigProfiles(m_dpy, va_profiles, &va_num_profiles);
             umcRes = va_to_umc_res(va_res);
         }
@@ -442,6 +443,7 @@ Status LinuxVideoAccelerator::Init(VideoAcceleratorParams* pInfo)
         }
         if (UMC_OK == umcRes)
         {
+            PERF_UTILITY_AUTO("vaQueryConfigEntrypoints", PERF_LEVEL_DDI);
             va_res = vaQueryConfigEntrypoints(m_dpy, va_profile, va_entrypoints, &va_num_entrypoints);
             umcRes = va_to_umc_res(va_res);
         }
@@ -489,6 +491,7 @@ Status LinuxVideoAccelerator::Init(VideoAcceleratorParams* pInfo)
 
             va_attributes[nattr++].type = VAConfigAttribEncryption;
 
+            PERF_UTILITY_AUTO("vaGetConfigAttributes", PERF_LEVEL_DDI);
             va_res = vaGetConfigAttributes(m_dpy, va_profile, va_entrypoint, va_attributes, nattr);
             umcRes = va_to_umc_res(va_res);
         }
@@ -504,6 +507,7 @@ Status LinuxVideoAccelerator::Init(VideoAcceleratorParams* pInfo)
             m_pConfigId = pParams->m_pConfigId;
             if (*m_pConfigId == VA_INVALID_ID)
             {
+                PERF_UTILITY_AUTO("vaCreateConfig", PERF_LEVEL_DDI);
                 va_res = vaCreateConfig(m_dpy, va_profile, va_entrypoint, va_attributes, attribsNumber, m_pConfigId);
                 umcRes = va_to_umc_res(va_res);
                 needRecreateContext = true;
@@ -528,6 +532,7 @@ Status LinuxVideoAccelerator::Init(VideoAcceleratorParams* pInfo)
             MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_EXTCALL, "vaCreateContext");
 
             assert(!pParams->m_surf && "render targets tied to the context shoul be NULL");
+            PERF_UTILITY_AUTO("vaCreateContext", PERF_LEVEL_DDI);
             va_res = vaCreateContext(m_dpy, *m_pConfigId, width, height, pParams->m_CreateFlags, NULL, 0, m_pContext);
 
             umcRes = va_to_umc_res(va_res);
@@ -594,12 +599,14 @@ Status LinuxVideoAccelerator::Close(void)
         if ((m_pContext && (*m_pContext != VA_INVALID_ID)) && !(m_pKeepVAState && *m_pKeepVAState))
         {
             MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_EXTCALL, "vaDestroyContext");
+            PERF_UTILITY_AUTO("vaDestroyContext", PERF_LEVEL_DDI);
             VAStatus vaSts = vaDestroyContext(m_dpy, *m_pContext);
             std::ignore = MFX_STS_TRACE(vaSts);
             *m_pContext = VA_INVALID_ID;
         }
         if ((m_pConfigId && (*m_pConfigId != VA_INVALID_ID)) && !(m_pKeepVAState && *m_pKeepVAState))
         {
+            PERF_UTILITY_AUTO("vaDestroyConfig", PERF_LEVEL_DDI);
             VAStatus vaSts = vaDestroyConfig(m_dpy, *m_pConfigId);
             std::ignore = MFX_STS_TRACE(vaSts);
             *m_pConfigId = VA_INVALID_ID;
@@ -637,6 +644,7 @@ Status LinuxVideoAccelerator::BeginFrame(int32_t FrameBufIndex)
         {
             MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_EXTCALL, "vaBeginPicture");
             MFX_LTRACE_2(MFX_TRACE_LEVEL_EXTCALL, m_sDecodeTraceStart, "%d|%d", *m_pContext, 0);
+            PERF_UTILITY_AUTO("vaBeginPicture", PERF_LEVEL_DDI);
             VAStatus va_res = vaBeginPicture(m_dpy, *m_pContext, *surface);
             umcRes = va_to_umc_res(va_res);
         }
@@ -791,6 +799,7 @@ VACompBuffer* LinuxVideoAccelerator::GetCompBufferHW(int32_t type, int32_t size,
         }
         buffer_size = va_size * va_num_elements;
 
+        PERF_UTILITY_AUTO("vaCreateBuffer", PERF_LEVEL_DDI);
         va_res = vaCreateBuffer(m_dpy, *m_pContext, va_type, va_size, va_num_elements, NULL, &id);
     }
     if (VA_STATUS_SUCCESS == va_res)
@@ -832,17 +841,21 @@ LinuxVideoAccelerator::Execute()
             {
                 if (pCompBuf->GetType() == VASliceParameterBufferType)
                 {
+                    PERF_UTILITY_AUTO("vaBufferSetNumElements", PERF_LEVEL_DDI);
                     va_sts = vaBufferSetNumElements(m_dpy, id, pCompBuf->GetNumOfItem());
                     if (VA_STATUS_SUCCESS == va_res) va_res = va_sts;
                 }
             }
-
-            va_sts = vaUnmapBuffer(m_dpy, id);
+            {
+                PERF_UTILITY_AUTO("vaUnmapBuffer", PERF_LEVEL_DDI);
+                va_sts = vaUnmapBuffer(m_dpy, id);
+            }
             if (VA_STATUS_SUCCESS == va_res) va_res = va_sts;
 
 
             {
                 MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_EXTCALL, "vaRenderPicture");
+                PERF_UTILITY_AUTO("vaRenderPicture", PERF_LEVEL_DDI);
                 va_sts = vaRenderPicture(m_dpy, *m_pContext, &id, 1);
                 if (VA_STATUS_SUCCESS == va_res) va_res = va_sts;
             }
@@ -865,6 +878,7 @@ Status LinuxVideoAccelerator::EndFrame(void*)
 
     {
         MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_EXTCALL, "vaEndPicture");
+        PERF_UTILITY_AUTO("vaEndPicture", PERF_LEVEL_DDI);
         va_res = vaEndPicture(m_dpy, *m_pContext);
         MFX_LTRACE_2(MFX_TRACE_LEVEL_EXTCALL, m_sDecodeTraceEnd, "%d|%d", *m_pContext, 0);
     }
@@ -920,9 +934,10 @@ uint16_t LinuxVideoAccelerator::GetDecodingError()
     for(VASurfaceID surface : m_associatedIds)
     {
         VASurfaceDecodeMBErrors* pVaDecErr = NULL;
-
-        va_sts = vaQuerySurfaceError(m_dpy, surface, VA_STATUS_ERROR_DECODING_ERROR, (void**)&pVaDecErr);
-
+        {
+            PERF_UTILITY_AUTO("vaQuerySurfaceError", PERF_LEVEL_DDI);
+            va_sts = vaQuerySurfaceError(m_dpy, surface, VA_STATUS_ERROR_DECODING_ERROR, (void**)&pVaDecErr);
+        }
         if (VA_STATUS_SUCCESS == va_sts)
         {
             if (NULL != pVaDecErr)
@@ -994,13 +1009,19 @@ Status LinuxVideoAccelerator::QueryTaskStatus(int32_t FrameBufIndex, void * stat
         return sts;
 
     VASurfaceStatus surface_status;
-
-    VAStatus va_status = vaQuerySurfaceStatus(m_dpy, *surface, &surface_status);
+    VAStatus va_status;
     VAStatus va_sts;
+    {
+        PERF_UTILITY_AUTO("vaQuerySurfaceStatus", PERF_LEVEL_DDI);
+        va_status = vaQuerySurfaceStatus(m_dpy, *surface, &surface_status);
+    }
     if ((VA_STATUS_SUCCESS == va_status) && (VASurfaceReady == surface_status))
     {
-        // handle decoding errors
-        va_sts = vaSyncSurface(m_dpy, *surface);
+        {
+            PERF_UTILITY_AUTO("vaSyncSurface", PERF_LEVEL_DDI);
+            // handle decoding errors
+            va_sts = vaSyncSurface(m_dpy, *surface);
+        }
 
         if (error)
         {
@@ -1043,12 +1064,12 @@ Status LinuxVideoAccelerator::SyncTask(int32_t FrameBufIndex, void *surfCorrupti
     VAStatus va_sts = VA_STATUS_SUCCESS;
     {
         MFX_AUTO_LTRACE(MFX_TRACE_LEVEL_EXTCALL, "vaSyncSurface");
+        PERF_UTILITY_AUTO("vaSyncSurface", PERF_LEVEL_DDI);
         va_sts = vaSyncSurface(m_dpy, *surface);
     }
-    if (EnableEventTrace)
-    {
-        TRACE_EVENT(MFX_TRACE_HOTSPOT_DDI_WAIT_TASK_SYNC, EVENT_TYPE_INFO, 0, make_event_data(FrameBufIndex, 0, va_sts));
-    }
+
+    TRACE_EVENT(MFX_TRACE_HOTSPOT_DDI_WAIT_TASK_SYNC, EVENT_TYPE_INFO, 0, make_event_data(FrameBufIndex, 0, va_sts));
+
     if (VA_STATUS_ERROR_DECODING_ERROR == va_sts)
     {
         if (surfCorruption) *(uint16_t*)surfCorruption = GetDecodingError();
