@@ -980,6 +980,11 @@ STRUCT(mfxExtPartialBitstreamParam,
     FIELD_T(mfxU16, reserved)
 )
 
+STRUCT(mfxExtVPPPercEncPrefilter,
+    FIELD_S(mfxExtBuffer, Header)
+    FIELD_T(mfxU16, reserved)
+)
+
 #if defined(MFX_ENABLE_ENCTOOLS)
 STRUCT(mfxExtEncToolsConfig,
     FIELD_S(mfxExtBuffer, Header)
@@ -998,3 +1003,9 @@ STRUCT(mfxExtEncToolsConfig,
     FIELD_T(mfxU16, reserved) /* Fixed size array */
 )
 #endif
+
+#ifdef MFX_ENABLE_ENCODE_STATS
+STRUCT(mfxExtEncodeStatsOutput,
+    FIELD_S(mfxExtBuffer, Header)
+)
+#endif
